@@ -16,6 +16,7 @@
 
 from nova import manager
 from nova.network import driver
+from nova import utils
 
 
 class MetadataManager(manager.Manager):
@@ -26,5 +27,10 @@ class MetadataManager(manager.Manager):
     """
     def __init__(self, *args, **kwargs):
         super(MetadataManager, self).__init__(*args, **kwargs)
-        self.network_driver = driver.load_network_driver()
-        self.network_driver.metadata_accept()
+
+        if not utils.is_neutron():
+            # NOTE(mikal): we only add iptables rules if we're running
+            # under nova-network. This code should go away when the
+            # deprecation of nova-network is complete.
+            self.network_driver = driver.load_network_driver()
+            self.network_driver.metadata_accept()
