@@ -16,7 +16,6 @@ from webob import exc
 
 from nova.api.openstack import common
 from nova.api.openstack.compute.schemas import admin_password
-from nova.api.openstack import extensions
 from nova.api.openstack import wsgi
 from nova.api import validation
 from nova import compute
@@ -36,7 +35,7 @@ class AdminPasswordController(wsgi.Controller):
     # a response.
     @wsgi.action('changePassword')
     @wsgi.response(202)
-    @extensions.expected_errors((400, 404, 409, 501))
+    @wsgi.expected_errors((404, 409, 501))
     @validation.schema(admin_password.change_password)
     def change_password(self, req, id, body):
         context = req.environ['nova.context']
