@@ -15,7 +15,6 @@
 
 from webob import exc
 
-from nova.api.openstack import extensions
 from nova.api.openstack import wsgi
 from nova.console import api as console_api
 from nova import exception
@@ -48,7 +47,7 @@ class ConsolesController(wsgi.Controller):
     def __init__(self):
         self.console_api = console_api.API()
 
-    @extensions.expected_errors(())
+    @wsgi.expected_errors(())
     def index(self, req, server_id):
         """Returns a list of consoles for this instance."""
         context = req.environ['nova.context']
@@ -62,7 +61,7 @@ class ConsolesController(wsgi.Controller):
     # NOTE(gmann): Here should be 201 instead of 200 by v2.1
     # +microversions because the console has been created
     # completely when returning a response.
-    @extensions.expected_errors(404)
+    @wsgi.expected_errors(404)
     def create(self, req, server_id, body):
         """Creates a new console."""
         context = req.environ['nova.context']
@@ -74,7 +73,7 @@ class ConsolesController(wsgi.Controller):
         except exception.InstanceNotFound as e:
             raise exc.HTTPNotFound(explanation=e.format_message())
 
-    @extensions.expected_errors(404)
+    @wsgi.expected_errors(404)
     def show(self, req, server_id, id):
         """Shows in-depth information on a specific console."""
         context = req.environ['nova.context']
@@ -90,7 +89,7 @@ class ConsolesController(wsgi.Controller):
         return _translate_detail_keys(console)
 
     @wsgi.response(202)
-    @extensions.expected_errors(404)
+    @wsgi.expected_errors(404)
     def delete(self, req, server_id, id):
         """Deletes a console."""
         context = req.environ['nova.context']
