@@ -16,9 +16,7 @@ from oslo_log import log as logging
 
 import webob.exc
 
-from nova.api.openstack import extensions
 from nova.api.openstack import wsgi
-from nova import exception
 from nova.policies import extensions as ext_policies
 
 LOG = logging.getLogger(__name__)
@@ -865,7 +863,7 @@ class ExtensionInfoController(wsgi.Controller):
                                   ' to the virtual interface list.'}
         all_extensions.append(vif_extension_info)
 
-    @extensions.expected_errors(())
+    @wsgi.expected_errors(())
     def index(self, req):
         context = req.environ['nova.context']
         context.can(ext_policies.BASE_POLICY_NAME)
@@ -877,7 +875,7 @@ class ExtensionInfoController(wsgi.Controller):
 
         return dict(extensions=EXTENSION_LIST)
 
-    @extensions.expected_errors(404)
+    @wsgi.expected_errors(404)
     def show(self, req, id):
         context = req.environ['nova.context']
         context.can(ext_policies.BASE_POLICY_NAME)
@@ -893,35 +891,3 @@ class ExtensionInfoController(wsgi.Controller):
                 return dict(extension=ext)
 
         raise webob.exc.HTTPNotFound()
-
-
-class LoadedExtensionInfo(object):
-    """Keep track of all loaded API extensions."""
-
-    def __init__(self):
-        self.extensions = {}
-
-    def register_extension(self, ext):
-        if not self._check_extension(ext):
-            return False
-
-        alias = ext.alias
-
-        if alias in self.extensions:
-            raise exception.NovaException("Found duplicate extension: %s"
-                                          % alias)
-        self.extensions[alias] = ext
-        return True
-
-    def _check_extension(self, extension):
-        """Checks for required methods in extension objects."""
-        try:
-            extension.is_valid()
-        except AttributeError:
-            LOG.exception("Exception loading extension")
-            return False
-
-        return True
-
-    def get_extensions(self):
-        return self.extensions
