@@ -20,16 +20,13 @@ import webob
 from nova.api.openstack import api_version_request
 from nova.api.openstack import common
 from nova.api.openstack.compute.schemas import flavor_access
-from nova.api.openstack import extensions
+from nova.api.openstack import identity
 from nova.api.openstack import wsgi
 from nova.api import validation
 from nova import exception
 from nova.i18n import _
-from nova import objects
 from nova.policies import flavor_access as fa_policies
 
-ALIAS = 'os-flavor-access'
-
 
 def _marshall_flavor_access(flavor):
     rval = []
@@ -42,7 +39,7 @@ def _marshall_flavor_access(flavor):
 
 class FlavorAccessController(wsgi.Controller):
     """The flavor access API controller for the OpenStack API."""
-    @extensions.expected_errors(404)
+    @wsgi.expected_errors(404)
     def index(self, req, flavor_id):
         context = req.environ['nova.context']
         context.can(fa_policies.BASE_POLICY_NAME)
@@ -60,36 +57,8 @@ class FlavorAccessController(wsgi.Controller):
 
 class FlavorActionController(wsgi.Controller):
     """The flavor access API controller for the OpenStack API."""
-    def _extend_flavor(self, flavor_rval, flavor_ref):
-        key = "%s:is_public" % (FlavorAccess.alias)
-        flavor_rval[key] = flavor_ref['is_public']
 
-    @wsgi.extends
-    def show(self, req, resp_obj, id):
-        context = req.environ['nova.context']
-        if context.can(fa_policies.BASE_POLICY_NAME, fatal=False):
-            db_flavor = req.get_db_flavor(id)
-
-            self._extend_flavor(resp_obj.obj['flavor'], db_flavor)
-
-    @wsgi.extends
-    def detail(self, req, resp_obj):
-        context = req.environ['nova.context']
-        if context.can(fa_policies.BASE_POLICY_NAME, fatal=False):
-            flavors = list(resp_obj.obj['flavors'])
-            for flavor_rval in flavors:
-                db_flavor = req.get_db_flavor(flavor_rval['id'])
-                self._extend_flavor(flavor_rval, db_flavor)
-
-    @wsgi.extends(action='create')
-    def create(self, req, body, resp_obj):
-        context = req.environ['nova.context']
-        if context.can(fa_policies.BASE_POLICY_NAME, fatal=False):
-            db_flavor = req.get_db_flavor(resp_obj.obj['flavor']['id'])
-
-            self._extend_flavor(resp_obj.obj['flavor'], db_flavor)
-
-    @extensions.expected_errors((400, 403, 404, 409))
+    @wsgi.expected_errors((400, 403, 404, 409))
     @wsgi.action("addTenantAccess")
     @validation.schema(flavor_access.add_tenant_access)
     def _add_tenant_access(self, req, id, body):
@@ -98,6 +67,7 @@ class FlavorActionController(wsgi.Controller):
 
         vals = body['addTenantAccess']
         tenant = vals['tenant']
+        identity.verify_project_id(context, tenant)
 
         flavor = common.get_flavor(context, id)
 
@@ -113,7 +83,7 @@ class FlavorActionController(wsgi.Controller):
             raise webob.exc.HTTPConflict(explanation=err.format_message())
         return _marshall_flavor_access(flavor)
 
-    @extensions.expected_errors((400, 403, 404))
+    @wsgi.expected_errors((400, 403, 404))
     @wsgi.action("removeTenantAccess")
     @validation.schema(flavor_access.remove_tenant_access)
     def _remove_tenant_access(self, req, id, body):
@@ -123,33 +93,16 @@ class FlavorActionController(wsgi.Controller):
 
         vals = body['removeTenantAccess']
         tenant = vals['tenant']
+        identity.verify_project_id(context, tenant)
+
+        # NOTE(gibi): We have to load a flavor from the db here as
+        # flavor.remove_access() will try to emit a notification and that needs
+        # a fully loaded flavor.
+        flavor = common.get_flavor(context, id)
 
-        flavor = objects.Flavor(context=context, flavorid=id)
         try:
             flavor.remove_access(tenant)
         except (exception.FlavorAccessNotFound,
                 exception.FlavorNotFound) as e:
             raise webob.exc.HTTPNotFound(explanation=e.format_message())
         return _marshall_flavor_access(flavor)
-
-
-class FlavorAccess(extensions.V21APIExtensionBase):
-    """Flavor access support."""
-
-    name = "FlavorAccess"
-    alias = ALIAS
-    version = 1
-
-    def get_resources(self):
-        res = extensions.ResourceExtension(
-            ALIAS,
-            controller=FlavorAccessController(),
-            parent=dict(member_name='flavor', collection_name='flavors'))
-
-        return [res]
-
-    def get_controller_extensions(self):
-        extension = extensions.ControllerExtension(
-                self, 'flavors', FlavorActionController())
-
-        return [extension]
