@@ -20,7 +20,6 @@ from nova.api.openstack.api_version_request import \
     MAX_IMAGE_META_PROXY_API_VERSION
 from nova.api.openstack import common
 from nova.api.openstack.compute.schemas import image_metadata
-from nova.api.openstack import extensions
 from nova.api.openstack import wsgi
 from nova.api import validation
 from nova import exception
@@ -44,7 +43,7 @@ class ImageMetadataController(wsgi.Controller):
             raise exc.HTTPNotFound(explanation=msg)
 
     @wsgi.Controller.api_version("2.1", MAX_IMAGE_META_PROXY_API_VERSION)
-    @extensions.expected_errors((403, 404))
+    @wsgi.expected_errors((403, 404))
     def index(self, req, image_id):
         """Returns the list of metadata for a given instance."""
         context = req.environ['nova.context']
@@ -52,7 +51,7 @@ class ImageMetadataController(wsgi.Controller):
         return dict(metadata=metadata)
 
     @wsgi.Controller.api_version("2.1", MAX_IMAGE_META_PROXY_API_VERSION)
-    @extensions.expected_errors((403, 404))
+    @wsgi.expected_errors((403, 404))
     def show(self, req, image_id, id):
         context = req.environ['nova.context']
         metadata = self._get_image(context, image_id)['properties']
@@ -62,7 +61,7 @@ class ImageMetadataController(wsgi.Controller):
             raise exc.HTTPNotFound()
 
     @wsgi.Controller.api_version("2.1", MAX_IMAGE_META_PROXY_API_VERSION)
-    @extensions.expected_errors((400, 403, 404))
+    @wsgi.expected_errors((400, 403, 404))
     @validation.schema(image_metadata.create)
     def create(self, req, image_id, body):
         context = req.environ['nova.context']
@@ -79,7 +78,7 @@ class ImageMetadataController(wsgi.Controller):
         return dict(metadata=image['properties'])
 
     @wsgi.Controller.api_version("2.1", MAX_IMAGE_META_PROXY_API_VERSION)
-    @extensions.expected_errors((400, 403, 404))
+    @wsgi.expected_errors((400, 403, 404))
     @validation.schema(image_metadata.update)
     def update(self, req, image_id, id, body):
         context = req.environ['nova.context']
@@ -102,7 +101,7 @@ class ImageMetadataController(wsgi.Controller):
         return dict(meta=meta)
 
     @wsgi.Controller.api_version("2.1", MAX_IMAGE_META_PROXY_API_VERSION)
-    @extensions.expected_errors((400, 403, 404))
+    @wsgi.expected_errors((400, 403, 404))
     @validation.schema(image_metadata.update_all)
     def update_all(self, req, image_id, body):
         context = req.environ['nova.context']
@@ -118,7 +117,7 @@ class ImageMetadataController(wsgi.Controller):
         return dict(metadata=metadata)
 
     @wsgi.Controller.api_version("2.1", MAX_IMAGE_META_PROXY_API_VERSION)
-    @extensions.expected_errors((403, 404))
+    @wsgi.expected_errors((403, 404))
     @wsgi.response(204)
     def delete(self, req, image_id, id):
         context = req.environ['nova.context']
