@@ -15,30 +15,41 @@
 
 from webob import exc
 
+from oslo_utils import timeutils
+
 from nova.api.openstack import api_version_request
 from nova.api.openstack import common
-from nova.api.openstack import extensions
+from nova.api.openstack.compute.schemas \
+    import instance_actions as schema_instance_actions
+from nova.api.openstack.compute.views \
+    import instance_actions as instance_actions_view
 from nova.api.openstack import wsgi
+from nova.api import validation
 from nova import compute
+from nova import exception
 from nova.i18n import _
 from nova.policies import instance_actions as ia_policies
 from nova import utils
 
+
 ACTION_KEYS = ['action', 'instance_uuid', 'request_id', 'user_id',
                'project_id', 'start_time', 'message']
+ACTION_KEYS_V258 = ['action', 'instance_uuid', 'request_id', 'user_id',
+                    'project_id', 'start_time', 'message', 'updated_at']
 EVENT_KEYS = ['event', 'start_time', 'finish_time', 'result', 'traceback']
 
 
 class InstanceActionsController(wsgi.Controller):
+    _view_builder_class = instance_actions_view.ViewBuilder
 
     def __init__(self):
         super(InstanceActionsController, self).__init__()
         self.compute_api = compute.API()
         self.action_api = compute.InstanceActionAPI()
 
-    def _format_action(self, action_raw):
+    def _format_action(self, action_raw, action_keys):
         action = {}
-        for key in ACTION_KEYS:
+        for key in action_keys:
             action[key] = action_raw.get(key)
         return action
 
@@ -60,17 +71,50 @@ class InstanceActionsController(wsgi.Controller):
         with utils.temporary_mutation(context, read_deleted='yes'):
             return common.get_instance(self.compute_api, context, server_id)
 
-    @extensions.expected_errors(404)
+    @wsgi.Controller.api_version("2.1", "2.57")
+    @wsgi.expected_errors(404)
     def index(self, req, server_id):
         """Returns the list of actions recorded for a given instance."""
         context = req.environ["nova.context"]
         instance = self._get_instance(req, context, server_id)
         context.can(ia_policies.BASE_POLICY_NAME, instance)
         actions_raw = self.action_api.actions_get(context, instance)
-        actions = [self._format_action(action) for action in actions_raw]
+        actions = [self._format_action(action, ACTION_KEYS)
+                   for action in actions_raw]
         return {'instanceActions': actions}
 
-    @extensions.expected_errors(404)
+    @wsgi.Controller.api_version("2.58")  # noqa
+    @wsgi.expected_errors((400, 404))
+    @validation.query_schema(schema_instance_actions.list_query_params_v258,
+                             "2.58")
+    def index(self, req, server_id):
+        """Returns the list of actions recorded for a given instance."""
+        context = req.environ["nova.context"]
+        instance = self._get_instance(req, context, server_id)
+        context.can(ia_policies.BASE_POLICY_NAME, instance)
+        search_opts = {}
+        search_opts.update(req.GET)
+        if 'changes-since' in search_opts:
+            search_opts['changes-since'] = timeutils.parse_isotime(
+                search_opts['changes-since'])
+
+        limit, marker = common.get_limit_and_marker(req)
+        try:
+            actions_raw = self.action_api.actions_get(context, instance,
+                                                      limit=limit,
+                                                      marker=marker,
+                                                      filters=search_opts)
+        except exception.MarkerNotFound as e:
+            raise exc.HTTPBadRequest(explanation=e.format_message())
+        actions = [self._format_action(action, ACTION_KEYS_V258)
+                   for action in actions_raw]
+        actions_dict = {'instanceActions': actions}
+        actions_links = self._view_builder.get_links(req, server_id, actions)
+        if actions_links:
+            actions_dict['links'] = actions_links
+        return actions_dict
+
+    @wsgi.expected_errors(404)
     def show(self, req, server_id, id):
         """Return data about the given instance action."""
         context = req.environ['nova.context']
@@ -83,7 +127,10 @@ class InstanceActionsController(wsgi.Controller):
             raise exc.HTTPNotFound(explanation=msg)
 
         action_id = action['id']
-        action = self._format_action(action)
+        if api_version_request.is_supported(req, min_version="2.58"):
+            action = self._format_action(action, ACTION_KEYS_V258)
+        else:
+            action = self._format_action(action, ACTION_KEYS)
         # Prior to microversion 2.51, events would only be returned in the
         # response for admins by default policy rules. Starting in
         # microversion 2.51, events are returned for admin_or_owner (of the
