@@ -14,7 +14,6 @@
 #   under the License.
 
 from nova.api.openstack import common
-from nova.api.openstack import extensions
 from nova.api.openstack import wsgi
 from nova import compute
 from nova.policies import lock_server as ls_policies
@@ -26,7 +25,7 @@ class LockServerController(wsgi.Controller):
         self.compute_api = compute.API()
 
     @wsgi.response(202)
-    @extensions.expected_errors(404)
+    @wsgi.expected_errors(404)
     @wsgi.action('lock')
     def _lock(self, req, id, body):
         """Lock a server instance."""
@@ -38,7 +37,7 @@ class LockServerController(wsgi.Controller):
         self.compute_api.lock(context, instance)
 
     @wsgi.response(202)
-    @extensions.expected_errors(404)
+    @wsgi.expected_errors(404)
     @wsgi.action('unlock')
     def _unlock(self, req, id, body):
         """Unlock a server instance."""
