@@ -14,6 +14,7 @@
 
 import copy
 
+from nova.api.openstack.compute.schemas import user_data
 from nova.api.validation import parameter_types
 from nova.api.validation.parameter_types import multi_params
 from nova.objects import instance
@@ -53,6 +54,7 @@ base_create = {
                 'accessIPv4': parameter_types.accessIPv4,
                 'accessIPv6': parameter_types.accessIPv6,
                 'personality': parameter_types.personality,
+                'availability_zone': parameter_types.name,
             },
             'required': ['name', 'flavorRef'],
             'additionalProperties': False,
@@ -66,6 +68,8 @@ base_create = {
 base_create_v20 = copy.deepcopy(base_create)
 base_create_v20['properties']['server'][
     'properties']['name'] = parameter_types.name_with_leading_trailing_spaces
+base_create_v20['properties']['server']['properties'][
+    'availability_zone'] = parameter_types.name_with_leading_trailing_spaces
 
 
 base_create_v219 = copy.deepcopy(base_create)
@@ -139,6 +143,11 @@ base_create_v252['properties']['server']['properties']['tags'] = {
 }
 
 
+# 2.57 builds on 2.52 and removes the personality parameter.
+base_create_v257 = copy.deepcopy(base_create_v252)
+base_create_v257['properties']['server']['properties'].pop('personality')
+
+
 base_update = {
     'type': 'object',
     'properties': {
@@ -199,6 +208,22 @@ base_rebuild_v219 = copy.deepcopy(base_rebuild)
 base_rebuild_v219['properties']['rebuild'][
     'properties']['description'] = parameter_types.description
 
+base_rebuild_v254 = copy.deepcopy(base_rebuild_v219)
+base_rebuild_v254['properties']['rebuild'][
+    'properties']['key_name'] = parameter_types.name_or_none
+
+# 2.57 builds on 2.54 and makes the following changes:
+# 1. Remove the personality parameter.
+# 2. Add the user_data parameter which is nullable so user_data can be reset.
+base_rebuild_v257 = copy.deepcopy(base_rebuild_v254)
+base_rebuild_v257['properties']['rebuild']['properties'].pop('personality')
+base_rebuild_v257['properties']['rebuild']['properties']['user_data'] = ({
+    'oneOf': [
+        user_data.common_user_data,
+        {'type': 'null'}
+    ]
+})
+
 resize = {
     'type': 'object',
     'properties': {
@@ -269,19 +294,15 @@ trigger_crash_dump = {
     'additionalProperties': False
 }
 
-# NOTE: We don't check actual values of queries on params
-# which are defined as the following common_param.
-common_param = multi_params({'type': 'string'})
-common_regex_param = multi_params({'type': 'string', 'format': 'regex'})
 
 JOINED_TABLE_QUERY_PARAMS_SERVERS = {
-    'block_device_mapping': common_param,
-    'services': common_param,
-    'metadata': common_param,
-    'system_metadata': common_param,
-    'info_cache': common_param,
-    'security_groups': common_param,
-    'pci_devices': common_param
+    'block_device_mapping': parameter_types.common_query_param,
+    'services': parameter_types.common_query_param,
+    'metadata': parameter_types.common_query_param,
+    'system_metadata': parameter_types.common_query_param,
+    'info_cache': parameter_types.common_query_param,
+    'security_groups': parameter_types.common_query_param,
+    'pci_devices': parameter_types.common_query_param
 }
 
 # These fields are valid values for sort_keys before we start
@@ -313,59 +334,59 @@ VALID_SORT_KEYS = {
 query_params_v21 = {
     'type': 'object',
     'properties': {
-        'user_id': common_param,
-        'project_id': common_param,
+        'user_id': parameter_types.common_query_param,
+        'project_id': parameter_types.common_query_param,
         # The alias of project_id. It should be removed in the
         # future with microversion bump.
-        'tenant_id': common_param,
-        'launch_index': common_param,
+        'tenant_id': parameter_types.common_query_param,
+        'launch_index': parameter_types.common_query_param,
         # The alias of image. It should be removed in the
         # future with microversion bump.
-        'image_ref': common_param,
-        'image': common_param,
-        'kernel_id': common_regex_param,
-        'ramdisk_id': common_regex_param,
-        'hostname': common_regex_param,
-        'key_name': common_regex_param,
-        'power_state': common_regex_param,
-        'vm_state': common_param,
-        'task_state': common_param,
-        'host': common_param,
-        'node': common_regex_param,
-        'flavor': common_regex_param,
-        'reservation_id': common_regex_param,
-        'launched_at': common_regex_param,
-        'terminated_at': common_regex_param,
-        'availability_zone': common_regex_param,
+        'image_ref': parameter_types.common_query_param,
+        'image': parameter_types.common_query_param,
+        'kernel_id': parameter_types.common_query_regex_param,
+        'ramdisk_id': parameter_types.common_query_regex_param,
+        'hostname': parameter_types.common_query_regex_param,
+        'key_name': parameter_types.common_query_regex_param,
+        'power_state': parameter_types.common_query_regex_param,
+        'vm_state': parameter_types.common_query_param,
+        'task_state': parameter_types.common_query_param,
+        'host': parameter_types.common_query_param,
+        'node': parameter_types.common_query_regex_param,
+        'flavor': parameter_types.common_query_regex_param,
+        'reservation_id': parameter_types.common_query_regex_param,
+        'launched_at': parameter_types.common_query_regex_param,
+        'terminated_at': parameter_types.common_query_regex_param,
+        'availability_zone': parameter_types.common_query_regex_param,
         # NOTE(alex_xu): This is pattern matching, it didn't get any benefit
         # from DB index.
-        'name': common_regex_param,
+        'name': parameter_types.common_query_regex_param,
         # The alias of name. It should be removed in the future
         # with microversion bump.
-        'display_name': common_regex_param,
-        'description': common_regex_param,
+        'display_name': parameter_types.common_query_regex_param,
+        'description': parameter_types.common_query_regex_param,
         # The alias of description. It should be removed in the
         # future with microversion bump.
-        'display_description': common_regex_param,
-        'locked_by': common_regex_param,
-        'uuid': common_param,
-        'root_device_name': common_regex_param,
-        'config_drive': common_regex_param,
-        'access_ip_v4': common_regex_param,
-        'access_ip_v6': common_regex_param,
-        'auto_disk_config': common_regex_param,
-        'progress': common_regex_param,
+        'display_description': parameter_types.common_query_regex_param,
+        'locked_by': parameter_types.common_query_regex_param,
+        'uuid': parameter_types.common_query_param,
+        'root_device_name': parameter_types.common_query_regex_param,
+        'config_drive': parameter_types.common_query_regex_param,
+        'access_ip_v4': parameter_types.common_query_regex_param,
+        'access_ip_v6': parameter_types.common_query_regex_param,
+        'auto_disk_config': parameter_types.common_query_regex_param,
+        'progress': parameter_types.common_query_regex_param,
         'sort_key': multi_params(VALID_SORT_KEYS),
-        'sort_dir': common_param,
-        'all_tenants': common_param,
-        'deleted': common_param,
-        'status': common_param,
+        'sort_dir': parameter_types.common_query_param,
+        'all_tenants': parameter_types.common_query_param,
+        'deleted': parameter_types.common_query_param,
+        'status': parameter_types.common_query_param,
         'changes-since': multi_params({'type': 'string',
                                        'format': 'date-time'}),
         # NOTE(alex_xu): The ip and ip6 are implemented in the python.
-        'ip': common_regex_param,
-        'ip6': common_regex_param,
-        'created_at': common_regex_param,
+        'ip': parameter_types.common_query_regex_param,
+        'ip6': parameter_types.common_query_regex_param,
+        'created_at': parameter_types.common_query_regex_param,
     },
     # For backward-compatible additionalProperties is set to be True here.
     # And we will either strip the extra params out or raise HTTP 400
@@ -373,7 +394,7 @@ query_params_v21 = {
     'additionalProperties': True,
     # Prevent internal-attributes that are started with underscore from
     # being striped out in schema validation, and raise HTTP 400 in API.
-    'patternProperties': {"^_": common_param}
+    'patternProperties': {"^_": parameter_types.common_query_param}
 }
 
 # Update the joined-table fields to the list so it will not be
@@ -387,8 +408,8 @@ query_params_v21['properties'].update(
 
 query_params_v226 = copy.deepcopy(query_params_v21)
 query_params_v226['properties'].update({
-    'tags': common_regex_param,
-    'tags-any': common_regex_param,
-    'not-tags': common_regex_param,
-    'not-tags-any': common_regex_param,
+    'tags': parameter_types.common_query_regex_param,
+    'tags-any': parameter_types.common_query_regex_param,
+    'not-tags': parameter_types.common_query_regex_param,
+    'not-tags-any': parameter_types.common_query_regex_param,
 })
