@@ -15,7 +15,6 @@
 from webob import exc
 
 from nova.api.openstack import common
-from nova.api.openstack import extensions
 from nova.api.openstack import wsgi
 from nova import compute
 from nova import exception
@@ -28,7 +27,7 @@ class SuspendServerController(wsgi.Controller):
         self.compute_api = compute.API()
 
     @wsgi.response(202)
-    @extensions.expected_errors((404, 409))
+    @wsgi.expected_errors((404, 409))
     @wsgi.action('suspend')
     def _suspend(self, req, id, body):
         """Permit admins to suspend the server."""
@@ -48,7 +47,7 @@ class SuspendServerController(wsgi.Controller):
                     'suspend', id)
 
     @wsgi.response(202)
-    @extensions.expected_errors((404, 409))
+    @wsgi.expected_errors((404, 409))
     @wsgi.action('resume')
     def _resume(self, req, id, body):
         """Permit admins to resume the server from suspend."""
