@@ -14,6 +14,8 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
+from oslo_utils import strutils
+
 from nova.api.openstack import common
 from nova.image import glance
 from nova import utils
@@ -70,6 +72,12 @@ class ViewBuilder(common.ViewBuilder):
                 }],
             }
 
+        auto_disk_config = image_dict['metadata'].get("auto_disk_config", None)
+        if auto_disk_config is not None:
+            value = strutils.bool_from_string(auto_disk_config)
+            image_dict["OS-DCF:diskConfig"] = (
+                'AUTO' if value else 'MANUAL')
+
         return dict(image=image_dict)
 
     def detail(self, request, images):
@@ -124,7 +132,8 @@ class ViewBuilder(common.ViewBuilder):
 
     def _get_alternate_link(self, request, identifier):
         """Create an alternate link for a specific image id."""
-        glance_url = glance.generate_glance_url()
+        glance_url = glance.generate_glance_url(
+            request.environ['nova.context'])
         glance_url = self._update_glance_link_prefix(glance_url)
         return '/'.join([glance_url,
                          self._collection_name,
