@@ -18,7 +18,6 @@ Cell scheduler filters
 """
 
 from nova import filters
-from nova import policy
 
 
 class BaseCellFilter(filters.BaseFilter):
@@ -31,9 +30,7 @@ class BaseCellFilter(filters.BaseFilter):
         is the name of the filter class.
         """
         name = 'cells_scheduler_filter:' + self.__class__.__name__
-        target = {'project_id': ctxt.project_id,
-                  'user_id': ctxt.user_id}
-        return policy.enforce(ctxt, name, target, do_raise=False)
+        return ctxt.can(name, fatal=False)
 
     def _filter_one(self, cell, filter_properties):
         return self.cell_passes(cell, filter_properties)
