@@ -20,6 +20,7 @@ import sys
 
 from oslo_log import log as logging
 from oslo_reports import guru_meditation_report as gmr
+from oslo_reports import opts as gmr_opts
 
 from nova.conductor import rpcapi as conductor_rpcapi
 import nova.conf
@@ -39,8 +40,9 @@ def main():
     logging.setup(CONF, "nova")
     utils.monkey_patch()
     objects.register_all()
+    gmr_opts.set_defaults(CONF)
 
-    gmr.TextGuruMeditation.setup_autorun(version)
+    gmr.TextGuruMeditation.setup_autorun(version, conf=CONF)
 
     objects_base.NovaObject.indirection_api = conductor_rpcapi.ConductorAPI()
 
