@@ -25,6 +25,7 @@ from nova.cmd import baseproxy
 import nova.conf
 from nova.conf import vnc
 from nova import config
+from nova.console.securityproxy import rfb
 
 
 CONF = nova.conf.CONF
@@ -36,6 +37,13 @@ def main():
     CONF.set_default('web', '/usr/share/novnc')
     config.parse_args(sys.argv)
 
+    # TODO(stephenfin): Always enable the security proxy once we support RFB
+    # version 3.3, as used in XenServer.
+    security_proxy = None
+    if CONF.compute_driver != 'xenapi.XenAPIDriver':
+        security_proxy = rfb.RFBSecurityProxy()
+
     baseproxy.proxy(
         host=CONF.vnc.novncproxy_host,
-        port=CONF.vnc.novncproxy_port)
+        port=CONF.vnc.novncproxy_port,
+        security_proxy=security_proxy)
