@@ -20,6 +20,7 @@ import sys
 
 from oslo_log import log as logging
 from oslo_reports import guru_meditation_report as gmr
+from oslo_reports import opts as gmr_opts
 
 import nova.conf
 from nova import config
@@ -37,9 +38,10 @@ def main():
     logging.setup(CONF, "nova")
     utils.monkey_patch()
     objects.register_all()
+    gmr_opts.set_defaults(CONF)
     objects.Service.enable_min_version_cache()
 
-    gmr.TextGuruMeditation.setup_autorun(version)
+    gmr.TextGuruMeditation.setup_autorun(version, conf=CONF)
 
     server = service.Service.create(binary='nova-scheduler',
                                     topic=scheduler_rpcapi.RPC_TOPIC)
