@@ -19,18 +19,23 @@ import sys
 
 from oslo_log import log as logging
 from oslo_reports import guru_meditation_report as gmr
+from oslo_reports import opts as gmr_opts
 
+import nova.conf
 from nova import config
 from nova import service
 from nova import version
 from nova.vnc import xvp_proxy
 
+CONF = nova.conf.CONF
+
 
 def main():
     config.parse_args(sys.argv)
     logging.setup(config.CONF, "nova")
+    gmr_opts.set_defaults(CONF)
 
-    gmr.TextGuruMeditation.setup_autorun(version)
+    gmr.TextGuruMeditation.setup_autorun(version, conf=CONF)
 
     wsgi_server = xvp_proxy.get_wsgi_server()
     service.serve(wsgi_server)
