@@ -578,8 +578,12 @@ class ResourceTracker(object):
         cn = objects.ComputeNode(context)
         cn.host = self.host
         self._copy_resources(cn, resources)
-        self.compute_nodes[nodename] = cn
         cn.create()
+        # Only map the ComputeNode into compute_nodes if create() was OK
+        # because if create() fails, on the next run through here nodename
+        # would be in compute_nodes and we won't try to create again (because
+        # of the logic above).
+        self.compute_nodes[nodename] = cn
         LOG.info('Compute node record created for '
                  '%(host)s:%(node)s with uuid: %(uuid)s',
                  {'host': self.host, 'node': nodename, 'uuid': cn.uuid})
@@ -642,6 +646,16 @@ class ResourceTracker(object):
         # now copy rest to compute_node
         compute_node.update_from_virt_driver(resources)
 
+    def remove_node(self, nodename):
+        """Handle node removal/rebalance.
+
+        Clean up any stored data about a compute node no longer
+        managed by this host.
+        """
+        self.stats.pop(nodename, None)
+        self.compute_nodes.pop(nodename, None)
+        self.old_resources.pop(nodename, None)
+
     def _get_host_metrics(self, context, nodename):
         """Get the metrics from monitors and
         notify information to message bus.
