@@ -14,6 +14,7 @@ from oslo_log import log as logging
 import oslo_messaging as messaging
 import six
 
+from nova import availability_zones
 from nova.compute import power_state
 from nova.conductor.tasks import base
 from nova.conductor.tasks import migrate
@@ -21,6 +22,7 @@ import nova.conf
 from nova import exception
 from nova.i18n import _
 from nova import objects
+from nova.objects import fields as obj_fields
 from nova.scheduler import utils as scheduler_utils
 from nova import utils
 
@@ -55,6 +57,7 @@ class LiveMigrationTask(base.TaskBase):
 
     def _execute(self):
         self._check_instance_is_active()
+        self._check_instance_has_no_numa()
         self._check_host_is_up(self.source)
 
         if should_do_migration_allocation(self.context):
@@ -99,6 +102,10 @@ class LiveMigrationTask(base.TaskBase):
             # node name off it to set in the Migration object below.
             dest_node = dest_node.hypervisor_hostname
 
+        self.instance.availability_zone = (
+            availability_zones.get_host_availability_zone(
+                self.context, self.destination))
+
         self.migration.source_node = self.instance.node
         self.migration.dest_node = dest_node
         self.migration.dest_compute = self.destination
@@ -136,6 +143,33 @@ class LiveMigrationTask(base.TaskBase):
                     state=self.instance.power_state,
                     method='live migrate')
 
+    def _check_instance_has_no_numa(self):
+        """Prevent live migrations of instances with NUMA topologies."""
+        if not self.instance.numa_topology:
+            return
+
+        # Only KVM (libvirt) supports NUMA topologies with CPU pinning;
+        # HyperV's vNUMA feature doesn't allow specific pinning
+        hypervisor_type = objects.ComputeNode.get_by_host_and_nodename(
+            self.context, self.source, self.instance.node).hypervisor_type
+
+        # KVM is not a hypervisor, so when using a virt_type of "kvm" the
+        # hypervisor_type will still be "QEMU".
+        if hypervisor_type.lower() != obj_fields.HVType.QEMU:
+            return
+
+        msg = ('Instance has an associated NUMA topology. '
+               'Instance NUMA topologies, including related attributes '
+               'such as CPU pinning, huge page and emulator thread '
+               'pinning information, are not currently recalculated on '
+               'live migration. See bug #1289064 for more information.'
+               )
+
+        if CONF.workarounds.enable_numa_live_migration:
+            LOG.warning(msg, instance=self.instance)
+        else:
+            raise exception.MigrationPreCheckError(reason=msg)
+
     def _check_host_is_up(self, host):
         service = objects.Service.get_by_compute_host(self.context, host)
 
