@@ -32,12 +32,12 @@ from nova.conf import console
 from nova.conf import consoleauth
 from nova.conf import crypto
 from nova.conf import database
+from nova.conf import devices
 from nova.conf import ephemeral_storage
 from nova.conf import flavors
 from nova.conf import glance
 from nova.conf import guestfs
 from nova.conf import hyperv
-from nova.conf import ipv6
 from nova.conf import ironic
 from nova.conf import key_manager
 from nova.conf import keystone
@@ -85,13 +85,13 @@ console.register_opts(CONF)
 consoleauth.register_opts(CONF)
 crypto.register_opts(CONF)
 database.register_opts(CONF)
+devices.register_opts(CONF)
 ephemeral_storage.register_opts(CONF)
 flavors.register_opts(CONF)
 glance.register_opts(CONF)
 guestfs.register_opts(CONF)
 hyperv.register_opts(CONF)
 mks.register_opts(CONF)
-ipv6.register_opts(CONF)
 ironic.register_opts(CONF)
 key_manager.register_opts(CONF)
 keystone.register_opts(CONF)
