@@ -415,7 +415,9 @@ configuration value if no per-aggregate setting is found.
 
 NOTE: This can be set per-compute, or if set to 0.0, the value
 set on the scheduler node(s) or compute node(s) will be used
-and defaulted to 16.0.
+and defaulted to 16.0. Once set to a non-default value, it is not possible
+to "unset" the config to get back to the default behavior. If you want
+to reset back to the default, explicitly specify 16.0.
 
 NOTE: As of the 16.0.0 Pike release, this configuration option is ignored
 for the ironic.IronicDriver compute driver and is hardcoded to 1.0.
@@ -442,7 +444,9 @@ configuration value if no per-aggregate setting found.
 
 NOTE: This can be set per-compute, or if set to 0.0, the value
 set on the scheduler node(s) or compute node(s) will be used and
-defaulted to 1.5.
+defaulted to 1.5. Once set to a non-default value, it is not possible
+to "unset" the config to get back to the default behavior. If you want
+to reset back to the default, explicitly specify 1.5.
 
 NOTE: As of the 16.0.0 Pike release, this configuration option is ignored
 for the ironic.IronicDriver compute driver and is hardcoded to 1.0.
@@ -473,7 +477,9 @@ instances.
 
 NOTE: This can be set per-compute, or if set to 0.0, the value
 set on the scheduler node(s) or compute node(s) will be used and
-defaulted to 1.0.
+defaulted to 1.0. Once set to a non-default value, it is not possible
+to "unset" the config to get back to the default behavior. If you want
+to reset back to the default, explicitly specify 1.0.
 
 NOTE: As of the 16.0.0 Pike release, this configuration option is ignored
 for the ironic.IronicDriver compute driver and is hardcoded to 1.0.
