@@ -45,12 +45,22 @@ Possible values:
         default='%(client_ip)s "%(request_line)s" status: %(status_code)s'
                 ' len: %(body_length)s time: %(wall_seconds).7f',
         deprecated_group='DEFAULT',
+        deprecated_for_removal=True,
+        deprecated_since='16.0.0',
+        deprecated_reason="""
+This option only works when running nova-api under eventlet, and
+encodes very eventlet specific pieces of information. Starting in Pike
+the preferred model for running nova-api is under uwsgi or apache
+mod_wsgi.
+""",
         help="""
 It represents a python format string that is used as the template to generate
 log lines. The following values can be formatted into it: client_ip,
 date_time, request_line, status_code, body_length, wall_seconds.
 
-This option is used for building custom request loglines.
+This option is used for building custom request loglines when running
+nova-api under eventlet. If used under uwsgi or apache, this option
+has no effect.
 
 Possible values:
 
@@ -67,8 +77,22 @@ for the original request, even if it was removed by a SSL terminating proxy.
 
 Possible values:
 
-* None (default) - the request scheme is not influenced by any HTTP headers.
+* None (default) - the request scheme is not influenced by any HTTP headers
 * Valid HTTP header, like HTTP_X_FORWARDED_PROTO
+
+WARNING: Do not set this unless you know what you are doing.
+
+Make sure ALL of the following are true before setting this (assuming the
+values from the example above):
+* Your API is behind a proxy.
+* Your proxy strips the X-Forwarded-Proto header from all incoming requests.
+  In other words, if end users include that header in their requests, the proxy
+  will discard it.
+* Your proxy sets the X-Forwarded-Proto header and sends it to API, but only
+  for requests that originally come in via HTTPS.
+
+If any of those are not true, you should keep this setting set to None.
+
 """),
     cfg.StrOpt(
         'ssl_ca_file',
