@@ -15,23 +15,18 @@
 
 """Handles ConsoleProxy API requests."""
 
-from oslo_config import cfg
 
 from nova.compute import rpcapi as compute_rpcapi
+import nova.conf
 from nova.console import rpcapi as console_rpcapi
 from nova.db import base
 from nova import objects
 
-CONF = cfg.CONF
-CONF.import_opt('console_topic', 'nova.console.rpcapi')
+CONF = nova.conf.CONF
 
 
 class API(base.Base):
     """API for spinning up or down console proxy connections."""
-
-    def __init__(self, **kwargs):
-        super(API, self).__init__(**kwargs)
-
     def get_consoles(self, context, instance_uuid):
         return self.db.console_get_all_by_instance(context, instance_uuid,
                                                    columns_to_join=['pool'])
@@ -41,7 +36,7 @@ class API(base.Base):
 
     def delete_console(self, context, instance_uuid, console_uuid):
         console = self.db.console_get(context, console_uuid, instance_uuid)
-        rpcapi = console_rpcapi.ConsoleAPI(topic=CONF.console_topic,
+        rpcapi = console_rpcapi.ConsoleAPI(topic=console_rpcapi.RPC_TOPIC,
                                            server=console['pool']['host'])
         rpcapi.remove_console(context, console['id'])
 
