@@ -97,6 +97,7 @@ doubled_words_re = re.compile(
 log_remove_context = re.compile(
     r"(.)*LOG\.(.*)\(.*(context=[_a-zA-Z0-9].*)+.*\)")
 return_not_followed_by_space = re.compile(r"^\s*return(?:\(|{|\"|'|#).*$")
+uuid4_re = re.compile(r"uuid4\(\)($|[^\.]|\.hex)")
 
 
 class BaseASTChecker(ast.NodeVisitor):
@@ -603,7 +604,7 @@ def check_config_option_in_central_place(logical_line, filename):
     conf_exceptions = [
         # CLI opts are allowed to be outside of nova/conf directory
         'nova/cmd/manage.py',
-        'nova/cmd/policy_check.py',
+        'nova/cmd/policy.py',
         'nova/cmd/status.py',
         # config options should not be declared in tests, but there is
         # another checker for it (N320)
@@ -779,10 +780,7 @@ def check_uuid4(logical_line):
     msg = ("N357: Use oslo_utils.uuidutils or uuidsentinel(in case of test "
            "cases) to generate UUID instead of uuid4().")
 
-    if "uuid4()." in logical_line:
-        return
-
-    if "uuid4()" in logical_line:
+    if uuid4_re.search(logical_line):
         yield (0, msg)
 
 
