@@ -18,7 +18,6 @@ from oslo_log import log as logging
 from oslo_utils import importutils
 
 import nova.conf
-from nova.i18n import _LE, _LI
 
 
 CONF = nova.conf.CONF
@@ -30,9 +29,9 @@ def load_network_driver(network_driver=None):
         network_driver = CONF.network_driver
 
     if not network_driver:
-        LOG.error(_LE("Network driver option required, but not specified"))
+        LOG.error("Network driver option required, but not specified")
         sys.exit(1)
 
-    LOG.info(_LI("Loading network driver '%s'"), network_driver)
+    LOG.info("Loading network driver '%s'", network_driver)
 
     return importutils.import_module(network_driver)
