@@ -27,7 +27,6 @@ import nova.conf
 from nova import context
 from nova.db import base
 from nova import exception
-from nova.i18n import _LE, _LI, _LW
 from nova.network import rpcapi as network_rpcapi
 from nova import objects
 from nova import rpc
@@ -149,7 +148,7 @@ class FloatingIP(object):
                                                   address,
                                                   affect_auto_assigned=True)
                 except exception.FloatingIpNotAssociated:
-                    LOG.info(_LI("Floating IP %s is not associated. Ignore."),
+                    LOG.info("Floating IP %s is not associated. Ignore.",
                              address)
                 # deallocate if auto_assigned
                 if floating_ip.auto_assigned:
@@ -168,12 +167,12 @@ class FloatingIP(object):
 
         if floating_ip.project_id != context.project_id:
             if floating_ip.project_id is None:
-                LOG.warning(_LW('Address |%(address)s| is not allocated'),
+                LOG.warning('Address |%(address)s| is not allocated',
                             {'address': floating_ip.address})
                 raise exception.Forbidden()
             else:
-                LOG.warning(_LW('Address |%(address)s| is not allocated '
-                                'to your project |%(project)s|'),
+                LOG.warning('Address |%(address)s| is not allocated '
+                            'to your project |%(project)s|',
                             {'address': floating_ip.address,
                              'project': context.project_id})
                 raise exception.Forbidden()
@@ -206,8 +205,8 @@ class FloatingIP(object):
                 objects.Quotas.check_deltas(context, {'floating_ips': 1},
                                             project_id)
         except exception.OverQuota:
-            LOG.warning(_LW("Quota exceeded for %s, tried to allocate "
-                            "floating IP"), context.project_id)
+            LOG.warning("Quota exceeded for %s, tried to allocate "
+                        "floating IP", context.project_id)
             raise exception.FloatingIpLimitExceeded()
 
         floating_ip = objects.FloatingIP.allocate_address(
@@ -223,8 +222,8 @@ class FloatingIP(object):
                                             project_id)
             except exception.OverQuota:
                 objects.FloatingIP.deallocate(context, floating_ip.address)
-                LOG.warning(_LW("Quota exceeded for %s, tried to allocate "
-                                "floating IP"), context.project_id)
+                LOG.warning("Quota exceeded for %s, tried to allocate "
+                            "floating IP", context.project_id)
                 raise exception.FloatingIpLimitExceeded()
 
         payload = dict(project_id=project_id, floating_ip=floating_ip)
@@ -344,12 +343,12 @@ class FloatingIP(object):
                         objects.FloatingIP.disassociate(context,
                                                         floating_address)
                     except Exception:
-                        LOG.warning(_LW('Failed to disassociated floating '
-                                        'address: %s'), floating_address)
+                        LOG.warning('Failed to disassociated floating '
+                                    'address: %s', floating_address)
                         pass
                     if "Cannot find device" in six.text_type(e):
                         try:
-                            LOG.error(_LE('Interface %s not found'), interface)
+                            LOG.error('Interface %s not found', interface)
                         except Exception:
                             pass
                         raise exception.NoFloatingIpInterface(
@@ -503,15 +502,14 @@ class FloatingIP(object):
         if not floating_addresses or (source and source == dest):
             return
 
-        LOG.info(_LI("Starting migration network for instance %s"),
-                 instance_uuid)
+        LOG.info("Starting migration network for instance %s", instance_uuid)
         for address in floating_addresses:
             floating_ip = objects.FloatingIP.get_by_address(context, address)
 
             if self._is_stale_floating_ip_address(context, floating_ip):
-                LOG.warning(_LW("Floating IP address |%(address)s| no longer "
-                                "belongs to instance %(instance_uuid)s. "
-                                "Will not migrate it "),
+                LOG.warning("Floating IP address |%(address)s| no longer "
+                            "belongs to instance %(instance_uuid)s. "
+                            "Will not migrate it ",
                             {'address': address,
                              'instance_uuid': instance_uuid})
                 continue
@@ -539,16 +537,15 @@ class FloatingIP(object):
         if not floating_addresses or (source and source == dest):
             return
 
-        LOG.info(_LI("Finishing migration network for instance %s"),
-                 instance_uuid)
+        LOG.info("Finishing migration network for instance %s", instance_uuid)
 
         for address in floating_addresses:
             floating_ip = objects.FloatingIP.get_by_address(context, address)
 
             if self._is_stale_floating_ip_address(context, floating_ip):
-                LOG.warning(_LW("Floating IP address |%(address)s| no longer "
-                                "belongs to instance %(instance_uuid)s. "
-                                "Will not setup it."),
+                LOG.warning("Floating IP address |%(address)s| no longer "
+                            "belongs to instance %(instance_uuid)s. "
+                            "Will not setup it.",
                             {'address': address,
                              'instance_uuid': instance_uuid})
                 continue
@@ -589,10 +586,10 @@ class FloatingIP(object):
                 if domain_entry:
                     domains.append(domain_entry)
             else:
-                LOG.warning(_LW('Database inconsistency: DNS domain |%s| is '
-                                'registered in the Nova db but not visible to '
-                                'either the floating or instance DNS driver. '
-                                'It will be ignored.'), dns_domain.domain)
+                LOG.warning('Database inconsistency: DNS domain |%s| is '
+                            'registered in the Nova db but not visible to '
+                            'either the floating or instance DNS driver. '
+                            'It will be ignored.', dns_domain.domain)
 
         return domains
 
@@ -629,8 +626,8 @@ class FloatingIP(object):
         try:
             self.instance_dns_manager.create_domain(domain)
         except exception.FloatingIpDNSExists:
-            LOG.warning(_LW('Domain |%(domain)s| already exists, '
-                            'changing zone to |%(av_zone)s|.'),
+            LOG.warning('Domain |%(domain)s| already exists, '
+                        'changing zone to |%(av_zone)s|.',
                         {'domain': domain, 'av_zone': av_zone})
 
     def create_public_dns_domain(self, context, domain, project):
@@ -638,8 +635,8 @@ class FloatingIP(object):
         try:
             self.floating_dns_manager.create_domain(domain)
         except exception.FloatingIpDNSExists:
-            LOG.warning(_LW('Domain |%(domain)s| already exists, '
-                            'changing project to |%(project)s|.'),
+            LOG.warning('Domain |%(domain)s| already exists, '
+                        'changing project to |%(project)s|.',
                         {'domain': domain, 'project': project})
 
     def delete_dns_domain(self, context, domain):
