@@ -18,10 +18,8 @@ from nova.objects import base
 from nova.objects import fields
 
 
-# TODO(berrange): Remove NovaObjectDictCompat
 @base.NovaObjectRegistry.register
-class DNSDomain(base.NovaPersistentObject, base.NovaObject,
-                base.NovaObjectDictCompat):
+class DNSDomain(base.NovaPersistentObject, base.NovaObject):
     # Version 1.0: Initial version
     VERSION = '1.0'
 
@@ -35,7 +33,7 @@ class DNSDomain(base.NovaPersistentObject, base.NovaObject,
     @staticmethod
     def _from_db_object(context, vif, db_vif):
         for field in vif.fields:
-            vif[field] = db_vif[field]
+            setattr(vif, field, db_vif[field])
         vif._context = context
         vif.obj_reset_changes()
         return vif
@@ -66,9 +64,6 @@ class DNSDomainList(base.ObjectListBase, base.NovaObject):
     fields = {
         'objects': fields.ListOfObjectsField('DNSDomain'),
     }
-    obj_relationships = {
-        'objects': [('1.0', '1.0')],
-    }
 
     @base.remotable_classmethod
     def get_all(cls, context):
