@@ -24,6 +24,8 @@ EVENT_NAMES = [
     'network-vif-unplugged',
     'network-vif-deleted',
 
+    # Volume was extended for this instance, tag is volume_id
+    'volume-extended',
 ]
 
 EVENT_STATUSES = ['failed', 'completed', 'in-progress']
@@ -34,7 +36,8 @@ class InstanceExternalEvent(obj_base.NovaObject):
     # Version 1.0: Initial version
     #              Supports network-changed and vif-plugged
     # Version 1.1: adds network-vif-deleted event
-    VERSION = '1.1'
+    # Version 1.2: adds volume-extended event
+    VERSION = '1.2'
 
     fields = {
         'instance_uuid': fields.UUIDField(),
