@@ -136,7 +136,8 @@ class InstanceMapping(base.NovaTimestampObject, base.NovaObject):
 class InstanceMappingList(base.ObjectListBase, base.NovaObject):
     # Version 1.0: Initial version
     # Version 1.1: Added get_by_cell_id method.
-    VERSION = '1.1'
+    # Version 1.2: Added get_by_instance_uuids method
+    VERSION = '1.2'
 
     fields = {
         'objects': fields.ListOfObjectsField('InstanceMapping'),
@@ -169,3 +170,28 @@ class InstanceMappingList(base.ObjectListBase, base.NovaObject):
         db_mappings = cls._get_by_cell_id_from_db(context, cell_id)
         return base.obj_make_list(context, cls(), objects.InstanceMapping,
                 db_mappings)
+
+    @staticmethod
+    @db_api.api_context_manager.reader
+    def _get_by_instance_uuids_from_db(context, uuids):
+        return (context.session.query(api_models.InstanceMapping)
+                .options(joinedload('cell_mapping'))
+                .filter(api_models.InstanceMapping.instance_uuid.in_(uuids))
+                .all())
+
+    @base.remotable_classmethod
+    def get_by_instance_uuids(cls, context, uuids):
+        db_mappings = cls._get_by_instance_uuids_from_db(context, uuids)
+        return base.obj_make_list(context, cls(), objects.InstanceMapping,
+                db_mappings)
+
+    @staticmethod
+    @db_api.api_context_manager.writer
+    def _destroy_bulk_in_db(context, instance_uuids):
+        return context.session.query(api_models.InstanceMapping).filter(
+                api_models.InstanceMapping.instance_uuid.in_(instance_uuids)).\
+                delete(synchronize_session=False)
+
+    @classmethod
+    def destroy_bulk(cls, context, instance_uuids):
+        return cls._destroy_bulk_in_db(context, instance_uuids)
