@@ -13,9 +13,9 @@
 #    under the License.
 
 import netaddr
-from oslo_config import cfg
 from oslo_utils import versionutils
 
+import nova.conf
 from nova import db
 from nova import exception
 from nova.i18n import _
@@ -23,23 +23,7 @@ from nova import objects
 from nova.objects import base as obj_base
 from nova.objects import fields
 
-network_opts = [
-    cfg.BoolOpt('share_dhcp_address',
-                default=False,
-                help='DEPRECATED: THIS VALUE SHOULD BE SET WHEN CREATING THE '
-                     'NETWORK. If True in multi_host mode, all compute hosts '
-                     'share the same dhcp address. The same IP address used '
-                     'for DHCP will be added on each nova-network node which '
-                     'is only visible to the vms on the same host.'),
-    # NOTE(mriedem): Remove network_device_mtu in Newton.
-    cfg.IntOpt('network_device_mtu',
-               deprecated_for_removal=True,
-               help='DEPRECATED: THIS VALUE SHOULD BE SET WHEN CREATING THE '
-                    'NETWORK. MTU setting for network interface.'),
-]
-
-CONF = cfg.CONF
-CONF.register_opts(network_opts)
+CONF = nova.conf.CONF
 
 
 # TODO(berrange): Remove NovaObjectDictCompat
@@ -121,8 +105,6 @@ class Network(obj_base.NovaPersistentObject, obj_base.NovaObject,
             db_value = db_network[field]
             if field is 'netmask_v6' and db_value is not None:
                 db_value = network._convert_legacy_ipv6_netmask(db_value)
-            if field is 'mtu' and db_value is None:
-                db_value = CONF.network_device_mtu
             if field is 'dhcp_server' and db_value is None:
                 db_value = db_network['gateway']
             if field is 'share_address' and CONF.share_dhcp_address:
