@@ -205,6 +205,8 @@ class RequestSpec(base.NovaObject):
             policies = list(filter_properties.get('group_policies'))
             hosts = list(filter_properties.get('group_hosts'))
             members = list(filter_properties.get('group_members'))
+            # TODO(mriedem): We could try to get the group uuid from the
+            # group hint in the filter_properties.
             self.instance_group = objects.InstanceGroup(policies=policies,
                                                         hosts=hosts,
                                                         members=members)
@@ -450,11 +452,23 @@ class RequestSpec(base.NovaObject):
             # though they should match.
             if key in ['id', 'instance_uuid']:
                 setattr(spec, key, db_spec[key])
-            else:
+            elif key == 'ignore_hosts':
+                # NOTE(mriedem): Do not override the 'ignore_hosts'
+                # field which is not persisted. It is not a lazy-loadable
+                # field. If it is not set, set None.
+                if not spec.obj_attr_is_set(key):
+                    setattr(spec, key, None)
+            elif key in spec_obj:
                 setattr(spec, key, getattr(spec_obj, key))
         spec._context = context
 
         if 'instance_group' in spec and spec.instance_group:
+            # NOTE(mriedem): We could have a half-baked instance group with no
+            # uuid if some legacy translation was performed on this spec in the
+            # past. In that case, try to workaround the issue by getting the
+            # group uuid from the scheduler hint.
+            if 'uuid' not in spec.instance_group:
+                spec.instance_group.uuid = spec.get_scheduler_hint('group')
             # NOTE(danms): We don't store the full instance group in
             # the reqspec since it would be stale almost immediately.
             # Instead, load it by uuid here so it's up-to-date.
@@ -511,9 +525,9 @@ class RequestSpec(base.NovaObject):
             if 'instance_group' in spec and spec.instance_group:
                 spec.instance_group.members = None
                 spec.instance_group.hosts = None
-            # NOTE(mriedem): Don't persist retries or requested_destination
-            # since those are per-request
-            for excluded in ('retry', 'requested_destination'):
+            # NOTE(mriedem): Don't persist retries, requested_destination
+            # or ignored hosts since those are per-request
+            for excluded in ('retry', 'requested_destination', 'ignore_hosts'):
                 if excluded in spec and getattr(spec, excluded):
                     setattr(spec, excluded, None)
 
