@@ -257,7 +257,7 @@ class Service(base.NovaPersistentObject, base.NovaObject,
         service.obj_reset_changes()
 
         # TODO(dpeschman): Drop this once all services have uuids in database
-        if 'uuid' not in service:
+        if 'uuid' not in service and not service.deleted:
             service.uuid = uuidutils.generate_uuid()
             LOG.debug('Generated UUID %(uuid)s for service %(id)i',
                       dict(uuid=service.uuid, id=service.id))
