@@ -35,7 +35,15 @@ extended_availability_zone_policies = [
                 'method': 'GET',
                 'path': '/servers/detail'
             }
-        ]),
+        ],
+        deprecated_for_removal=True,
+        deprecated_reason=(
+            'Nova API extension concept has been removed in Pike. Those '
+            'extensions have their own policies enforcement. As there is '
+            'no extensions now, "os_compute_api:os-extended-availability-zone"'
+            ' policy which was added for extensions is not needed any more'
+        ),
+        deprecated_since='17.0.0'),
 ]
 
 
