@@ -72,11 +72,31 @@ flavor_extra_specs_policies = [
     policy.DocumentedRuleDefault(
         POLICY_ROOT % 'index',
         base.RULE_ADMIN_OR_OWNER,
-        "List extra specs for a flavor",
+        "List extra specs for a flavor. Starting with microversion 2.47, "
+        "the flavor used for a server is also returned in the response "
+        "when showing server details, updating a server or rebuilding a "
+        "server.",
         [
             {
                 'path': '/flavors/{flavor_id}/os-extra_specs/',
                 'method': 'GET'
+            },
+            # Microversion 2.47 operations for servers:
+            {
+                'path': '/servers/detail',
+                'method': 'GET'
+            },
+            {
+                'path': '/servers/{server_id}',
+                'method': 'GET'
+            },
+            {
+                'path': '/servers/{server_id}',
+                'method': 'PUT'
+            },
+            {
+                'path': '/servers/{server_id}/action (rebuild)',
+                'method': 'POST'
             }
         ]
     ),
