@@ -40,7 +40,19 @@ flavor_rxtx_policies = [
                 'method': 'POST',
                 'path': '/flavors'
             },
-        ]),
+            {
+                'method': 'PUT',
+                'path': '/flavors/{flavor_id}'
+            },
+        ],
+        deprecated_for_removal=True,
+        deprecated_reason=(
+            'Nova API extension concept has been removed in Pike. Those '
+            'extensions have their own policies enforcement. As there is '
+            'no extensions now, "os_compute_api:os-flavor-rxtx" policy '
+            'which was added for extensions is not needed any more'
+        ),
+        deprecated_since='17.0.0'),
 ]
 
 
