@@ -25,11 +25,12 @@ LOG = logging.getLogger(__name__)
 
 
 class DifferentHostFilter(filters.BaseHostFilter):
-    '''Schedule the instance on a different host from a set of instances.'''
-
+    """Schedule the instance on a different host from a set of instances."""
     # The hosts the instances are running on doesn't change within a request
     run_filter_once_per_request = True
 
+    RUN_ON_REBUILD = False
+
     def host_passes(self, host_state, spec_obj):
         affinity_uuids = spec_obj.get_scheduler_hint('different_host')
         if affinity_uuids:
@@ -40,13 +41,14 @@ class DifferentHostFilter(filters.BaseHostFilter):
 
 
 class SameHostFilter(filters.BaseHostFilter):
-    '''Schedule the instance on the same host as another instance in a set of
+    """Schedule the instance on the same host as another instance in a set of
     instances.
-    '''
-
+    """
     # The hosts the instances are running on doesn't change within a request
     run_filter_once_per_request = True
 
+    RUN_ON_REBUILD = False
+
     def host_passes(self, host_state, spec_obj):
         affinity_uuids = spec_obj.get_scheduler_hint('same_host')
         if affinity_uuids:
@@ -57,12 +59,12 @@ class SameHostFilter(filters.BaseHostFilter):
 
 
 class SimpleCIDRAffinityFilter(filters.BaseHostFilter):
-    '''Schedule the instance on a host with a particular cidr
-    '''
-
+    """Schedule the instance on a host with a particular cidr"""
     # The address of a host doesn't change within a request
     run_filter_once_per_request = True
 
+    RUN_ON_REBUILD = False
+
     def host_passes(self, host_state, spec_obj):
         affinity_cidr = spec_obj.get_scheduler_hint('cidr', '/24')
         affinity_host_addr = spec_obj.get_scheduler_hint('build_near_host_ip')
@@ -81,18 +83,26 @@ class _GroupAntiAffinityFilter(filters.BaseHostFilter):
     """Schedule the instance on a different host from a set of group
     hosts.
     """
+
+    RUN_ON_REBUILD = False
+
     def host_passes(self, host_state, spec_obj):
-        # Only invoke the filter is 'anti-affinity' is configured
+        # Only invoke the filter if 'anti-affinity' is configured
         policies = (spec_obj.instance_group.policies
                     if spec_obj.instance_group else [])
         if self.policy_name not in policies:
             return True
+        # NOTE(hanrong): Move operations like resize can check the same source
+        # compute node where the instance is. That case, AntiAffinityFilter
+        # must not return the source as a non-possible destination.
+        if spec_obj.instance_uuid in host_state.instances.keys():
+            return True
 
         group_hosts = (spec_obj.instance_group.hosts
                        if spec_obj.instance_group else [])
         LOG.debug("Group anti affinity: check if %(host)s not "
-                    "in %(configured)s", {'host': host_state.host,
-                                           'configured': group_hosts})
+                  "in %(configured)s", {'host': host_state.host,
+                                        'configured': group_hosts})
         if group_hosts:
             return host_state.host not in group_hosts
 
@@ -109,8 +119,11 @@ class ServerGroupAntiAffinityFilter(_GroupAntiAffinityFilter):
 class _GroupAffinityFilter(filters.BaseHostFilter):
     """Schedule the instance on to host from a set of group hosts.
     """
+
+    RUN_ON_REBUILD = False
+
     def host_passes(self, host_state, spec_obj):
-        # Only invoke the filter is 'affinity' is configured
+        # Only invoke the filter if 'affinity' is configured
         policies = (spec_obj.instance_group.policies
                     if spec_obj.instance_group else [])
         if self.policy_name not in policies:
@@ -119,8 +132,8 @@ class _GroupAffinityFilter(filters.BaseHostFilter):
         group_hosts = (spec_obj.instance_group.hosts
                        if spec_obj.instance_group else [])
         LOG.debug("Group affinity: check if %(host)s in "
-                    "%(configured)s", {'host': host_state.host,
-                                        'configured': group_hosts})
+                  "%(configured)s", {'host': host_state.host,
+                                     'configured': group_hosts})
         if group_hosts:
             return host_state.host in group_hosts
 
