@@ -127,6 +127,7 @@ class HostState(object):
         # Additional host information from the compute node stats:
         self.num_instances = 0
         self.num_io_ops = 0
+        self.failed_builds = 0
 
         # Other information
         self.host_ip = None
@@ -835,8 +836,8 @@ class HostManager(object):
                              "Re-created its InstanceList."), host_name)
                 return
             host_info["updated"] = True
-            LOG.info(_LI("Successfully synced instances from host '%s'."),
-                     host_name)
+            LOG.debug("Successfully synced instances from host '%s'.",
+                      host_name)
         else:
             self._recreate_instance_info(context, host_name)
             LOG.info(_LI("Received a sync request from an unknown host '%s'. "
