@@ -27,6 +27,7 @@ import warnings
 import fixtures
 from keystoneauth1 import session as ks
 import mock
+from neutronclient.common import exceptions as neutron_client_exc
 from oslo_concurrency import lockutils
 from oslo_config import cfg
 import oslo_messaging as messaging
@@ -1045,6 +1046,9 @@ class AllServicesCurrent(fixtures.Fixture):
         self.useFixture(fixtures.MonkeyPatch(
             'nova.objects.Service.get_minimum_version_multi',
             self._fake_minimum))
+        self.useFixture(fixtures.MonkeyPatch(
+            'nova.objects.service.get_minimum_version_all_cells',
+            lambda *a, **k: service_obj.SERVICE_VERSION))
         compute_rpcapi.LAST_VERSION = None
 
     def _fake_minimum(self, *args, **kwargs):
@@ -1250,6 +1254,12 @@ class NeutronFixture(fixtures.Fixture):
             if current_port['id'] == port:
                 self._ports.remove(current_port)
 
+    def show_network(self, network, **_params):
+        network = self._get_first_id_match(network, self._networks)
+        if network is None:
+            raise neutron_client_exc.NetworkNotFoundClient()
+        return {'network': network}
+
     def list_networks(self, retrieve_all=True, **_params):
         return copy.deepcopy({'networks': self._networks})
 
