@@ -62,7 +62,7 @@ class ApiSampleTestBaseV21(testscenarios.WithScenarios,
     # any additional fixtures needed for this scenario
     _additional_fixtures = []
     sample_dir = None
-    _project_id = True
+    _use_project_id = True
 
     scenarios = [
         # test v2 with the v2.1 compatibility stack
@@ -74,7 +74,7 @@ class ApiSampleTestBaseV21(testscenarios.WithScenarios,
         # test v2.18 code without project id
         ('v2_1_noproject_id', {
             'api_major_version': 'v2.1',
-            '_project_id': False,
+            '_use_project_id': False,
             '_additional_fixtures': [
                 api_paste_fixture.ApiPasteNoProjectId]})
     ]
@@ -112,7 +112,9 @@ class ApiSampleTestBaseV21(testscenarios.WithScenarios,
 
         super(ApiSampleTestBaseV21, self)._setup_services()
 
-        self.useFixture(test.SampleNetworks(host=self.network.host))
+        if not self.USE_NEUTRON:
+            # self.network is only setup if USE_NEUTRON=False
+            self.useFixture(test.SampleNetworks(host=self.network.host))
         fake_network.stub_compute_with_ips(self.stubs)
         self.useFixture(fixtures.SpawnIsSynchronousFixture())
         # this is used to generate sample docs
