@@ -13,17 +13,14 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-from oslo_config import cfg
-
+import nova.conf
 from nova.tests.functional.api_sample_tests import test_servers
 
-CONF = cfg.CONF
-CONF.import_opt('osapi_compute_extension',
-                'nova.api.openstack.compute.legacy_v2.extensions')
+CONF = nova.conf.CONF
 
 
 class AdminPasswordJsonTest(test_servers.ServersSampleBase):
-    extension_name = 'os-admin-password'
+    sample_dir = 'os-admin-password'
 
     def test_server_password(self):
         uuid = self._post_server()
@@ -32,4 +29,4 @@ class AdminPasswordJsonTest(test_servers.ServersSampleBase):
                                  'admin-password-change-password',
                                  subs)
         self.assertEqual(202, response.status_code)
-        self.assertEqual("", response.content)
+        self.assertEqual("", response.text)
