@@ -13,6 +13,7 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
+import mock
 from six.moves import range
 
 from nova.cells import state
@@ -22,27 +23,17 @@ from nova import exception
 from nova.tests.functional.api_sample_tests import api_sample_base
 
 CONF = nova.conf.CONF
-CONF.import_opt('osapi_compute_extension',
-                'nova.api.openstack.compute.legacy_v2.extensions')
 
 
 class CellsSampleJsonTest(api_sample_base.ApiSampleTestBaseV21):
-    extension_name = "os-cells"
-
-    def _get_flags(self):
-        f = super(CellsSampleJsonTest, self)._get_flags()
-        f['osapi_compute_extension'] = CONF.osapi_compute_extension[:]
-        f['osapi_compute_extension'].append(
-            'nova.api.openstack.compute.contrib.cells.Cells')
-        f['osapi_compute_extension'].append('nova.api.openstack.compute.'
-                      'contrib.cell_capacities.Cell_capacities')
-        return f
+    sample_dir = "os-cells"
 
     def setUp(self):
         # db_check_interval < 0 makes cells manager always hit the DB
         self.flags(enable=True, db_check_interval=-1, group='cells')
         super(CellsSampleJsonTest, self).setUp()
-        self.cells = self.start_service('cells', manager=CONF.cells.manager)
+        self.cells = self.start_service('cells',
+                                 manager='nova.cells.manager.CellsManager')
         self._stub_cells()
 
     def _stub_cells(self, num_cells=5):
@@ -101,8 +92,6 @@ class CellsSampleJsonTest(api_sample_base.ApiSampleTestBaseV21):
                                         {}, response, 200)
 
     def _mock_cell_capacity(self):
-        self.mox.StubOutWithMock(self.cells.manager.state_manager,
-                                 'get_our_capacities')
         response = {"ram_free":
                         {"units_by_mb": {"8192": 0, "512": 13,
                                          "4096": 1, "2048": 3, "16384": 0},
@@ -112,6 +101,6 @@ class CellsSampleJsonTest(api_sample_base.ApiSampleTestBaseV21):
                                          "40960": 23, "163840": 5, "0": 0},
                          "total_mb": 1052672}
         }
-        self.cells.manager.state_manager.get_our_capacities(). \
-            AndReturn(response)
-        self.mox.ReplayAll()
+        goc_mock = mock.Mock()
+        goc_mock.return_value = response
+        self.cells.manager.state_manager.get_our_capacities = goc_mock
