@@ -13,17 +13,12 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-import uuid
-
-from oslo_config import cfg
+from oslo_utils import uuidutils
 
 from nova.objects import keypair as keypair_obj
 from nova.tests.functional.api_sample_tests import api_sample_base
 from nova.tests.unit import fake_crypto
-
-CONF = cfg.CONF
-CONF.import_opt('osapi_compute_extension',
-                'nova.api.openstack.compute.legacy_v2.extensions')
+from nova.tests import uuidsentinel as uuids
 
 
 class KeyPairsSampleJsonTest(api_sample_base.ApiSampleTestBaseV21):
@@ -32,13 +27,6 @@ class KeyPairsSampleJsonTest(api_sample_base.ApiSampleTestBaseV21):
     expected_delete_status_code = 202
     expected_post_status_code = 200
 
-    def _get_flags(self):
-        f = super(KeyPairsSampleJsonTest, self)._get_flags()
-        f['osapi_compute_extension'] = CONF.osapi_compute_extension[:]
-        f['osapi_compute_extension'].append(
-            'nova.api.openstack.compute.contrib.keypairs.Keypairs')
-        return f
-
     def setUp(self):
         super(KeyPairsSampleJsonTest, self).setUp()
         self.api.microversion = self.microversion
@@ -54,7 +42,10 @@ class KeyPairsSampleJsonTest(api_sample_base.ApiSampleTestBaseV21):
 
     def _check_keypairs_post(self, **kwargs):
         """Get api sample of key pairs post request."""
-        key_name = 'keypair-' + str(uuid.uuid4())
+        key_name = kwargs.pop('kp_name', None)
+        if not key_name:
+            key_name = 'keypair-' + uuids.fake
+
         subs = dict(keypair_name=key_name, **kwargs)
         response = self._do_post('os-keypairs', 'keypairs-post-req', subs)
         subs = {'keypair_name': key_name}
@@ -72,7 +63,7 @@ class KeyPairsSampleJsonTest(api_sample_base.ApiSampleTestBaseV21):
 
     def _check_keypairs_import_key_post(self, public_key, **kwargs):
         # Get api sample of key pairs post to import user's key.
-        key_name = 'keypair-' + str(uuid.uuid4())
+        key_name = 'keypair-' + uuids.fake
         subs = {
             'keypair_name': key_name,
         }
@@ -126,7 +117,7 @@ class KeyPairsV22SampleJsonTest(KeyPairsSampleJsonTest):
             keypair_type=keypair_obj.KEYPAIR_TYPE_X509)
 
     def test_keypairs_post_invalid(self):
-        key_name = 'keypair-' + str(uuid.uuid4())
+        key_name = 'keypair-' + uuids.fake
         subs = dict(keypair_name=key_name, keypair_type='fakey_type')
         response = self._do_post('os-keypairs', 'keypairs-post-req', subs)
 
@@ -146,7 +137,7 @@ class KeyPairsV22SampleJsonTest(KeyPairsSampleJsonTest):
             public_key, keypair_type=keypair_obj.KEYPAIR_TYPE_X509)
 
     def _check_keypairs_import_key_post_invalid(self, keypair_type):
-        key_name = 'keypair-' + str(uuid.uuid4())
+        key_name = 'keypair-' + uuids.fake
         subs = {
             'keypair_name': key_name,
             'keypair_type': keypair_type,
@@ -206,6 +197,29 @@ class KeyPairsV210SampleJsonTest(KeyPairsSampleJsonTest):
         self.assertEqual(self.expected_delete_status_code,
                          response.status_code)
 
+    def test_keypairs_list_for_different_users(self):
+        # Get api sample of key pairs list request.
+
+        # create common kp_name for two users
+        kp_name = 'keypair-' + uuids.fake
+
+        keypair_user1 = self._check_keypairs_post(
+            keypair_type=keypair_obj.KEYPAIR_TYPE_SSH,
+            user_id="user1", kp_name=kp_name)
+        keypair_user2 = self._check_keypairs_post(
+            keypair_type=keypair_obj.KEYPAIR_TYPE_SSH,
+            user_id="user2", kp_name=kp_name)
+
+        # get all keypairs for user1 (only one)
+        response = self._do_get('os-keypairs?user_id=user1')
+        subs = {'keypair_name': keypair_user1}
+        self._verify_response('keypairs-list-resp', subs, response, 200)
+
+        # get all keypairs for user2 (only one)
+        response = self._do_get('os-keypairs?user_id=user2')
+        subs = {'keypair_name': keypair_user2}
+        self._verify_response('keypairs-list-resp', subs, response, 200)
+
 
 class KeyPairsV210SampleJsonTestNotAdmin(KeyPairsV210SampleJsonTest):
     ADMIN_API = False
@@ -216,10 +230,86 @@ class KeyPairsV210SampleJsonTestNotAdmin(KeyPairsV210SampleJsonTest):
             user_id="fake")
 
     def test_keypairs_post_for_other_user(self):
-        key_name = 'keypair-' + str(uuid.uuid4())
+        key_name = 'keypair-' + uuids.fake
         subs = dict(keypair_name=key_name,
                     keypair_type=keypair_obj.KEYPAIR_TYPE_SSH,
                     user_id='fake1')
         response = self._do_post('os-keypairs', 'keypairs-post-req', subs)
 
         self.assertEqual(403, response.status_code)
+
+    def test_keypairs_list_for_different_users(self):
+        # get and post for other users is forbidden for non admin
+        response = self._do_get('os-keypairs?user_id=fake1')
+        self.assertEqual(403, response.status_code)
+
+
+class KeyPairsV235SampleJsonTest(api_sample_base.ApiSampleTestBaseV21):
+    ADMIN_API = True
+    sample_dir = "keypairs"
+    microversion = '2.35'
+    expected_post_status_code = 201
+    scenarios = [('v2_35', {'api_major_version': 'v2.1'})]
+
+    def setUp(self):
+        super(KeyPairsV235SampleJsonTest, self).setUp()
+        self.api.microversion = self.microversion
+
+    # TODO(pkholkin): this is only needed because we randomly choose the
+    # uuid each time.
+    def generalize_subs(self, subs, vanilla_regexes):
+        subs['keypair_name'] = 'keypair-[0-9a-f-]+'
+        return subs
+
+    def test_keypairs_post(self, user="admin", kp_name=None):
+        return self._check_keypairs_post(
+            keypair_type=keypair_obj.KEYPAIR_TYPE_SSH,
+            user_id=user, kp_name=kp_name)
+
+    def _check_keypairs_post(self, **kwargs):
+        """Get api sample of key pairs post request."""
+        key_name = kwargs.pop('kp_name', None)
+        if not key_name:
+            key_name = 'keypair-' + uuidutils.generate_uuid()
+
+        subs = dict(keypair_name=key_name, **kwargs)
+        response = self._do_post('os-keypairs', 'keypairs-post-req', subs)
+        subs = {'keypair_name': key_name}
+
+        self._verify_response('keypairs-post-resp', subs, response,
+                              self.expected_post_status_code)
+        return key_name
+
+    def test_keypairs_list(self):
+        # Get api sample of key pairs list request.
+
+        # sort key_pairs by name before paging
+        keypairs = sorted([self.test_keypairs_post() for i in range(3)])
+
+        response = self._do_get('os-keypairs?marker=%s&limit=1' % keypairs[1])
+        subs = {'keypair_name': keypairs[2]}
+        self._verify_response('keypairs-list-resp', subs, response, 200)
+
+    def test_keypairs_list_for_different_users(self):
+        # Get api sample of key pairs list request.
+
+        # create common kp_names for two users
+        kp_names = ['keypair-' + uuidutils.generate_uuid() for i in range(3)]
+
+        # sort key_pairs by name before paging
+        keypairs_user1 = sorted([self.test_keypairs_post(
+            user="user1", kp_name=kp_name) for kp_name in kp_names])
+        keypairs_user2 = sorted([self.test_keypairs_post(
+            user="user2", kp_name=kp_name) for kp_name in kp_names])
+
+        # get all keypairs after the second for user1
+        response = self._do_get('os-keypairs?user_id=user1&marker=%s'
+                                % keypairs_user1[1])
+        subs = {'keypair_name': keypairs_user1[2]}
+        self._verify_response('keypairs-list-user1-resp', subs, response, 200)
+
+        # get only one keypair after the second for user2
+        response = self._do_get('os-keypairs?user_id=user2&marker=%s&limit=1'
+                                % keypairs_user2[1])
+        subs = {'keypair_name': keypairs_user2[2]}
+        self._verify_response('keypairs-list-user2-resp', subs, response, 200)
