@@ -18,6 +18,7 @@ import datetime
 from nova import context
 from nova import objects
 from nova.tests.functional.api_sample_tests import api_sample_base
+from nova.tests import uuidsentinel as uuids
 
 
 # NOTE(ShaoHe Feng) here I can not use uuidsentinel, it generate a random
@@ -44,7 +45,8 @@ def _stub_migrations(stub_self, context, filters):
             'created_at': datetime.datetime(2012, 10, 29, 13, 42, 2),
             'updated_at': datetime.datetime(2012, 10, 29, 13, 42, 2),
             'deleted_at': None,
-            'deleted': False
+            'deleted': False,
+            'uuid': uuids.migration1,
         },
         {
             'id': 5678,
@@ -62,7 +64,8 @@ def _stub_migrations(stub_self, context, filters):
             'created_at': datetime.datetime(2013, 10, 22, 13, 42, 2),
             'updated_at': datetime.datetime(2013, 10, 22, 13, 42, 2),
             'deleted_at': None,
-            'deleted': False
+            'deleted': False,
+            'uuid': uuids.migration2,
         }
     ]
     return fake_migrations
@@ -181,3 +184,110 @@ class MigrationsSamplesJsonTestV2_23(api_sample_base.ApiSampleTestBaseV21):
             'migrations-get',
             {"instance_1": INSTANCE_UUID_1, "instance_2": INSTANCE_UUID_2},
             response, 200)
+
+
+class MigrationsSamplesJsonTestV2_59(MigrationsSamplesJsonTestV2_23):
+    microversion = '2.59'
+    scenarios = [('v2_59', {'api_major_version': 'v2.1'})]
+    fake_migrations = [
+        # in-progress live-migration.
+        {
+            'source_node': 'node1',
+            'dest_node': 'node2',
+            'source_compute': 'compute1',
+            'dest_compute': 'compute2',
+            'dest_host': '1.2.3.4',
+            'status': 'running',
+            'instance_uuid': INSTANCE_UUID_1,
+            'old_instance_type_id': 1,
+            'new_instance_type_id': 1,
+            'migration_type': 'live-migration',
+            'hidden': False,
+            'created_at': datetime.datetime(2016, 0o1, 29, 11, 42, 2),
+            'updated_at': datetime.datetime(2016, 0o1, 29, 11, 42, 2),
+            'deleted_at': None,
+            'deleted': False,
+            'uuid': '12341d4b-346a-40d0-83c6-5f4f6892b650'
+        },
+        # non in-progress live-migration.
+        {
+            'source_node': 'node1',
+            'dest_node': 'node2',
+            'source_compute': 'compute1',
+            'dest_compute': 'compute2',
+            'dest_host': '1.2.3.4',
+            'status': 'error',
+            'instance_uuid': INSTANCE_UUID_1,
+            'old_instance_type_id': 1,
+            'new_instance_type_id': 1,
+            'migration_type': 'live-migration',
+            'hidden': False,
+            'created_at': datetime.datetime(2016, 0o1, 29, 12, 42, 2),
+            'updated_at': datetime.datetime(2016, 0o1, 29, 12, 42, 2),
+            'deleted_at': None,
+            'deleted': False,
+            'uuid': '22341d4b-346a-40d0-83c6-5f4f6892b650'
+        },
+        # non in-progress resize.
+        {
+            'source_node': 'node10',
+            'dest_node': 'node20',
+            'source_compute': 'compute10',
+            'dest_compute': 'compute20',
+            'dest_host': '5.6.7.8',
+            'status': 'error',
+            'instance_uuid': INSTANCE_UUID_2,
+            'old_instance_type_id': 5,
+            'new_instance_type_id': 6,
+            'migration_type': 'resize',
+            'hidden': False,
+            'created_at': datetime.datetime(2016, 0o6, 23, 13, 42, 2),
+            'updated_at': datetime.datetime(2016, 0o6, 23, 13, 42, 2),
+            'deleted_at': None,
+            'deleted': False,
+            'uuid': '32341d4b-346a-40d0-83c6-5f4f6892b650'
+        },
+        # in-progress resize.
+        {
+            'source_node': 'node10',
+            'dest_node': 'node20',
+            'source_compute': 'compute10',
+            'dest_compute': 'compute20',
+            'dest_host': '5.6.7.8',
+            'status': 'migrating',
+            'instance_uuid': INSTANCE_UUID_2,
+            'old_instance_type_id': 5,
+            'new_instance_type_id': 6,
+            'migration_type': 'resize',
+            'hidden': False,
+            'created_at': datetime.datetime(2016, 0o6, 23, 14, 42, 2),
+            'updated_at': datetime.datetime(2016, 0o6, 23, 14, 42, 2),
+            'deleted_at': None,
+            'deleted': False,
+            'uuid': '42341d4b-346a-40d0-83c6-5f4f6892b650'
+        }
+    ]
+
+    def test_get_migrations_with_limit(self):
+        response = self._do_get('os-migrations?limit=1')
+        self.assertEqual(200, response.status_code)
+        self._verify_response(
+            'migrations-get-with-limit',
+            {"instance_2": INSTANCE_UUID_2}, response, 200)
+
+    def test_get_migrations_with_marker(self):
+        response = self._do_get(
+            'os-migrations?marker=22341d4b-346a-40d0-83c6-5f4f6892b650')
+        self.assertEqual(200, response.status_code)
+        self._verify_response(
+            'migrations-get-with-marker',
+            {"instance_1": INSTANCE_UUID_1, "instance_2": INSTANCE_UUID_2},
+            response, 200)
+
+    def test_get_migrations_with_timestamp_filter(self):
+        response = self._do_get(
+            'os-migrations?changes-since=2016-06-23T13:42:01.000000')
+        self.assertEqual(200, response.status_code)
+        self._verify_response(
+            'migrations-get-with-timestamp-filter',
+            {"instance_2": INSTANCE_UUID_2}, response, 200)
