@@ -13,24 +13,11 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-from oslo_config import cfg
-
 from nova.tests.functional.api_sample_tests import api_sample_base
 
-CONF = cfg.CONF
-CONF.import_opt('osapi_compute_extension',
-                'nova.api.openstack.compute.legacy_v2.extensions')
-
 
 class ServerGroupsSampleJsonTest(api_sample_base.ApiSampleTestBaseV21):
-    extension_name = "os-server-groups"
-
-    def _get_flags(self):
-        f = super(ServerGroupsSampleJsonTest, self)._get_flags()
-        f['osapi_compute_extension'] = CONF.osapi_compute_extension[:]
-        f['osapi_compute_extension'].append(
-            'nova.api.openstack.compute.contrib.server_groups.Server_groups')
-        return f
+    sample_dir = "os-server-groups"
 
     def _get_create_subs(self):
         return {'name': 'test'}
@@ -47,11 +34,6 @@ class ServerGroupsSampleJsonTest(api_sample_base.ApiSampleTestBaseV21):
         return self._verify_response('server-groups-post-resp',
                                      subs, response, 200)
 
-    def _create_server_group(self):
-        subs = self._get_create_subs()
-        return self._do_post('os-server-groups',
-                             'server-groups-post-req', subs)
-
     def test_server_groups_post(self):
         return self._post_server_group()
 
