@@ -79,6 +79,9 @@ class SimpleTenantUsageV240Test(test_servers.ServersSampleBase):
         super(SimpleTenantUsageV240Test, self).setUp()
         self.api.microversion = self.microversion
 
+        self.project_id_0 = astb.PROJECT_ID
+        self.project_id_1 = '0000000e737461636b20342065000000'
+
         started = timeutils.utcnow()
         now = started + datetime.timedelta(hours=1)
 
@@ -87,8 +90,11 @@ class SimpleTenantUsageV240Test(test_servers.ServersSampleBase):
             # make uuids incrementing, so that sort order is deterministic
             uuid_format = '1f1deceb-17b5-4c04-84c7-e0d4499c8f%02d'
             mock_uuids.side_effect = [uuid_format % x for x in range(100)]
+            self.project_id = self.project_id_0
             self.instance1_uuid = self._post_server(name='instance-1')
             self.instance2_uuid = self._post_server(name='instance-2')
+
+            self.project_id = self.project_id_1
             self.instance3_uuid = self._post_server(name='instance-3')
         timeutils.set_time_override(now)
 
@@ -118,9 +124,27 @@ class SimpleTenantUsageV240Test(test_servers.ServersSampleBase):
         self._verify_response(template_name, {}, response, 200)
 
     def test_get_tenant_usage_details(self):
-        tenant_id = astb.PROJECT_ID
+        tenant_id = self.project_id_0
         url = 'os-simple-tenant-usage/{tenant}?%s'.format(tenant=tenant_id)
         response = self._do_get(url % (parse.urlencode(self.query)))
         template_name = 'simple-tenant-usage-get-specific'
-        subs = {'tenant_id': self.api.project_id}
+        subs = {'tenant_id': self.project_id_0}
         self._verify_response(template_name, subs, response, 200)
+
+    def test_get_tenants_usage_end_marker(self):
+        # When using the last server retrieved as a marker,
+        # the subsequent usages list should be empty (bug #1796689).
+        url = 'os-simple-tenant-usage?%s'
+        query = dict(detailed=1,
+                     start=self.query['start'],
+                     end=self.query['end'])
+
+        response = self._do_get(url % (parse.urlencode(query)))
+        template_name = 'simple-tenant-usage-get-all'
+        self._verify_response(template_name, {}, response, 200)
+
+        last_server = response.json()['tenant_usages'][-1]['server_usages'][-1]
+        query['marker'] = last_server['instance_id']
+
+        response = self._do_get(url % (parse.urlencode(query)))
+        self.assertEqual(0, len(response.json()['tenant_usages']))
