@@ -303,6 +303,24 @@ class ApiSampleTestBase(integrated_helpers._IntegratedTestBase):
 
         return matched_value
 
+    @property
+    def project_id(self):
+        # We'll allow test cases to override the default project id. This is
+        # useful when using multiple tenants.
+        project_id = None
+        try:
+            project_id = self.api.project_id
+        except AttributeError:
+            pass
+
+        return project_id or PROJECT_ID
+
+    @project_id.setter
+    def project_id(self, project_id):
+        self.api.project_id = project_id
+        # Reset cached credentials
+        self.api.auth_result = None
+
     def generalize_subs(self, subs, vanilla_regexes):
         """Give the test a chance to modify subs after the server response
         was verified, and before the on-disk doc/api_samples file is checked.
@@ -317,17 +335,20 @@ class ApiSampleTestBase(integrated_helpers._IntegratedTestBase):
     def _update_links(self, sample_data):
         """Process sample data and update version specific links."""
         # replace version urls
-        url_re = self._get_host() + "/v(2|2\.1)/" + PROJECT_ID
+
+        project_id_exp = '(%s|%s)' % (PROJECT_ID, self.project_id)
+
+        url_re = self._get_host() + "/v(2|2\.1)/" + project_id_exp
         new_url = self._get_host() + "/" + self.api_major_version
-        if self._project_id:
-            new_url += "/" + PROJECT_ID
+        if self._use_project_id:
+            new_url += "/" + self.project_id
         updated_data = re.sub(url_re, new_url, sample_data)
 
         # replace unversioned urls
-        url_re = self._get_host() + "/" + PROJECT_ID
+        url_re = self._get_host() + "/" + project_id_exp
         new_url = self._get_host()
-        if self._project_id:
-            new_url += "/" + PROJECT_ID
+        if self._use_project_id:
+            new_url += "/" + self.project_id
         updated_data = re.sub(url_re, new_url, updated_data)
         return updated_data
 
@@ -461,17 +482,17 @@ class ApiSampleTestBase(integrated_helpers._IntegratedTestBase):
     def _get_compute_endpoint(self):
         # NOTE(sdague): "openstack" is stand in for project_id, it
         # should be more generic in future.
-        if self._project_id:
-            return '%s/%s' % (self._get_host(), PROJECT_ID)
+        if self._use_project_id:
+            return '%s/%s' % (self._get_host(), self.project_id)
         else:
             return self._get_host()
 
     def _get_vers_compute_endpoint(self):
         # NOTE(sdague): "openstack" is stand in for project_id, it
         # should be more generic in future.
-        if self._project_id:
+        if self._use_project_id:
             return '%s/%s/%s' % (self._get_host(), self.api_major_version,
-                                 PROJECT_ID)
+                                 self.project_id)
         else:
             return '%s/%s' % (self._get_host(), self.api_major_version)
 
