@@ -12,6 +12,9 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
+import mock
+
+from nova.compute import api as compute_api
 from nova import exception
 from nova.tests import fixtures as nova_fixtures
 from nova.tests.functional import integrated_helpers
@@ -54,7 +57,13 @@ class LiveMigrationCinderFailure(integrated_helpers._IntegratedTestBase,
         self.addCleanup(fake.restore_nodes)
         self.compute2 = self.start_service('compute', host='host2')
 
-    def test_live_migrate_terminate_connection_fails(self):
+    # To get the old Cinder flow we need to hack the service version, otherwise
+    # the new flow is attempted and CinderFixture complains about auth because
+    # it's not stubbing out the new flow methods.
+    @mock.patch(
+        'nova.objects.service.get_minimum_version_all_cells',
+        return_value=compute_api.CINDER_V3_ATTACH_MIN_COMPUTE_VERSION - 1)
+    def test_live_migrate_terminate_connection_fails(self, _):
         self.useFixture(nova_fixtures.CinderFixture(self))
         server = self.api.post_server({
             'server': {
@@ -96,3 +105,44 @@ class LiveMigrationCinderFailure(integrated_helpers._IntegratedTestBase,
                                          'status': 'ACTIVE'})
         self.assertEqual(2, stub_terminate_connection.call_count)
         self.assertEqual(1, stub_terminate_connection.raise_count)
+
+    def test_live_migrate_attachment_delete_fails(self):
+        self.useFixture(nova_fixtures.CinderFixtureNewAttachFlow(self))
+        server = self.api.post_server({
+            'server': {
+                'flavorRef': 1,
+                'imageRef': '155d900f-4e14-4e4c-a73d-069cbf4541e6',
+                'name': 'live-migrate-attachment-delete-fail-test',
+                'networks': 'none',
+                'block_device_mapping_v2': [
+                    {'boot_index': 0,
+                     'uuid': uuids.broken_volume,
+                     'source_type': 'volume',
+                     'destination_type': 'volume'},
+                    {'boot_index': 1,
+                     'uuid': uuids.working_volume,
+                     'source_type': 'volume',
+                     'destination_type': 'volume'}]}})
+        server = self._wait_for_state_change(self.api, server, 'ACTIVE')
+
+        source = server['OS-EXT-SRV-ATTR:host']
+        if source == self.compute.host:
+            dest = self.compute2.host
+        else:
+            dest = self.compute.host
+
+        post = {
+            'os-migrateLive': {
+                'host': dest,
+                'block_migration': False,
+            }
+        }
+        stub_attachment_delete = FakeCinderError()
+        self.stub_out('nova.volume.cinder.API.attachment_delete',
+                      stub_attachment_delete)
+        self.api.post_server_action(server['id'], post)
+        self._wait_for_server_parameter(self.api, server,
+                                        {'OS-EXT-SRV-ATTR:host': dest,
+                                         'status': 'ACTIVE'})
+        self.assertEqual(2, stub_attachment_delete.call_count)
+        self.assertEqual(1, stub_attachment_delete.raise_count)
