@@ -16,7 +16,6 @@ from nova.db.sqlalchemy import api as db_api
 from nova.db.sqlalchemy import api_models
 from nova import exception
 from nova import objects
-from nova.objects import flavor as flavor_obj
 from nova import test
 from nova.tests import fixtures
 
@@ -36,19 +35,10 @@ fake_api_flavor = {
     'is_public': True,
     'extra_specs': {'foo': 'bar'},
     'projects': ['project1', 'project2'],
+    'description': None
     }
 
 
-class ForcedFlavor(objects.Flavor):
-    """A Flavor object that lets us create with things still in the main DB.
-
-    This is required for us to be able to test mixed scenarios.
-    """
-    @staticmethod
-    def _ensure_migrated(*args):
-        return True
-
-
 class FlavorObjectTestCase(test.NoDBTestCase):
     USES_DB_SELF = True
 
@@ -113,11 +103,6 @@ class FlavorObjectTestCase(test.NoDBTestCase):
         flavor.create()
         self._test_query(flavor)
 
-    def test_query_main(self):
-        self._create_main_flavor()
-        flavor = objects.Flavor.get_by_flavor_id(self.context, 'mainflavor')
-        self._test_query(flavor)
-
     def test_save(self):
         flavor = objects.Flavor(context=self.context, **fake_api_flavor)
         flavor.create()
@@ -169,18 +154,6 @@ class FlavorObjectTestCase(test.NoDBTestCase):
         self.assertEqual(
             0, self._collect_flavor_residue_api(self.context, flavor))
 
-    def _create_main_flavor(self, **updates):
-        values = dict(fake_api_flavor, flavorid='mainflavor')
-        del values['projects']
-        del values['extra_specs']
-        values.update(updates)
-        return db_api.flavor_create(self.context, values)
-
-    def test_destroy_main(self):
-        self._create_main_flavor()
-        flavor = objects.Flavor.get_by_flavor_id(self.context, 'mainflavor')
-        self._test_destroy(flavor)
-
     def test_destroy_missing_flavor_by_flavorid(self):
         flavor = objects.Flavor(context=self.context, flavorid='foo')
         self.assertRaises(exception.FlavorNotFound,
@@ -203,84 +176,31 @@ class FlavorObjectTestCase(test.NoDBTestCase):
 
     def test_get_all_with_some_api_flavors(self):
         expect_len = len(db_api.flavor_get_all(self.context))
-        flavor = ForcedFlavor(context=self.context, **fake_api_flavor)
+        flavor = objects.Flavor(context=self.context, **fake_api_flavor)
         flavor.create()
         self._test_get_all(expect_len + 1)
 
     def test_get_all_with_all_api_flavors(self):
         self._delete_main_flavors()
-        flavor = ForcedFlavor(context=self.context, **fake_api_flavor)
+        flavor = objects.Flavor(context=self.context, **fake_api_flavor)
         flavor.create()
         self._test_get_all(1)
 
     def test_get_all_with_marker_in_api(self):
-        db_flavors = [self._create_main_flavor(),
-                      self._create_main_flavor(flavorid='mainflavor2',
-                                               name='m1.foo2')]
-        db_flavor_ids = [x['flavorid'] for x in db_flavors]
-        flavor = ForcedFlavor(context=self.context, **fake_api_flavor)
+        flavor = objects.Flavor(context=self.context, **fake_api_flavor)
         flavor.create()
         fake_flavor2 = dict(fake_api_flavor, name='m1.zoo', flavorid='m1.zoo')
-        flavor = ForcedFlavor(context=self.context, **fake_flavor2)
+        flavor = objects.Flavor(context=self.context, **fake_flavor2)
         flavor.create()
-        result = self._test_get_all(3, marker='m1.foo', limit=3)
+        result = self._test_get_all(1, marker='m1.foo', limit=1)
         result_flavorids = [x.flavorid for x in result]
-        self.assertEqual(['m1.zoo'] + db_flavor_ids[:2], result_flavorids)
+        self.assertEqual(['m1.zoo'], result_flavorids)
 
-    def test_get_all_with_marker_in_main(self):
-        db_flavors = [self._create_main_flavor(flavorid='mainflavor1',
-                                               name='main1'),
-                      self._create_main_flavor(flavorid='mainflavor2',
-                                               name='main2')]
-        db_flavor_ids = [x['flavorid'] for x in db_flavors]
-        flavor = ForcedFlavor(context=self.context, **fake_api_flavor)
+    def test_get_all_with_marker_not_found(self):
+        flavor = objects.Flavor(context=self.context, **fake_api_flavor)
         flavor.create()
         fake_flavor2 = dict(fake_api_flavor, name='m1.zoo', flavorid='m1.zoo')
-        flavor = ForcedFlavor(context=self.context, **fake_flavor2)
-        flavor.create()
-        result = self._test_get_all(1, marker='mainflavor1', limit=3)
-        result_flavorids = [x.flavorid for x in result]
-        self.assertEqual(db_flavor_ids[1:], result_flavorids)
-
-    def test_get_all_with_marker_in_neither(self):
-        flavor = ForcedFlavor(context=self.context, **fake_api_flavor)
-        flavor.create()
-        fake_flavor2 = dict(fake_api_flavor, name='m1.zoo', flavorid='m1.zoo')
-        flavor = ForcedFlavor(context=self.context, **fake_flavor2)
+        flavor = objects.Flavor(context=self.context, **fake_flavor2)
         flavor.create()
         self.assertRaises(exception.MarkerNotFound,
                           self._test_get_all, 2, marker='noflavoratall')
-
-    def test_create_checks_main_flavors(self):
-        self._create_main_flavor()
-        flavor = objects.Flavor(context=self.context, **fake_api_flavor)
-        self.assertRaises(exception.ObjectActionError, flavor.create)
-        self._delete_main_flavors()
-        flavor.create()
-
-
-class FlavorMigrationTestCase(test.NoDBTestCase):
-    USES_DB_SELF = True
-
-    def setUp(self):
-        super(FlavorMigrationTestCase, self).setUp()
-        self.useFixture(fixtures.Database())
-        self.useFixture(fixtures.Database(database='api'))
-        self.context = context.get_admin_context()
-
-    def test_migration(self):
-        main_flavors = len(db.flavor_get_all(self.context))
-        match, done = flavor_obj.migrate_flavors(self.context, 50)
-        self.assertEqual(main_flavors, match)
-        self.assertEqual(main_flavors, done)
-        self.assertEqual(0, len(db.flavor_get_all(self.context)))
-        self.assertEqual(main_flavors,
-                         len(objects.FlavorList.get_all(self.context)))
-
-    def test_migrate_flavor_reset_autoincrement(self):
-        # NOTE(danms): Not much we can do here other than just make
-        # sure that the non-postgres case does not explode.
-        match, done = flavor_obj.migrate_flavor_reset_autoincrement(
-            self.context, 0)
-        self.assertEqual(0, match)
-        self.assertEqual(0, done)
