@@ -60,15 +60,6 @@ class TestRescheduleWithServerGroup(test.TestCase,
         self.addCleanup(nova.tests.unit.image.fake.FakeImageService_reset)
 
         self.start_service('conductor')
-        self.flags(enabled_filters=[
-            "RetryFilter",
-            "AvailabilityZoneFilter",
-            "ComputeFilter",
-            "ComputeCapabilitiesFilter",
-            "ImagePropertiesFilter",
-            "ServerGroupAntiAffinityFilter",
-            "ServerGroupAffinityFilter"],
-            group='filter_scheduler')
         self.start_service('scheduler')
 
         # We start two compute services because we're going to fake one raising
