@@ -34,7 +34,7 @@ class RebuildVolumeBackedSameImage(integrated_helpers._IntegratedTestBase,
     def setUp(self):
         super(RebuildVolumeBackedSameImage, self).setUp()
         # We are creating a volume-backed server so we need the CinderFixture.
-        self.useFixture(nova_fixtures.CinderFixture(self))
+        self.useFixture(nova_fixtures.CinderFixtureNewAttachFlow(self))
 
     def _setup_scheduler_service(self):
         # Add the IsolatedHostsFilter to the list of enabled filters since it
@@ -83,6 +83,6 @@ class RebuildVolumeBackedSameImage(integrated_helpers._IntegratedTestBase,
         }
         server = self.api.api_post('/servers/%s/action' % server['id'],
                                    rebuild_req_body).body['server']
-        # FIXME(mriedem): Once bug 1482040 is fixed, the server image ref
-        # should still be blank for a volume-backed server after the rebuild.
-        self.assertNotEqual('', server['image'])
+        # The server image ref should still be blank for a volume-backed server
+        # after the rebuild.
+        self.assertEqual('', server['image'])
