@@ -36,7 +36,7 @@ class SecgroupsFullstack(testscenarios.WithScenarios, test.TestCase):
     _flavor_ref_parameter = 'flavorRef'
 
     # This test uses ``testscenarios`` which matrix multiplies the
-    # test across the scenarios listed below setting the attributres
+    # test across the scenarios listed below setting the attributes
     # in the dictionary on ``self`` for each scenario.
     scenarios = [
         ('v2', {
@@ -62,7 +62,7 @@ class SecgroupsFullstack(testscenarios.WithScenarios, test.TestCase):
         server = {}
 
         image = self.api.get_images()[0]
-        LOG.info("Image: %s" % image)
+        LOG.info("Image: %s", image)
 
         if self._image_ref_parameter in image:
             image_href = image[self._image_ref_parameter]
