@@ -22,7 +22,6 @@ import six
 from nova.api.openstack import compute
 from nova.compute import api as compute_api
 from nova.compute import flavors
-from nova import objects
 from nova import test
 from nova.tests.unit.api.openstack import fakes
 from nova.tests.unit import fake_instance
@@ -82,13 +81,13 @@ class DiskConfigTestCaseV21(test.TestCase):
         self.stub_out('nova.db.instance_get_all_by_filters',
                       fake_instance_get_all)
 
-        self.stubs.Set(objects.Instance, 'save',
-                       lambda *args, **kwargs: None)
+        self.stub_out('nova.objects.Instance.save',
+                      lambda *args, **kwargs: None)
 
         def fake_rebuild(*args, **kwargs):
             pass
 
-        self.stubs.Set(compute_api.API, 'rebuild', fake_rebuild)
+        self.stub_out('nova.compute.api.API.rebuild', fake_rebuild)
 
         def fake_instance_create(context, inst_, session=None):
             inst = fake_instance.fake_db_instance(**{
@@ -415,7 +414,7 @@ class DiskConfigTestCaseV21(test.TestCase):
             self.assertTrue(kwargs['auto_disk_config'])
             return old_create(*args, **kwargs)
 
-        self.stubs.Set(compute_api.API, 'create', create)
+        self.stub_out('nova.compute.api.API.create', create)
 
         req.body = jsonutils.dump_as_bytes(body)
         res = req.get_response(self.app)
@@ -443,7 +442,7 @@ class DiskConfigTestCaseV21(test.TestCase):
             self.assertIn('auto_disk_config', kwargs)
             self.assertTrue(kwargs['auto_disk_config'])
 
-        self.stubs.Set(compute_api.API, 'rebuild', rebuild)
+        self.stub_out('nova.compute.api.API.rebuild', rebuild)
 
         req.body = jsonutils.dump_as_bytes(body)
         res = req.get_response(self.app)
@@ -464,7 +463,7 @@ class DiskConfigTestCaseV21(test.TestCase):
             self.assertIn('auto_disk_config', kwargs)
             self.assertTrue(kwargs['auto_disk_config'])
 
-        self.stubs.Set(compute_api.API, 'resize', resize)
+        self.stub_out('nova.compute.api.API.resize', resize)
 
         req.body = jsonutils.dump_as_bytes(body)
         req.get_response(self.app)
