@@ -16,7 +16,6 @@
 import mock
 from oslo_config import cfg
 from oslo_serialization import jsonutils
-import webob
 
 from nova.api.openstack import wsgi as os_wsgi
 from nova import compute
@@ -83,18 +82,18 @@ class ExtendedServerAttributesTestV21(test.TestCase):
     def setUp(self):
         super(ExtendedServerAttributesTestV21, self).setUp()
         fakes.stub_out_nw_api(self)
-        self.stubs.Set(compute.api.API, 'get', fake_compute_get)
-        self.stubs.Set(compute.api.API, 'get_all', fake_compute_get_all)
+        fakes.stub_out_secgroup_api(self)
+        self.stub_out('nova.compute.api.API.get', fake_compute_get)
+        self.stub_out('nova.compute.api.API.get_all', fake_compute_get_all)
         self.stub_out('nova.db.instance_get_by_uuid', fake_compute_get)
 
     def _make_request(self, url):
         req = fakes.HTTPRequest.blank(url)
         req.headers['Accept'] = self.content_type
         req.headers = {os_wsgi.API_VERSION_REQUEST_HEADER:
-                       self.wsgi_api_version}
+                       'compute %s' % self.wsgi_api_version}
         res = req.get_response(
-            fakes.wsgi_app_v21(init_only=('servers',
-                                          'os-extended-server-attributes')))
+            fakes.wsgi_app_v21())
         return res
 
     def _get_server(self, body):
@@ -147,29 +146,13 @@ class ExtendedServerAttributesTestV21(test.TestCase):
         def fake_compute_get(*args, **kwargs):
             raise exception.InstanceNotFound(instance_id='fake')
 
-        self.stubs.Set(compute.api.API, 'get', fake_compute_get)
+        self.stub_out('nova.compute.api.API.get', fake_compute_get)
         url = self.fake_url + '/servers/70f6db34-de8d-4fbd-aafb-4065bdfa6115'
         res = self._make_request(url)
 
         self.assertEqual(res.status_int, 404)
 
 
-class ExtendedServerAttributesTestV2(ExtendedServerAttributesTestV21):
-
-    def setUp(self):
-        super(ExtendedServerAttributesTestV2, self).setUp()
-        self.flags(
-            osapi_compute_extension=[
-                'nova.api.openstack.compute.contrib.select_extensions'],
-            osapi_compute_ext_list=['Extended_server_attributes'])
-
-    def _make_request(self, url):
-        req = webob.Request.blank(url)
-        req.headers['Accept'] = self.content_type
-        res = req.get_response(fakes.wsgi_app(init_only=('servers',)))
-        return res
-
-
 class ExtendedServerAttributesTestV23(ExtendedServerAttributesTestV21):
     wsgi_api_version = '2.3'
 
