@@ -14,9 +14,7 @@
 #    under the License.
 
 from oslo_serialization import jsonutils
-import webob
 
-from nova import compute
 from nova import exception
 from nova import objects
 from nova.objects import instance as instance_obj
@@ -58,18 +56,17 @@ class ExtendedStatusTestV21(test.TestCase):
         pass
 
     def _make_request(self, url):
-        req = webob.Request.blank(url)
+        req = fakes.HTTPRequest.blank(url)
         req.headers['Accept'] = self.content_type
-        res = req.get_response(fakes.wsgi_app_v21(
-            init_only=('servers',
-                       'os-extended-status')))
+        res = req.get_response(fakes.wsgi_app_v21())
         return res
 
     def setUp(self):
         super(ExtendedStatusTestV21, self).setUp()
         fakes.stub_out_nw_api(self)
-        self.stubs.Set(compute.api.API, 'get', fake_compute_get)
-        self.stubs.Set(compute.api.API, 'get_all', fake_compute_get_all)
+        fakes.stub_out_secgroup_api(self)
+        self.stub_out('nova.compute.api.API.get', fake_compute_get)
+        self.stub_out('nova.compute.api.API.get_all', fake_compute_get_all)
         self._set_flags()
         return_server = fakes.fake_instance_get()
         self.stub_out('nova.db.instance_get_by_uuid', return_server)
@@ -112,23 +109,8 @@ class ExtendedStatusTestV21(test.TestCase):
         def fake_compute_get(*args, **kwargs):
             raise exception.InstanceNotFound(instance_id='fake')
 
-        self.stubs.Set(compute.api.API, 'get', fake_compute_get)
+        self.stub_out('nova.compute.api.API.get', fake_compute_get)
         url = self.fake_url + '/servers/70f6db34-de8d-4fbd-aafb-4065bdfa6115'
         res = self._make_request(url)
 
         self.assertEqual(res.status_int, 404)
-
-
-class ExtendedStatusTestV2(ExtendedStatusTestV21):
-
-    def _set_flags(self):
-        self.flags(
-            osapi_compute_extension=[
-                'nova.api.openstack.compute.contrib.select_extensions'],
-            osapi_compute_ext_list=['Extended_status'])
-
-    def _make_request(self, url):
-        req = webob.Request.blank(url)
-        req.headers['Accept'] = self.content_type
-        res = req.get_response(fakes.wsgi_app(init_only=('servers',)))
-        return res
