@@ -16,8 +16,6 @@
 import mock
 import webob
 
-from nova.api.openstack.compute.legacy_v2.contrib import multinic \
-        as multinic_v2
 from nova.api.openstack.compute import multinic as multinic_v21
 from nova import compute
 from nova import exception
@@ -43,8 +41,7 @@ def compute_api_remove_fixed_ip(self, context, instance, address):
     last_remove_fixed_ip = (instance['uuid'], address)
 
 
-def compute_api_get(self, context, instance_id, want_objects=False,
-                    expected_attrs=None):
+def compute_api_get(self, context, instance_id, expected_attrs=None):
     instance = objects.Instance()
     instance.uuid = instance_id
     instance.id = 1
@@ -61,12 +58,11 @@ class FixedIpTestV21(test.NoDBTestCase):
     def setUp(self):
         super(FixedIpTestV21, self).setUp()
         fakes.stub_out_networking(self)
-        fakes.stub_out_rate_limiting(self.stubs)
-        self.stubs.Set(compute.api.API, "add_fixed_ip",
-                       compute_api_add_fixed_ip)
-        self.stubs.Set(compute.api.API, "remove_fixed_ip",
-                       compute_api_remove_fixed_ip)
-        self.stubs.Set(compute.api.API, 'get', compute_api_get)
+        self.stub_out('nova.compute.api.API.add_fixed_ip',
+                      compute_api_add_fixed_ip)
+        self.stub_out('nova.compute.api.API.remove_fixed_ip',
+                      compute_api_remove_fixed_ip)
+        self.stub_out('nova.compute.api.API.get', compute_api_get)
         self.controller = self.controller_class.MultinicController()
         self.fake_req = fakes.HTTPRequest.blank('')
 
@@ -75,15 +71,7 @@ class FixedIpTestV21(test.NoDBTestCase):
         last_add_fixed_ip = (None, None)
 
         body = dict(addFixedIp=dict(networkId='test_net'))
-        resp = self.controller._add_fixed_ip(self.fake_req, UUID, body=body)
-        # NOTE: on v2.1, http status code is set as wsgi_code of API
-        # method instead of status_int in a response object.
-        if isinstance(self.controller,
-                      multinic_v21.MultinicController):
-            status_int = self.controller._add_fixed_ip.wsgi_code
-        else:
-            status_int = resp.status_int
-        self.assertEqual(status_int, 202)
+        self.controller._add_fixed_ip(self.fake_req, UUID, body=body)
         self.assertEqual(last_add_fixed_ip, (UUID, 'test_net'))
 
     def _test_add_fixed_ip_bad_request(self, body):
@@ -123,15 +111,7 @@ class FixedIpTestV21(test.NoDBTestCase):
         last_remove_fixed_ip = (None, None)
 
         body = dict(removeFixedIp=dict(address='10.10.10.1'))
-        resp = self.controller._remove_fixed_ip(self.fake_req, UUID, body=body)
-        # NOTE: on v2.1, http status code is set as wsgi_code of API
-        # method instead of status_int in a response object.
-        if isinstance(self.controller,
-                      multinic_v21.MultinicController):
-            status_int = self.controller._remove_fixed_ip.wsgi_code
-        else:
-            status_int = resp.status_int
-        self.assertEqual(status_int, 202)
+        self.controller._remove_fixed_ip(self.fake_req, UUID, body=body)
         self.assertEqual(last_remove_fixed_ip, (UUID, '10.10.10.1'))
 
     def test_remove_fixed_ip_no_address(self):
@@ -164,16 +144,6 @@ class FixedIpTestV21(test.NoDBTestCase):
                           UUID, body=body)
 
 
-class FixedIpTestV2(FixedIpTestV21):
-    controller_class = multinic_v2
-    validation_error = webob.exc.HTTPBadRequest
-
-    def test_remove_fixed_ip_invalid_address(self):
-        # NOTE(cyeoh): This test is disabled for the V2 API because it is
-        # has poorer input validation.
-        pass
-
-
 class MultinicPolicyEnforcementV21(test.NoDBTestCase):
 
     def setUp(self):
@@ -202,3 +172,21 @@ class MultinicPolicyEnforcementV21(test.NoDBTestCase):
         self.assertEqual(
             "Policy doesn't allow %s to be performed." % rule_name,
             exc.format_message())
+
+
+class MultinicAPIDeprecationTest(test.NoDBTestCase):
+
+    def setUp(self):
+        super(MultinicAPIDeprecationTest, self).setUp()
+        self.controller = multinic_v21.MultinicController()
+        self.req = fakes.HTTPRequest.blank('', version='2.44')
+
+    def test_add_fixed_ip_not_found(self):
+        body = dict(addFixedIp=dict(networkId='test_net'))
+        self.assertRaises(exception.VersionNotFoundForAPIMethod,
+            self.controller._add_fixed_ip, self.req, UUID, body=body)
+
+    def test_remove_fixed_ip__not_found(self):
+        body = dict(removeFixedIp=dict(address='10.10.10.1'))
+        self.assertRaises(exception.VersionNotFoundForAPIMethod,
+            self.controller._remove_fixed_ip, self.req, UUID, body=body)
