@@ -13,17 +13,16 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 import six
-import uuid
 
 import mock
 from neutronclient.common import exceptions as n_exc
-from neutronclient.neutron import v2_0 as neutronv20
 from oslo_config import cfg
 from oslo_serialization import jsonutils
 from oslo_utils import encodeutils
+from oslo_utils import uuidutils
 import webob
 
-from nova.api.openstack.compute.legacy_v2.contrib import security_groups
+from nova.api.openstack.compute import security_groups
 from nova import compute
 from nova import context
 import nova.db
@@ -43,7 +42,7 @@ UUID_SERVER = uuids.server
 class TestNeutronSecurityGroupsTestCase(test.TestCase):
     def setUp(self):
         super(TestNeutronSecurityGroupsTestCase, self).setUp()
-        cfg.CONF.set_override('security_group_api', 'neutron')
+        cfg.CONF.set_override('use_neutron', True)
         self.original_client = neutron_api.get_client
         neutron_api.get_client = get_client
 
@@ -56,6 +55,8 @@ class TestNeutronSecurityGroupsTestCase(test.TestCase):
 class TestNeutronSecurityGroupsV21(
         test_security_groups.TestSecurityGroupsV21,
         TestNeutronSecurityGroupsTestCase):
+    # Used to override set config in the base test in test_security_groups.
+    use_neutron = True
 
     def _create_sg_template(self, **kwargs):
         sg = test_security_groups.security_group_request_template(**kwargs)
@@ -73,7 +74,7 @@ class TestNeutronSecurityGroupsV21(
     def _create_port(self, **kwargs):
         body = {'port': {'binding:vnic_type': model.VNIC_TYPE_NORMAL}}
         fields = ['security_groups', 'device_id', 'network_id',
-                  'port_security_enabled']
+                  'port_security_enabled', 'ip_allocation']
         for field in fields:
             if field in kwargs:
                 body['port'][field] = kwargs[field]
@@ -129,6 +130,14 @@ class TestNeutronSecurityGroupsV21(
         # Enforced by Neutron server.
         pass
 
+    def test_create_security_group_over_quota_during_recheck(self):
+        # Enforced by Neutron server.
+        pass
+
+    def test_create_security_group_no_quota_recheck(self):
+        # Enforced by Neutron server.
+        pass
+
     def test_update_security_group(self):
         # Enforced by Neutron server.
         pass
@@ -139,6 +148,13 @@ class TestNeutronSecurityGroupsV21(
         list_dict = self.controller.index(req)
         self.assertEqual(len(list_dict['security_groups']), 2)
 
+    def test_get_security_group_list_offset_and_limit(self):
+        path = '/v2/fake/os-security-groups?offset=1&limit=1'
+        self._create_sg_template().get('security_group')
+        req = fakes.HTTPRequest.blank(path)
+        list_dict = self.controller.index(req)
+        self.assertEqual(len(list_dict['security_groups']), 1)
+
     def test_get_security_group_list_all_tenants(self):
         pass
 
@@ -190,7 +206,7 @@ class TestNeutronSecurityGroupsV21(
         neutron = neutron_api.API()
         with mock.patch.object(nova.db, 'instance_get_by_uuid',
                                return_value=db_inst):
-            neutron.allocate_for_instance(_context, instance,
+            neutron.allocate_for_instance(_context, instance, False, None,
                                           security_groups=[sg['id']])
 
         req = fakes.HTTPRequest.blank('/v2/fake/os-security-groups/%s'
@@ -278,6 +294,22 @@ class TestNeutronSecurityGroupsV21(
                           self.manager._addSecurityGroup,
                           req, UUID_SERVER, body)
 
+    def test_associate_deferred_ip_port(self):
+        sg = self._create_sg_template().get('security_group')
+        net = self._create_network()
+        self._create_port(
+            network_id=net['network']['id'], security_groups=[sg['id']],
+            port_security_enabled=True, ip_allocation='deferred',
+            device_id=UUID_SERVER)
+
+        self.stub_out('nova.db.instance_get_by_uuid',
+                      test_security_groups.return_server)
+        body = dict(addSecurityGroup=dict(name="test"))
+
+        req = fakes.HTTPRequest.blank('/v2/fake/servers/%s/action' %
+                                      UUID_SERVER)
+        self.manager._addSecurityGroup(req, UUID_SERVER, body)
+
     def test_disassociate_by_non_existing_security_group_name(self):
         self.stub_out('nova.db.instance_get_by_uuid',
                       test_security_groups.return_server)
@@ -316,18 +348,6 @@ class TestNeutronSecurityGroupsV21(
                                       UUID_SERVER)
         self.manager._removeSecurityGroup(req, UUID_SERVER, body)
 
-    def test_get_raises_no_unique_match_error(self):
-
-        def fake_find_resourceid_by_name_or_id(client, param, name,
-                                               project_id=None):
-            raise n_exc.NeutronClientNoUniqueMatch()
-
-        self.stubs.Set(neutronv20, 'find_resourceid_by_name_or_id',
-                       fake_find_resourceid_by_name_or_id)
-        security_group_api = self.controller.security_group_api
-        self.assertRaises(exception.NoUniqueMatch, security_group_api.get,
-                          context.get_admin_context(), 'foobar')
-
     def test_get_instances_security_groups_bindings(self):
         servers = [{'id': test_security_groups.FAKE_UUID1},
                    {'id': test_security_groups.FAKE_UUID2}]
@@ -412,12 +432,6 @@ class TestNeutronSecurityGroupsV21(
                            device_id=test_security_groups.FAKE_UUID1)
 
 
-class TestNeutronSecurityGroupsV2(TestNeutronSecurityGroupsV21):
-    secgrp_ctl_cls = security_groups.SecurityGroupController
-    server_secgrp_ctl_cls = security_groups.ServerSecurityGroupController
-    secgrp_act_ctl_cls = security_groups.SecurityGroupActionController
-
-
 class TestNeutronSecurityGroupRulesTestCase(TestNeutronSecurityGroupsTestCase):
     def setUp(self):
         super(TestNeutronSecurityGroupRulesTestCase, self).setUp()
@@ -477,19 +491,21 @@ class _TestNeutronSecurityGroupRulesBase(object):
         # Enforced by neutron
         pass
 
+    def test_create_rule_over_quota_during_recheck(self):
+        # Enforced by neutron
+        pass
 
-class TestNeutronSecurityGroupRulesV2(
-        _TestNeutronSecurityGroupRulesBase,
-        test_security_groups.TestSecurityGroupRulesV2,
-        TestNeutronSecurityGroupRulesTestCase):
-    pass
+    def test_create_rule_no_quota_recheck(self):
+        # Enforced by neutron
+        pass
 
 
 class TestNeutronSecurityGroupRulesV21(
         _TestNeutronSecurityGroupRulesBase,
         test_security_groups.TestSecurityGroupRulesV21,
         TestNeutronSecurityGroupRulesTestCase):
-    pass
+    # Used to override set config in the base test in test_security_groups.
+    use_neutron = True
 
 
 class TestNeutronSecurityGroupsOutputTest(TestNeutronSecurityGroupsTestCase):
@@ -509,19 +525,18 @@ class TestNeutronSecurityGroupsOutputTest(TestNeutronSecurityGroupsTestCase):
                        'get_instances_security_groups_bindings',
                        (test_security_groups.
                        fake_get_instances_security_groups_bindings))
-        self.flags(
-            osapi_compute_extension=[
-                'nova.api.openstack.compute.contrib.select_extensions'],
-            osapi_compute_ext_list=['Security_groups'])
 
     def _make_request(self, url, body=None):
-        req = webob.Request.blank(url)
+        req = fakes.HTTPRequest.blank(url)
         if body:
             req.method = 'POST'
             req.body = encodeutils.safe_encode(self._encode_body(body))
         req.content_type = self.content_type
         req.headers['Accept'] = self.content_type
-        res = req.get_response(fakes.wsgi_app(init_only=('servers',)))
+
+        # NOTE: This 'os-security-groups' is for enabling security_groups
+        #       attribute on response body.
+        res = req.get_response(fakes.wsgi_app_v21())
         return res
 
     def _encode_body(self, body):
@@ -641,7 +656,7 @@ class MockClient(object):
         if not len(self._fake_security_groups):
             ret = {'name': 'default', 'description': 'default',
                    'tenant_id': 'fake_tenant', 'security_group_rules': [],
-                   'id': str(uuid.uuid4())}
+                   'id': uuidutils.generate_uuid()}
             self._fake_security_groups[ret['id']] = ret
 
     def _reset(self):
@@ -666,7 +681,7 @@ class MockClient(object):
             raise n_exc.NeutronClientException(message=msg, status_code=401)
         ret = {'name': s.get('name'), 'description': s.get('description'),
                'tenant_id': 'fake', 'security_group_rules': [],
-               'id': str(uuid.uuid4())}
+               'id': uuidutils.generate_uuid()}
 
         self._fake_security_groups[ret['id']] = ret
         return {'security_group': ret}
@@ -676,7 +691,7 @@ class MockClient(object):
         ret = {'status': 'ACTIVE', 'subnets': [], 'name': n.get('name'),
                'admin_state_up': n.get('admin_state_up', True),
                'tenant_id': 'fake_tenant',
-               'id': str(uuid.uuid4())}
+               'id': uuidutils.generate_uuid()}
         if 'port_security_enabled' in n:
             ret['port_security_enabled'] = n['port_security_enabled']
         self._fake_networks[ret['id']] = ret
@@ -691,7 +706,7 @@ class MockClient(object):
             raise n_exc.NeutronClientException(message=msg, status_code=404)
         ret = {'name': s.get('name'), 'network_id': s.get('network_id'),
                'tenant_id': 'fake_tenant', 'cidr': s.get('cidr'),
-               'id': str(uuid.uuid4()), 'gateway_ip': '10.0.0.1'}
+               'id': uuidutils.generate_uuid(), 'gateway_ip': '10.0.0.1'}
         net['subnets'].append(ret['id'])
         self._fake_networks[net['id']] = net
         self._fake_subnets[ret['id']] = ret
@@ -699,12 +714,13 @@ class MockClient(object):
 
     def create_port(self, body):
         p = body.get('port')
-        ret = {'status': 'ACTIVE', 'id': str(uuid.uuid4()),
+        ret = {'status': 'ACTIVE', 'id': uuidutils.generate_uuid(),
                'mac_address': p.get('mac_address', 'fa:16:3e:b8:f5:fb'),
-               'device_id': p.get('device_id', str(uuid.uuid4())),
+               'device_id': p.get('device_id', uuidutils.generate_uuid()),
                'admin_state_up': p.get('admin_state_up', True),
                'security_groups': p.get('security_groups', []),
                'network_id': p.get('network_id'),
+               'ip_allocation': p.get('ip_allocation'),
                'binding:vnic_type':
                    p.get('binding:vnic_type') or model.VNIC_TYPE_NORMAL}
 
@@ -719,7 +735,7 @@ class MockClient(object):
         if not port_security and ret['security_groups']:
             raise exception.SecurityGroupCannotBeApplied()
 
-        if network['subnets']:
+        if network['subnets'] and p.get('ip_allocation') != 'deferred':
             ret['fixed_ips'] = [{'subnet_id': network['subnets'][0],
                                  'ip_address': '10.0.0.1'}]
         if not ret['security_groups'] and (port_security is None or
@@ -740,7 +756,7 @@ class MockClient(object):
         ret = {}
         for field in fields:
             ret[field] = r.get(field)
-        ret['id'] = str(uuid.uuid4())
+        ret['id'] = uuidutils.generate_uuid()
         self._fake_security_group_rules[ret['id']] = ret
         return {'security_group_rules': [ret]}
 
@@ -881,3 +897,23 @@ class MockClient(object):
                        'one or more ports still in use on the network'
                        % network)
             raise n_exc.NeutronClientException(message=msg, status_code=409)
+
+    def find_resource(self, resource, name_or_id, project_id=None,
+                      cmd_resource=None, parent_id=None, fields=None):
+        if resource == 'security_group':
+            # lookup first by unique id
+            sg = self._fake_security_groups.get(name_or_id)
+            if sg:
+                return sg
+            # lookup by name, raise an exception on duplicates
+            res = None
+            for sg in self._fake_security_groups.values():
+                if sg['name'] == name_or_id:
+                    if res:
+                        raise n_exc.NeutronClientNoUniqueMatch(
+                            resource=resource, name=name_or_id)
+                    res = sg
+            if res:
+                return res
+        raise n_exc.NotFound("Fake %s '%s' not found." %
+                             (resource, name_or_id))
