@@ -13,19 +13,17 @@
 #   under the License.
 
 import mock
-from oslo_config import cfg
 import webob
 
-from nova.api.openstack.compute.legacy_v2.contrib import rescue as rescue_v2
 from nova.api.openstack.compute import rescue as rescue_v21
-from nova.api.openstack import extensions
 from nova import compute
+import nova.conf
 from nova import exception
 from nova import test
 from nova.tests.unit.api.openstack import fakes
+from nova.tests.unit import fake_instance
 
-CONF = cfg.CONF
-CONF.import_opt('password_length', 'nova.utils')
+CONF = nova.conf.CONF
 UUID = '70f6db34-de8d-4fbd-aafb-4065bdfa6114'
 
 
@@ -39,39 +37,36 @@ def unrescue(self, context, instance):
 
 
 def fake_compute_get(*args, **kwargs):
-
-    return {'id': 1, 'uuid': UUID}
+    return fake_instance.fake_instance_obj(args[1], id=1,
+                                           uuid=UUID, **kwargs)
 
 
 class RescueTestV21(test.NoDBTestCase):
 
     image_uuid = '76fa36fc-c930-4bf3-8c8a-ea2a2420deb6'
-    image_href = 'http://localhost/v2/fake/images/%s' % image_uuid
 
     def setUp(self):
         super(RescueTestV21, self).setUp()
 
-        self.stubs.Set(compute.api.API, "get", fake_compute_get)
-        self.stubs.Set(compute.api.API, "rescue", rescue)
-        self.stubs.Set(compute.api.API, "unrescue", unrescue)
+        self.stub_out("nova.compute.api.API.get", fake_compute_get)
+        self.stub_out("nova.compute.api.API.rescue", rescue)
+        self.stub_out("nova.compute.api.API.unrescue", unrescue)
         self.controller = self._set_up_controller()
         self.fake_req = fakes.HTTPRequest.blank('')
 
     def _set_up_controller(self):
         return rescue_v21.RescueController()
 
-    def test_rescue_from_locked_server(self):
-        def fake_rescue_from_locked_server(self, context,
-            instance, rescue_password=None, rescue_image_ref=None):
-            raise exception.InstanceIsLocked(instance_uuid=instance['uuid'])
+    @mock.patch.object(compute.api.API, "rescue")
+    def test_rescue_from_locked_server(self, mock_rescue):
+        mock_rescue.side_effect = exception.InstanceIsLocked(
+            instance_uuid=UUID)
 
-        self.stubs.Set(compute.api.API,
-                       'rescue',
-                       fake_rescue_from_locked_server)
         body = {"rescue": {"adminPass": "AABBCC112233"}}
         self.assertRaises(webob.exc.HTTPConflict,
                           self.controller._rescue,
                           self.fake_req, UUID, body=body)
+        self.assertTrue(mock_rescue.called)
 
     def test_rescue_with_preset_password(self):
         body = {"rescue": {"adminPass": "AABBCC112233"}}
@@ -83,16 +78,16 @@ class RescueTestV21(test.NoDBTestCase):
         resp = self.controller._rescue(self.fake_req, UUID, body=body)
         self.assertEqual(CONF.password_length, len(resp['adminPass']))
 
-    def test_rescue_of_rescued_instance(self):
+    @mock.patch.object(compute.api.API, "rescue")
+    def test_rescue_of_rescued_instance(self, mock_rescue):
+        mock_rescue.side_effect = exception.InstanceInvalidState(
+            'fake message')
         body = dict(rescue=None)
 
-        def fake_rescue(*args, **kwargs):
-            raise exception.InstanceInvalidState('fake message')
-
-        self.stubs.Set(compute.api.API, "rescue", fake_rescue)
         self.assertRaises(webob.exc.HTTPConflict,
                           self.controller._rescue,
                           self.fake_req, UUID, body=body)
+        self.assertTrue(mock_rescue.called)
 
     def test_unrescue(self):
         body = dict(unrescue=None)
@@ -106,55 +101,71 @@ class RescueTestV21(test.NoDBTestCase):
             status_int = resp.status_int
         self.assertEqual(202, status_int)
 
-    def test_unrescue_from_locked_server(self):
-        def fake_unrescue_from_locked_server(self, context,
-            instance):
-            raise exception.InstanceIsLocked(instance_uuid=instance['uuid'])
-
-        self.stubs.Set(compute.api.API,
-                       'unrescue',
-                       fake_unrescue_from_locked_server)
+    @mock.patch.object(compute.api.API, "unrescue")
+    def test_unrescue_from_locked_server(self, mock_unrescue):
+        mock_unrescue.side_effect = exception.InstanceIsLocked(
+            instance_uuid=UUID)
 
         body = dict(unrescue=None)
         self.assertRaises(webob.exc.HTTPConflict,
                           self.controller._unrescue,
                           self.fake_req, UUID, body=body)
+        self.assertTrue(mock_unrescue.called)
 
-    def test_unrescue_of_active_instance(self):
+    @mock.patch.object(compute.api.API, "unrescue")
+    def test_unrescue_of_active_instance(self, mock_unrescue):
+        mock_unrescue.side_effect = exception.InstanceInvalidState(
+            'fake message')
         body = dict(unrescue=None)
 
-        def fake_unrescue(*args, **kwargs):
-            raise exception.InstanceInvalidState('fake message')
-
-        self.stubs.Set(compute.api.API, "unrescue", fake_unrescue)
         self.assertRaises(webob.exc.HTTPConflict,
                           self.controller._unrescue,
                           self.fake_req, UUID, body=body)
+        self.assertTrue(mock_unrescue.called)
 
-    def test_rescue_raises_unrescuable(self):
+    @mock.patch.object(compute.api.API, "rescue")
+    def test_rescue_raises_unrescuable(self, mock_rescue):
+        mock_rescue.side_effect = exception.InstanceNotRescuable(
+            'fake message')
         body = dict(rescue=None)
 
-        def fake_rescue(*args, **kwargs):
-            raise exception.InstanceNotRescuable('fake message')
-
-        self.stubs.Set(compute.api.API, "rescue", fake_rescue)
         self.assertRaises(webob.exc.HTTPBadRequest,
                           self.controller._rescue,
                           self.fake_req, UUID, body=body)
+        self.assertTrue(mock_rescue.called)
 
-    @mock.patch('nova.compute.api.API.rescue')
-    def test_rescue_with_bad_image_specified(self, mock_compute_api_rescue):
+    def test_rescue_with_bad_image_specified(self):
         body = {"rescue": {"adminPass": "ABC123",
                            "rescue_image_ref": "img-id"}}
-        self.assertRaises(webob.exc.HTTPBadRequest,
+        self.assertRaises(exception.ValidationError,
+                          self.controller._rescue,
+                          self.fake_req, UUID, body=body)
+
+    def test_rescue_with_imageRef_as_full_url(self):
+        image_href = ('http://localhost/v2/fake/images/'
+                      '76fa36fc-c930-4bf3-8c8a-ea2a2420deb6')
+        body = {"rescue": {"adminPass": "ABC123",
+                           "rescue_image_ref": image_href}}
+        self.assertRaises(exception.ValidationError,
+                          self.controller._rescue,
+                          self.fake_req, UUID, body=body)
+
+    def test_rescue_with_imageRef_as_empty_string(self):
+        body = {"rescue": {"adminPass": "ABC123",
+                           "rescue_image_ref": ''}}
+        self.assertRaises(exception.ValidationError,
                           self.controller._rescue,
                           self.fake_req, UUID, body=body)
 
     @mock.patch('nova.compute.api.API.rescue')
-    def test_rescue_with_image_specified(self, mock_compute_api_rescue):
-        instance = fake_compute_get()
+    @mock.patch('nova.api.openstack.common.get_instance')
+    def test_rescue_with_image_specified(
+        self, get_instance_mock, mock_compute_api_rescue):
+        instance = fake_instance.fake_instance_obj(
+            self.fake_req.environ['nova.context'])
+        get_instance_mock.return_value = instance
         body = {"rescue": {"adminPass": "ABC123",
-            "rescue_image_ref": self.image_href}}
+            "rescue_image_ref": self.image_uuid}}
         resp_json = self.controller._rescue(self.fake_req, UUID, body=body)
         self.assertEqual("ABC123", resp_json['adminPass'])
 
@@ -165,8 +176,12 @@ class RescueTestV21(test.NoDBTestCase):
             rescue_image_ref=self.image_uuid)
 
     @mock.patch('nova.compute.api.API.rescue')
-    def test_rescue_without_image_specified(self, mock_compute_api_rescue):
-        instance = fake_compute_get()
+    @mock.patch('nova.api.openstack.common.get_instance')
+    def test_rescue_without_image_specified(
+        self, get_instance_mock, mock_compute_api_rescue):
+        instance = fake_instance.fake_instance_obj(
+            self.fake_req.environ['nova.context'])
+        get_instance_mock.return_value = instance
         body = {"rescue": {"adminPass": "ABC123"}}
 
         resp_json = self.controller._rescue(self.fake_req, UUID, body=body)
@@ -187,7 +202,7 @@ class RescueTestV21(test.NoDBTestCase):
         self.assertEqual(CONF.password_length, len(resp['adminPass']))
 
     def test_rescue_disable_password(self):
-        self.flags(enable_instance_password=False)
+        self.flags(enable_instance_password=False, group='api')
         body = dict(rescue=None)
         resp_json = self.controller._rescue(self.fake_req, UUID, body=body)
         self.assertNotIn('adminPass', resp_json)
@@ -199,24 +214,6 @@ class RescueTestV21(test.NoDBTestCase):
                           self.fake_req, UUID, body=body)
 
 
-class RescueTestV20(RescueTestV21):
-
-    def _set_up_controller(self):
-        ext_mgr = extensions.ExtensionManager()
-        ext_mgr.extensions = {'os-extended-rescue-with-image': 'fake'}
-        return rescue_v2.RescueController(ext_mgr)
-
-    def test_rescue_with_invalid_property(self):
-        # NOTE(cyeoh): input validation in original v2 code does not
-        # check for invalid properties.
-        pass
-
-    def test_rescue_disable_password(self):
-        # NOTE(cyeoh): Original v2.0 code does not support disabling
-        # the admin password being returned through a conf setting
-        pass
-
-
 class RescuePolicyEnforcementV21(test.NoDBTestCase):
 
     def setUp(self):
@@ -224,10 +221,16 @@ class RescuePolicyEnforcementV21(test.NoDBTestCase):
         self.controller = rescue_v21.RescueController()
         self.req = fakes.HTTPRequest.blank('')
 
-    def test_rescue_policy_failed(self):
+    @mock.patch('nova.api.openstack.common.get_instance')
+    def test_rescue_policy_failed_with_other_project(self, get_instance_mock):
+        get_instance_mock.return_value = fake_instance.fake_instance_obj(
+            self.req.environ['nova.context'],
+            project_id=self.req.environ['nova.context'].project_id)
         rule_name = "os_compute_api:os-rescue"
-        self.policy.set_rules({rule_name: "project:non_fake"})
+        self.policy.set_rules({rule_name: "project_id:%(project_id)s"})
         body = {"rescue": {"adminPass": "AABBCC112233"}}
+        # Change the project_id in request context.
+        self.req.environ['nova.context'].project_id = 'other-project'
         exc = self.assertRaises(
             exception.PolicyNotAuthorized,
             self.controller._rescue, self.req, fakes.FAKE_UUID,
@@ -236,6 +239,41 @@ class RescuePolicyEnforcementV21(test.NoDBTestCase):
             "Policy doesn't allow %s to be performed." % rule_name,
             exc.format_message())
 
+    @mock.patch('nova.api.openstack.common.get_instance')
+    def test_rescue_overridden_policy_failed_with_other_user_in_same_project(
+        self, get_instance_mock):
+        get_instance_mock.return_value = (
+            fake_instance.fake_instance_obj(self.req.environ['nova.context']))
+        rule_name = "os_compute_api:os-rescue"
+        self.policy.set_rules({rule_name: "user_id:%(user_id)s"})
+        # Change the user_id in request context.
+        self.req.environ['nova.context'].user_id = 'other-user'
+        body = {"rescue": {"adminPass": "AABBCC112233"}}
+        exc = self.assertRaises(exception.PolicyNotAuthorized,
+                                self.controller._rescue, self.req,
+                                fakes.FAKE_UUID, body=body)
+        self.assertEqual(
+                      "Policy doesn't allow %s to be performed." % rule_name,
+                      exc.format_message())
+
+    @mock.patch('nova.compute.api.API.rescue')
+    @mock.patch('nova.api.openstack.common.get_instance')
+    def test_lock_overridden_policy_pass_with_same_user(self,
+                                                        get_instance_mock,
+                                                        rescue_mock):
+        instance = fake_instance.fake_instance_obj(
+            self.req.environ['nova.context'],
+            user_id=self.req.environ['nova.context'].user_id)
+        get_instance_mock.return_value = instance
+        rule_name = "os_compute_api:os-rescue"
+        self.policy.set_rules({rule_name: "user_id:%(user_id)s"})
+        body = {"rescue": {"adminPass": "AABBCC112233"}}
+        self.controller._rescue(self.req, fakes.FAKE_UUID, body=body)
+        rescue_mock.assert_called_once_with(self.req.environ['nova.context'],
+                                            instance,
+                                            rescue_password='AABBCC112233',
+                                            rescue_image_ref=None)
+
     def test_unrescue_policy_failed(self):
         rule_name = "os_compute_api:os-rescue"
         self.policy.set_rules({rule_name: "project:non_fake"})
