@@ -22,39 +22,59 @@ from nova import objects
 from nova.objects import instance as instance_obj
 from nova import test
 from nova.tests.unit.api.openstack import fakes
+from nova.tests import uuidsentinel as uuids
 
 fake_instances = {
-    '00000000-0000-0000-0000-000000000001': objects.Instance(
+    '00000000-0000-0000-0000-000000000001': objects.Instance(id=1,
         uuid='00000000-0000-0000-0000-000000000001', host='host1'),
-    '00000000-0000-0000-0000-000000000002': objects.Instance(
+    '00000000-0000-0000-0000-000000000002': objects.Instance(id=2,
         uuid='00000000-0000-0000-0000-000000000002', host='host1'),
-    '00000000-0000-0000-0000-000000000003': objects.Instance(
+    '00000000-0000-0000-0000-000000000003': objects.Instance(id=3,
         uuid='00000000-0000-0000-0000-000000000003', host='host2'),
-    '00000000-0000-0000-0000-000000000004': objects.Instance(
+    '00000000-0000-0000-0000-000000000004': objects.Instance(id=4,
         uuid='00000000-0000-0000-0000-000000000004', host=None),
 }
 fake_instance_uuids = sorted(fake_instances.keys())
 MISSING_UUID = '00000000-0000-0000-0000-000000000005'
 
+fake_cells = [objects.CellMapping(uuid=uuids.cell1, database_connection="db1"),
+              objects.CellMapping(uuid=uuids.cell2, database_connection="db2")]
+fake_instance_mappings = [
+        objects.InstanceMapping(cell_mapping=fake_cells[instance.id % 2],
+                                instance_uuid=instance.uuid)
+        for instance in fake_instances.values()]
+
 
 @classmethod
-def fake_get_by_uuid(cls, context, uuid, **kwargs):
-    if 'expected_attrs' in kwargs:
-        expected_attrs_set = set(kwargs['expected_attrs'])
+def fake_get_by_filters(cls, context, filters, expected_attrs=None):
+    if expected_attrs:
+        # This is a regression check for bug 1645479.
+        expected_attrs_set = set(expected_attrs)
         full_expected_attrs_set = set(instance_obj.INSTANCE_OPTIONAL_ATTRS)
         assert expected_attrs_set.issubset(full_expected_attrs_set), \
             ('%s is not a subset of %s' % (expected_attrs_set,
                                            full_expected_attrs_set))
-    try:
-        return fake_instances[uuid]
-    except KeyError:
-        raise exception.InstanceNotFound(instance_id=uuid)
+    l = objects.InstanceList(objects=[
+        inst for inst in fake_instances.values()
+        if inst.uuid in filters['uuid']])
+    return l
 
 
-@mock.patch('nova.objects.instance.Instance.get_by_uuid', fake_get_by_uuid)
+@classmethod
+def fake_get_by_instance_uuids(cls, context, uuids):
+    mappings = [im for im in fake_instance_mappings
+                if im.instance_uuid in uuids]
+    return objects.InstanceMappingList(objects=mappings)
+
+
+@mock.patch('nova.objects.InstanceMappingList.get_by_instance_uuids',
+            fake_get_by_instance_uuids)
+@mock.patch('nova.objects.InstanceList.get_by_filters',
+            fake_get_by_filters)
 class ServerExternalEventsTestV21(test.NoDBTestCase):
     server_external_events = server_external_events_v21
     invalid_error = exception.ValidationError
+    wsgi_api_version = '2.1'
 
     def setUp(self):
         super(ServerExternalEventsTestV21, self).setUp()
@@ -74,7 +94,8 @@ class ServerExternalEventsTestV21(test.NoDBTestCase):
         self.resp_event_2['status'] = 'completed'
         self.default_resp_body = {'events': [self.resp_event_1,
                                              self.resp_event_2]}
-        self.req = fakes.HTTPRequest.blank('', use_admin_context=True)
+        self.req = fakes.HTTPRequest.blank('', use_admin_context=True,
+                                           version=self.wsgi_api_version)
 
     def _assert_call(self, body, expected_uuids, expected_events):
         with mock.patch.object(self.api.compute_api,
@@ -85,12 +106,21 @@ class ServerExternalEventsTestV21(test.NoDBTestCase):
         code = response._code
 
         self.assertEqual(1, api_method.call_count)
-        for inst in api_method.call_args_list[0][0][1]:
-            expected_uuids.remove(inst.uuid)
-        self.assertEqual([], expected_uuids)
-        for event in api_method.call_args_list[0][0][2]:
-            expected_events.remove(event.name)
-        self.assertEqual([], expected_events)
+        call = api_method.call_args_list[0]
+        args = call[0]
+
+        call_instances = args[1]
+        call_events = args[2]
+
+        self.assertEqual(set(expected_uuids),
+                         set([instance.uuid for instance in call_instances]))
+        self.assertEqual(len(expected_uuids), len(call_instances))
+
+        self.assertEqual(set(expected_events),
+                         set([event.name for event in call_events]))
+        self.assertEqual(len(expected_events),
+                         len(call_events))
+
         return result, code
 
     def test_create(self):
@@ -157,3 +187,23 @@ class ServerExternalEventsTestV21(test.NoDBTestCase):
         body = {'events': self.event_1}
         self.assertRaises(self.invalid_error,
                           self.api.create, self.req, body=body)
+
+
+@mock.patch('nova.objects.InstanceMappingList.get_by_instance_uuids',
+            fake_get_by_instance_uuids)
+@mock.patch('nova.objects.InstanceList.get_by_filters',
+            fake_get_by_filters)
+class ServerExternalEventsTestV251(ServerExternalEventsTestV21):
+    wsgi_api_version = '2.51'
+
+    def test_create_with_missing_tag(self):
+        body = self.default_body
+        body['events'][1]['name'] = 'volume-extended'
+        result, code = self._assert_call(body,
+                                         [fake_instance_uuids[0]],
+                                         ['network-vif-plugged'])
+        self.assertEqual(200, result['events'][0]['code'])
+        self.assertEqual('completed', result['events'][0]['status'])
+        self.assertEqual(400, result['events'][1]['code'])
+        self.assertEqual('failed', result['events'][1]['status'])
+        self.assertEqual(207, code)
