@@ -13,8 +13,6 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-import uuid
-
 import mock
 from oslo_config import cfg
 from oslo_serialization import jsonutils
@@ -22,8 +20,6 @@ from oslo_utils import timeutils
 import six
 import webob
 
-from nova.api.openstack.compute.legacy_v2 import server_metadata \
-        as server_metadata_v2
 from nova.api.openstack.compute import server_metadata \
         as server_metadata_v21
 from nova.compute import rpcapi as compute_rpcapi
@@ -34,6 +30,7 @@ from nova import objects
 from nova import test
 from nova.tests.unit.api.openstack import fakes
 from nova.tests.unit import fake_instance
+from nova.tests import uuidsentinel as uuids
 
 
 CONF = cfg.CONF
@@ -78,7 +75,7 @@ def stub_server_metadata():
 
 def stub_max_server_metadata():
     metadata = {"metadata": {}}
-    for num in range(CONF.quota_metadata_items):
+    for num in range(CONF.quota.metadata_items):
         metadata['metadata']['key%i' % num] = "blah"
     return metadata
 
@@ -120,7 +117,7 @@ class ServerMetaDataTestV21(test.TestCase):
 
     def setUp(self):
         super(ServerMetaDataTestV21, self).setUp()
-        fakes.stub_out_key_pair_funcs(self.stubs)
+        fakes.stub_out_key_pair_funcs(self)
         self.stub_out('nova.db.instance_get', return_server)
         self.stub_out('nova.db.instance_get_by_uuid',
                       return_server_by_uuid)
@@ -134,7 +131,7 @@ class ServerMetaDataTestV21(test.TestCase):
 
     def _set_up_resources(self):
         self.controller = server_metadata_v21.ServerMetadataController()
-        self.uuid = str(uuid.uuid4())
+        self.uuid = uuids.fake
         self.url = '/fake/servers/%s/metadata' % self.uuid
 
     def _get_request(self, param_url=''):
@@ -585,7 +582,7 @@ class ServerMetaDataTestV21(test.TestCase):
         self.stub_out('nova.db.instance_metadata_update',
                       return_create_instance_metadata)
         data = {"metadata": {}}
-        for num in range(CONF.quota_metadata_items + 1):
+        for num in range(CONF.quota.metadata_items + 1):
             data['metadata']['key%i' % num] = "blah"
         req = self._get_request()
         req.method = 'POST'
@@ -624,7 +621,7 @@ class ServerMetaDataTestV21(test.TestCase):
         self.stub_out('nova.db.instance_metadata_update',
                       return_create_instance_metadata)
         data = {"metadata": {}}
-        for num in range(CONF.quota_metadata_items + 1):
+        for num in range(CONF.quota.metadata_items + 1):
             data['metadata']['key%i' % num] = "blah"
         req = self._get_request()
         req.method = 'PUT'
@@ -640,7 +637,7 @@ class ServerMetaDataTestV21(test.TestCase):
         self.stub_out('nova.db.instance_metadata_update',
                       return_create_instance_metadata)
         data = {"metadata": {}}
-        for num in range(CONF.quota_metadata_items + 1):
+        for num in range(CONF.quota.metadata_items + 1):
             data['metadata']['key%i' % num] = "blah"
         req = self._get_request()
         req.method = 'PUT'
@@ -669,24 +666,11 @@ class ServerMetaDataTestV21(test.TestCase):
                           body=data)
 
 
-class ServerMetaDataTestV2(ServerMetaDataTestV21):
-    validation_ex = webob.exc.HTTPBadRequest
-    validation_ex_large = webob.exc.HTTPRequestEntityTooLarge
-
-    def _set_up_resources(self):
-        self.controller = server_metadata_v2.Controller()
-        self.uuid = str(uuid.uuid4())
-        self.url = '/v1.1/fake/servers/%s/metadata' % self.uuid
-
-    def _get_request(self, param_url=''):
-        return fakes.HTTPRequest.blank(self.url + param_url)
-
-
 class BadStateServerMetaDataTestV21(test.TestCase):
 
     def setUp(self):
         super(BadStateServerMetaDataTestV21, self).setUp()
-        fakes.stub_out_key_pair_funcs(self.stubs)
+        fakes.stub_out_key_pair_funcs(self)
         self.stub_out('nova.db.instance_metadata_get',
                       return_server_metadata)
         self.stubs.Set(compute_rpcapi.ComputeAPI, 'change_instance_metadata',
@@ -700,7 +684,7 @@ class BadStateServerMetaDataTestV21(test.TestCase):
 
     def _set_up_resources(self):
         self.controller = server_metadata_v21.ServerMetadataController()
-        self.uuid = str(uuid.uuid4())
+        self.uuid = uuids.fake
         self.url = '/fake/servers/%s/metadata' % self.uuid
 
     def _get_request(self, param_url=''):
@@ -762,16 +746,6 @@ class BadStateServerMetaDataTestV21(test.TestCase):
                 req, self.uuid, body=expected)
 
 
-class BadStateServerMetaDataTestV2(BadStateServerMetaDataTestV21):
-    def _set_up_resources(self):
-        self.controller = server_metadata_v2.Controller()
-        self.uuid = str(uuid.uuid4())
-        self.url = '/v1.1/fake/servers/%s/metadata' % self.uuid
-
-    def _get_request(self, param_url=''):
-        return fakes.HTTPRequest.blank(self.url + param_url)
-
-
 class ServerMetaPolicyEnforcementV21(test.NoDBTestCase):
 
     def setUp(self):
