@@ -19,12 +19,13 @@ import copy
 import datetime
 
 import mock
-from oslo_config import cfg
 from oslo_utils import timeutils
 from six.moves import range
 
 from nova.cells import messaging
 from nova.cells import utils as cells_utils
+from nova.compute import rpcapi as compute_rpcapi
+import nova.conf
 from nova import context
 from nova import objects
 from nova import test
@@ -33,9 +34,7 @@ from nova.tests.unit import fake_instance
 from nova.tests.unit import fake_server_actions
 from nova.tests.unit.objects import test_flavor
 
-CONF = cfg.CONF
-CONF.import_opt('compute_topic', 'nova.compute.rpcapi')
-
+CONF = nova.conf.CONF
 
 FAKE_COMPUTE_NODES = [dict(id=1, host='host1'), dict(id=2, host='host2')]
 FAKE_SERVICES = [dict(id=1, host='host1'),
@@ -247,7 +246,7 @@ class CellsManagerClassTestCase(test.NoDBTestCase):
         self.stubs.Set(timeutils, 'utcnow', utcnow)
 
         self.cells_manager._heal_instances(fake_context)
-        self.assertEqual(True, call_info['shuffle'])
+        self.assertTrue(call_info['shuffle'])
         self.assertIsNone(call_info['project_id'])
         self.assertEqual(updated_since, call_info['updated_since'])
         self.assertEqual(1, call_info['get_instances'])
@@ -256,7 +255,7 @@ class CellsManagerClassTestCase(test.NoDBTestCase):
 
         call_info['sync_instances'] = []
         self.cells_manager._heal_instances(fake_context)
-        self.assertEqual(True, call_info['shuffle'])
+        self.assertTrue(call_info['shuffle'])
         self.assertIsNone(call_info['project_id'])
         self.assertEqual(updated_since, call_info['updated_since'])
         self.assertEqual(2, call_info['get_instances'])
@@ -390,7 +389,7 @@ class CellsManagerClassTestCase(test.NoDBTestCase):
                                  'proxy_rpc_to_manager')
         fake_response = self._get_fake_response()
         cell_and_host = cells_utils.cell_with_item('fake-cell', 'fake-host')
-        topic = "%s.%s" % (CONF.compute_topic, cell_and_host)
+        topic = "%s.%s" % (compute_rpcapi.RPC_TOPIC, cell_and_host)
         self.msg_runner.proxy_rpc_to_manager(self.ctxt, 'fake-cell',
                 'fake-host', topic, 'fake-rpc-msg',
                 True, -1).AndReturn(fake_response)
@@ -654,8 +653,10 @@ class CellsManagerClassTestCase(test.NoDBTestCase):
 
     def test_get_migrations(self):
         filters = {'status': 'confirmed'}
-        cell1_migrations = [{'id': 123}]
-        cell2_migrations = [{'id': 456}]
+        cell1_migrations = objects.MigrationList(
+            objects=[objects.Migration(id=123)])
+        cell2_migrations = objects.MigrationList(
+            objects=[objects.Migration(id=456)])
         fake_responses = [self._get_fake_response(cell1_migrations),
                           self._get_fake_response(cell2_migrations)]
         self.mox.StubOutWithMock(self.msg_runner,
@@ -666,12 +667,13 @@ class CellsManagerClassTestCase(test.NoDBTestCase):
 
         response = self.cells_manager.get_migrations(self.ctxt, filters)
 
-        self.assertEqual([cell1_migrations[0], cell2_migrations[0]], response)
+        self.assertEqual(cell1_migrations.objects + cell2_migrations.objects,
+                         response.objects)
 
     def test_get_migrations_for_a_given_cell(self):
         filters = {'status': 'confirmed', 'cell_name': 'ChildCell1'}
         target_cell = '%s%s%s' % (CONF.cells.name, '!', filters['cell_name'])
-        migrations = [{'id': 123}]
+        migrations = objects.MigrationList(objects=[objects.Migration(id=123)])
         fake_responses = [self._get_fake_response(migrations)]
         self.mox.StubOutWithMock(self.msg_runner,
                                  'get_migrations')
@@ -680,7 +682,7 @@ class CellsManagerClassTestCase(test.NoDBTestCase):
         self.mox.ReplayAll()
 
         response = self.cells_manager.get_migrations(self.ctxt, filters)
-        self.assertEqual(migrations, response)
+        self.assertEqual(migrations.objects, response.objects)
 
     def test_instance_update_from_api(self):
         self.mox.StubOutWithMock(self.msg_runner,
