@@ -126,10 +126,10 @@ class TestCellsStateManager(test.NoDBTestCase):
     def setUp(self):
         super(TestCellsStateManager, self).setUp()
 
-        self.stubs.Set(objects.ComputeNodeList, 'get_all',
-                       _fake_compute_node_get_all)
-        self.stubs.Set(objects.ServiceList, 'get_by_binary',
-                       _fake_service_get_all_by_binary)
+        self.stub_out('nova.objects.ComputeNodeList.get_all',
+                      _fake_compute_node_get_all)
+        self.stub_out('nova.objects.ServiceList.get_by_binary',
+                      _fake_service_get_all_by_binary)
         self.stub_out('nova.objects.FlavorList.get_all',
                       _fake_instance_type_all)
         self.stub_out('nova.db.cell_get_all', _fake_cell_get_all)
@@ -234,8 +234,8 @@ class TestCellsStateManagerNToOne(TestCellsStateManager):
     def setUp(self):
         super(TestCellsStateManagerNToOne, self).setUp()
 
-        self.stubs.Set(objects.ComputeNodeList, 'get_all',
-                       _fake_compute_node_n_to_one_get_all)
+        self.stub_out('nova.objects.ComputeNodeList.get_all',
+                      _fake_compute_node_n_to_one_get_all)
 
     def test_capacity_part_reserve(self):
         # utilize half the cell's free capacity
@@ -317,19 +317,15 @@ class TestCellsGetCapacity(TestCellsStateManager):
         other_cell = models.Cell(name="other_cell_name")
         cell.capacities = self.capacities
         other_cell.capacities = self.capacities
-        self.stubs.Set(self.state_manager, 'child_cells',
-                        {"cell_name": cell,
-                        "other_cell_name": other_cell})
+        self.state_manager.child_cells = {"cell_name": cell,
+                                          "other_cell_name": other_cell}
+        self.state_manager.my_cell_state.capacities = self.capacities
 
     def test_get_cell_capacity_for_all_cells(self):
-        self.stubs.Set(self.state_manager.my_cell_state, 'capacities',
-                                                        self.capacities)
         capacities = self.state_manager.get_capacities()
         self.assertEqual({"ram_free": 3702}, capacities)
 
     def test_get_cell_capacity_for_the_parent_cell(self):
-        self.stubs.Set(self.state_manager.my_cell_state, 'capacities',
-                                                        self.capacities)
         capacities = self.state_manager.\
                      get_capacities(self.state_manager.my_cell_state.name)
         self.assertEqual({"ram_free": 3702}, capacities)
