@@ -14,6 +14,7 @@
 
 from os_vif import objects as osv_objects
 from os_vif.objects import fields as os_vif_fields
+import six
 
 from nova import exception
 from nova.network import model
@@ -988,9 +989,31 @@ class OSVIFUtilTestCase(test.NoDBTestCase):
                 subnets=[]),
         )
 
-        self.assertRaises(exception.NovaException,
-                          os_vif_util.nova_to_osvif_vif,
-                          vif)
+        ex = self.assertRaises(exception.NovaException,
+                               os_vif_util.nova_to_osvif_vif, vif)
+        self.assertIn('Unsupported VIF type wibble', six.text_type(ex))
+
+    def test_nova_to_osvif_vif_binding_failed(self):
+        vif = model.VIF(
+            id="dc065497-3c8d-4f44-8fb4-e1d33c16a536",
+            type="binding_failed",
+            address="22:52:25:62:e2:aa",
+            network=model.Network(
+                id="b82c1929-051e-481d-8110-4669916c7915",
+                label="Demo Net",
+                subnets=[]),)
+        self.assertIsNone(os_vif_util.nova_to_osvif_vif(vif))
+
+    def test_nova_to_osvif_vif_unbound(self):
+        vif = model.VIF(
+            id="dc065497-3c8d-4f44-8fb4-e1d33c16a536",
+            type="unbound",
+            address="22:52:25:62:e2:aa",
+            network=model.Network(
+                id="b82c1929-051e-481d-8110-4669916c7915",
+                label="Demo Net",
+                subnets=[]),)
+        self.assertIsNone(os_vif_util.nova_to_osvif_vif(vif))
 
     def test_nova_to_osvif_vhostuser_vrouter(self):
         vif = model.VIF(
