@@ -119,7 +119,7 @@ class TestNotificationBase(test.NoDBTestCase):
         'id': 123,
         'uuid': uuids.service,
         'host': 'fake-host',
-        'binary': 'nova-fake',
+        'binary': 'nova-compute',
         'topic': 'fake-service-topic',
         'report_count': 1,
         'forced_down': False,
@@ -168,7 +168,7 @@ class TestNotificationBase(test.NoDBTestCase):
                              expected_event_type,
                              expected_payload):
         mock_notifier.prepare.assert_called_once_with(
-            publisher_id='nova-fake:fake-host')
+            publisher_id='nova-compute:fake-host')
         mock_notify = mock_notifier.prepare.return_value.info
         self.assertTrue(mock_notify.called)
         self.assertEqual(mock_notify.call_args[0][0], mock_context)
@@ -198,8 +198,9 @@ class TestNotificationBase(test.NoDBTestCase):
             event_type=notification.EventType(
                 object='test_object',
                 action=fields.NotificationAction.UPDATE),
-            publisher=notification.NotificationPublisher(host='fake-host',
-                                                         binary='nova-fake'),
+            publisher=notification.NotificationPublisher(
+                host='fake-host',
+                source='nova-compute'),
             priority=fields.NotificationPriority.INFO,
             payload=self.payload)
 
@@ -372,13 +373,18 @@ notification_object_data = {
     'AuditPeriodPayload': '1.0-2b429dd307b8374636703b843fa3f9cb',
     'BandwidthPayload': '1.0-ee2616a7690ab78406842a2b68e34130',
     'BlockDevicePayload': '1.0-29751e1b6d41b1454e36768a1e764df8',
-    'EventType': '1.5-ffa6d332f4462c45a2a363356a14165f',
+    'EventType': '1.8-0f8fb2dbc76f10c7c56d1680c65ad0cf',
     'ExceptionNotification': '1.0-a73147b93b520ff0061865849d3dfa56',
     'ExceptionPayload': '1.0-27db46ee34cd97e39f2643ed92ad0cc5',
     'FlavorNotification': '1.0-a73147b93b520ff0061865849d3dfa56',
-    'FlavorPayload': '1.3-6335e626893d7df5f96f87e6731fef56',
+    'FlavorPayload': '1.4-2e7011b8b4e59167fe8b7a0a81f0d452',
     'InstanceActionNotification': '1.0-a73147b93b520ff0061865849d3dfa56',
     'InstanceActionPayload': '1.5-fb2804ce9b681bfb217e729153c22611',
+    'InstanceActionRescueNotification': '1.0-a73147b93b520ff0061865849d3dfa56',
+    'InstanceActionRescuePayload': '1.0-a29f3339d0b8c3bcc997ab5d19d898d5',
+    'InstanceActionResizePrepNotification':
+        '1.0-a73147b93b520ff0061865849d3dfa56',
+    'InstanceActionResizePrepPayload': '1.0-3a23d3dd6516964a51c256b2f8b4646c',
     'InstanceActionVolumeNotification': '1.0-a73147b93b520ff0061865849d3dfa56',
     'InstanceActionVolumePayload': '1.3-f175b22ac6d6d0aea2bac21e12156e77',
     'InstanceActionVolumeSwapNotification':
@@ -387,13 +393,18 @@ notification_object_data = {
     'InstanceCreateNotification': '1.0-a73147b93b520ff0061865849d3dfa56',
     'InstanceCreatePayload': '1.7-a35b2f3aa64dcc262ebb830e78939bdb',
     'InstancePayload': '1.5-201d852973dbcb5caab89082a3140487',
+    'InstanceActionSnapshotNotification':
+        '1.0-a73147b93b520ff0061865849d3dfa56',
+    'InstanceActionSnapshotPayload': '1.6-6f96ad137957d802aac94c90337fd950',
     'InstanceStateUpdatePayload': '1.0-07e111c0fa0f6db0f79b0726d593e3da',
     'InstanceUpdateNotification': '1.0-a73147b93b520ff0061865849d3dfa56',
     'InstanceUpdatePayload': '1.6-9145c7cac4208eb841ceaaa9c10b2d9b',
     'IpPayload': '1.0-8ecf567a99e516d4af094439a7632d34',
     'KeypairNotification': '1.0-a73147b93b520ff0061865849d3dfa56',
     'KeypairPayload': '1.0-6daebbbde0e1bf35c1556b1ecd9385c1',
-    'NotificationPublisher': '1.0-bbbc1402fb0e443a3eb227cc52b61545',
+    'NotificationPublisher': '2.2-b6ad48126247e10b46b6b0240e52e614',
+    'ServerGroupNotification': '1.0-a73147b93b520ff0061865849d3dfa56',
+    'ServerGroupPayload': '1.0-eb4bd1738b4670cfe1b7c30344c143c3',
     'ServiceStatusNotification': '1.0-a73147b93b520ff0061865849d3dfa56',
     'ServiceStatusPayload': '1.1-7b6856bd879db7f3ecbcd0ca9f35f92f',
 }
