@@ -13,6 +13,7 @@
 #    under the License.
 
 import copy
+
 import mock
 import netaddr
 from oslo_serialization import jsonutils
@@ -89,6 +90,7 @@ fake_compute_node = {
     'cpu_allocation_ratio': 16.0,
     'ram_allocation_ratio': 1.5,
     'disk_allocation_ratio': 1.0,
+    'mapped': 0,
     }
 # FIXME(sbauza) : For compatibility checking, to be removed once we are sure
 # that all computes are running latest DB version with host field in it.
@@ -152,15 +154,48 @@ class _TestComputeNodeObject(object):
         return {'supported_hv_specs': 'supported_instances',
                 'pci_device_pools': 'pci_stats'}
 
-    def test_get_by_id(self):
-        self.mox.StubOutWithMock(db, 'compute_node_get')
-        db.compute_node_get(self.context, 123).AndReturn(fake_compute_node)
-        self.mox.ReplayAll()
+    @mock.patch.object(db, 'compute_node_get')
+    def test_get_by_id(self, get_mock):
+        get_mock.return_value = fake_compute_node
         compute = compute_node.ComputeNode.get_by_id(self.context, 123)
         self.compare_obj(compute, fake_compute_node,
                          subs=self.subs(),
                          comparators=self.comparators())
         self.assertNotIn('uuid', compute.obj_what_changed())
+        get_mock.assert_called_once_with(self.context, 123)
+
+    @mock.patch.object(compute_node.ComputeNodeList, 'get_all_by_uuids')
+    def test_get_by_uuid(self, get_all_by_uuids):
+        fake_node = copy.copy(fake_compute_node)
+        fake_node['stats'] = None
+        get_all_by_uuids.return_value = objects.ComputeNodeList(
+            objects=[objects.ComputeNode(**fake_node)])
+        compute = compute_node.ComputeNode.get_by_uuid(
+            self.context, uuidsentinel.fake_compute_node)
+        self.assertEqual(uuidsentinel.fake_compute_node, compute.uuid)
+        get_all_by_uuids.assert_called_once_with(
+            self.context, [uuidsentinel.fake_compute_node])
+
+    @mock.patch.object(compute_node.ComputeNodeList, 'get_all_by_uuids')
+    def test_get_by_uuid_not_found(self, get_all_by_uuids):
+        get_all_by_uuids.return_value = objects.ComputeNodeList()
+        self.assertRaises(exception.ComputeHostNotFound,
+                          compute_node.ComputeNode.get_by_uuid,
+                          self.context, uuidsentinel.fake_compute_node)
+        get_all_by_uuids.assert_called_once_with(
+            self.context, [uuidsentinel.fake_compute_node])
+
+    @mock.patch.object(db, 'compute_node_get')
+    def test_get_without_mapped(self, get_mock):
+        fake_node = copy.copy(fake_compute_node)
+        fake_node['mapped'] = None
+        get_mock.return_value = fake_node
+        compute = compute_node.ComputeNode.get_by_id(self.context, 123)
+        self.compare_obj(compute, fake_compute_node,
+                         subs=self.subs(),
+                         comparators=self.comparators())
+        self.assertIn('mapped', compute)
+        self.assertEqual(0, compute.mapped)
 
     @mock.patch.object(objects.Service, 'get_by_id')
     @mock.patch.object(db, 'compute_node_get')
@@ -181,15 +216,14 @@ class _TestComputeNodeObject(object):
                          subs=self.subs(),
                          comparators=self.comparators())
 
-    def test_get_by_service_id(self):
-        self.mox.StubOutWithMock(db, 'compute_nodes_get_by_service_id')
-        db.compute_nodes_get_by_service_id(self.context, 456).AndReturn(
-            [fake_compute_node])
-        self.mox.ReplayAll()
+    @mock.patch.object(db, 'compute_nodes_get_by_service_id')
+    def test_get_by_service_id(self, get_mock):
+        get_mock.return_value = [fake_compute_node]
         compute = compute_node.ComputeNode.get_by_service_id(self.context, 456)
         self.compare_obj(compute, fake_compute_node,
                          subs=self.subs(),
                          comparators=self.comparators())
+        get_mock.assert_called_once_with(self.context, 456)
 
     @mock.patch.object(db, 'compute_node_get_by_host_and_nodename')
     def test_get_by_host_and_nodename(self, cn_get_by_h_and_n):
@@ -227,18 +261,10 @@ class _TestComputeNodeObject(object):
             compute_node.ComputeNode.get_first_node_by_host_for_old_compat,
             self.context, 'fake')
 
-    def test_create(self):
-        self.mox.StubOutWithMock(db, 'compute_node_create')
-        db.compute_node_create(
-            self.context,
-            {
-                'service_id': 456,
-                'stats': fake_stats_db_format,
-                'host_ip': fake_host_ip,
-                'supported_instances': fake_supported_hv_specs_db_format,
-                'uuid': uuidsentinel.fake_compute_node,
-            }).AndReturn(fake_compute_node)
-        self.mox.ReplayAll()
+    @mock.patch.object(db, 'compute_node_create')
+    @mock.patch('nova.db.compute_node_get', return_value=fake_compute_node)
+    def test_create(self, mock_get, mock_create):
+        mock_create.return_value = fake_compute_node
         compute = compute_node.ComputeNode(context=self.context)
         compute.service_id = 456
         compute.uuid = uuidsentinel.fake_compute_node
@@ -252,10 +278,19 @@ class _TestComputeNodeObject(object):
         self.compare_obj(compute, fake_compute_node,
                          subs=self.subs(),
                          comparators=self.comparators())
+        param_dict = {
+            'service_id': 456,
+            'stats': fake_stats_db_format,
+            'host_ip': fake_host_ip,
+            'supported_instances': fake_supported_hv_specs_db_format,
+            'uuid': uuidsentinel.fake_compute_node
+        }
+        mock_create.assert_called_once_with(self.context, param_dict)
 
     @mock.patch('nova.db.compute_node_create')
     @mock.patch('oslo_utils.uuidutils.generate_uuid')
-    def test_create_allocates_uuid(self, mock_gu, mock_create):
+    @mock.patch('nova.db.compute_node_get', return_value=fake_compute_node)
+    def test_create_allocates_uuid(self, mock_get, mock_gu, mock_create):
         mock_create.return_value = fake_compute_node
         mock_gu.return_value = fake_compute_node['uuid']
         obj = objects.ComputeNode(context=self.context)
@@ -264,31 +299,23 @@ class _TestComputeNodeObject(object):
         mock_create.assert_called_once_with(
             self.context, {'uuid': fake_compute_node['uuid']})
 
-    def test_recreate_fails(self):
-        self.mox.StubOutWithMock(db, 'compute_node_create')
-        db.compute_node_create(
-            self.context, {'service_id': 456,
-                           'uuid': uuidsentinel.fake_compute_node}).AndReturn(
-            fake_compute_node)
-        self.mox.ReplayAll()
+    @mock.patch('nova.db.compute_node_create')
+    @mock.patch('nova.db.compute_node_get', return_value=fake_compute_node)
+    def test_recreate_fails(self, mock_get, mock_create):
+        mock_create.return_value = fake_compute_node
         compute = compute_node.ComputeNode(context=self.context)
         compute.service_id = 456
         compute.uuid = uuidsentinel.fake_compute_node
         compute.create()
         self.assertRaises(exception.ObjectActionError, compute.create)
+        param_dict = {'service_id': 456,
+                      'uuid': uuidsentinel.fake_compute_node}
+        mock_create.assert_called_once_with(self.context, param_dict)
 
-    def test_save(self):
-        self.mox.StubOutWithMock(db, 'compute_node_update')
-        db.compute_node_update(
-            self.context, 123,
-            {
-                'vcpus_used': 3,
-                'stats': fake_stats_db_format,
-                'host_ip': fake_host_ip,
-                'supported_instances': fake_supported_hv_specs_db_format,
-                'uuid': uuidsentinel.fake_compute_node,
-            }).AndReturn(fake_compute_node)
-        self.mox.ReplayAll()
+    @mock.patch.object(db, 'compute_node_update')
+    @mock.patch('nova.db.compute_node_get', return_value=fake_compute_node)
+    def test_save(self, mock_get, mock_update):
+        mock_update.return_value = fake_compute_node
         compute = compute_node.ComputeNode(context=self.context)
         compute.id = 123
         compute.vcpus_used = 3
@@ -301,97 +328,99 @@ class _TestComputeNodeObject(object):
         self.compare_obj(compute, fake_compute_node,
                          subs=self.subs(),
                          comparators=self.comparators())
+        param_dict = {
+            'vcpus_used': 3,
+            'stats': fake_stats_db_format,
+            'host_ip': fake_host_ip,
+            'supported_instances': fake_supported_hv_specs_db_format,
+            'uuid': uuidsentinel.fake_compute_node,
+        }
+        mock_update.assert_called_once_with(self.context, 123, param_dict)
 
-    def test_query_allocates_uuid(self):
-        fake = dict(fake_compute_node)
-        fake.pop('uuid')
-        db.compute_node_create(self.context, fake)
-        with mock.patch('oslo_utils.uuidutils.generate_uuid') as mock_gu:
-            mock_gu.return_value = uuidsentinel.fake_compute_node
-            obj = objects.ComputeNode.get_by_id(self.context, fake['id'])
-            mock_gu.assert_called_once_with()
-            self.assertEqual(uuidsentinel.fake_compute_node, obj.uuid)
-            self.assertNotIn('uuid', obj.obj_get_changes())
-        with mock.patch('oslo_utils.uuidutils.generate_uuid') as mock_gu:
-            obj = objects.ComputeNode.get_by_id(self.context, fake['id'])
-            self.assertEqual(uuidsentinel.fake_compute_node, obj.uuid)
-            self.assertFalse(mock_gu.called)
-
-    def test_save_pci_device_pools_empty(self):
+    @mock.patch('nova.db.compute_node_update')
+    def test_save_pci_device_pools_empty(self, mock_update):
         fake_pci = jsonutils.dumps(
             objects.PciDevicePoolList(objects=[]).obj_to_primitive())
         compute_dict = fake_compute_node.copy()
         compute_dict['pci_stats'] = fake_pci
+        mock_update.return_value = compute_dict
 
-        with mock.patch.object(
-                db, 'compute_node_update',
-                return_value=compute_dict) as mock_compute_node_update:
-            compute = compute_node.ComputeNode(context=self.context)
-            compute.id = 123
-            compute.pci_device_pools = objects.PciDevicePoolList(objects=[])
-            compute.save()
-            self.compare_obj(compute, compute_dict,
-                             subs=self.subs(),
-                             comparators=self.comparators())
+        compute = compute_node.ComputeNode(context=self.context)
+        compute.id = 123
+        compute.pci_device_pools = objects.PciDevicePoolList(objects=[])
+        compute.save()
+        self.compare_obj(compute, compute_dict,
+                         subs=self.subs(),
+                         comparators=self.comparators())
 
-        mock_compute_node_update.assert_called_once_with(
+        mock_update.assert_called_once_with(
             self.context, 123, {'pci_stats': fake_pci})
 
-    def test_save_pci_device_pools_null(self):
+    @mock.patch('nova.db.compute_node_update')
+    def test_save_pci_device_pools_null(self, mock_update):
         compute_dict = fake_compute_node.copy()
         compute_dict['pci_stats'] = None
+        mock_update.return_value = compute_dict
 
-        with mock.patch.object(
-                db, 'compute_node_update',
-                return_value=compute_dict) as mock_compute_node_update:
-            compute = compute_node.ComputeNode(context=self.context)
-            compute.id = 123
-            compute.pci_device_pools = None
-            compute.save()
-            self.compare_obj(compute, compute_dict,
-                             subs=self.subs(),
-                             comparators=self.comparators())
+        compute = compute_node.ComputeNode(context=self.context)
+        compute.id = 123
+        compute.pci_device_pools = None
+        compute.save()
+        self.compare_obj(compute, compute_dict,
+                         subs=self.subs(),
+                         comparators=self.comparators())
 
-        mock_compute_node_update.assert_called_once_with(
+        mock_update.assert_called_once_with(
             self.context, 123, {'pci_stats': None})
 
     @mock.patch.object(db, 'compute_node_create',
                        return_value=fake_compute_node)
-    def test_set_id_failure(self, db_mock):
-        compute = compute_node.ComputeNode(context=self.context)
+    @mock.patch.object(db, 'compute_node_get',
+                       return_value=fake_compute_node)
+    def test_set_id_failure(self, mock_get, db_mock):
+        compute = compute_node.ComputeNode(context=self.context,
+                                           uuid=fake_compute_node['uuid'])
         compute.create()
         self.assertRaises(ovo_exc.ReadOnlyFieldError, setattr,
                           compute, 'id', 124)
 
-    def test_destroy(self):
-        self.mox.StubOutWithMock(db, 'compute_node_delete')
-        db.compute_node_delete(self.context, 123)
-        self.mox.ReplayAll()
+    @mock.patch.object(db, 'compute_node_delete')
+    def test_destroy(self, mock_delete):
         compute = compute_node.ComputeNode(context=self.context)
         compute.id = 123
         compute.destroy()
+        mock_delete.assert_called_once_with(self.context, 123)
 
-    def test_get_all(self):
-        self.mox.StubOutWithMock(db, 'compute_node_get_all')
-        db.compute_node_get_all(self.context).AndReturn([fake_compute_node])
-        self.mox.ReplayAll()
+    @mock.patch.object(db, 'compute_node_get_all')
+    def test_get_all(self, mock_get_all):
+        mock_get_all.return_value = [fake_compute_node]
         computes = compute_node.ComputeNodeList.get_all(self.context)
         self.assertEqual(1, len(computes))
         self.compare_obj(computes[0], fake_compute_node,
                          subs=self.subs(),
                          comparators=self.comparators())
+        mock_get_all.assert_called_once_with(self.context)
 
-    def test_get_by_hypervisor(self):
-        self.mox.StubOutWithMock(db, 'compute_node_search_by_hypervisor')
-        db.compute_node_search_by_hypervisor(self.context, 'hyper').AndReturn(
-            [fake_compute_node])
-        self.mox.ReplayAll()
+    @mock.patch.object(db, 'compute_node_search_by_hypervisor')
+    def test_get_by_hypervisor(self, mock_search):
+        mock_search.return_value = [fake_compute_node]
         computes = compute_node.ComputeNodeList.get_by_hypervisor(self.context,
                                                                   'hyper')
         self.assertEqual(1, len(computes))
         self.compare_obj(computes[0], fake_compute_node,
                          subs=self.subs(),
                          comparators=self.comparators())
+        mock_search.assert_called_once_with(self.context, 'hyper')
+
+    @mock.patch('nova.db.compute_node_get_all_by_pagination',
+                return_value=[fake_compute_node])
+    def test_get_by_pagination(self, fake_get_by_pagination):
+        computes = compute_node.ComputeNodeList.get_by_pagination(
+            self.context, limit=1, marker=1)
+        self.assertEqual(1, len(computes))
+        self.compare_obj(computes[0], fake_compute_node,
+                         subs=self.subs(),
+                         comparators=self.comparators())
 
     @mock.patch('nova.db.compute_nodes_get_by_service_id')
     def test__get_by_service(self, cn_get_by_svc_id):
@@ -544,6 +573,17 @@ class _TestComputeNodeObject(object):
         self.assertEqual(1.5, compute.ram_allocation_ratio)
         self.assertEqual(1.0, compute.disk_allocation_ratio)
 
+    def test_get_all_by_not_mapped(self):
+        for mapped in (1, 0, 1, 3):
+            compute = fake_compute_with_resources.obj_clone()
+            compute._context = self.context
+            compute.mapped = mapped
+            compute.create()
+        nodes = compute_node.ComputeNodeList.get_all_by_not_mapped(
+            self.context, 2)
+        self.assertEqual(3, len(nodes))
+        self.assertEqual([0, 1, 1], sorted([x.mapped for x in nodes]))
+
 
 class TestComputeNodeObject(test_objects._LocalTest,
                             _TestComputeNodeObject):
