@@ -17,7 +17,7 @@ import mock
 from nova import db
 from nova.objects import virtual_interface as vif_obj
 from nova.tests.unit.objects import test_objects
-
+from nova.tests import uuidsentinel as uuids
 
 fake_vif = {
     'created_at': None,
@@ -27,8 +27,9 @@ fake_vif = {
     'id': 1,
     'address': '00:00:00:00:00:00',
     'network_id': 123,
-    'instance_uuid': 'fake-uuid',
-    'uuid': 'fake-uuid-2',
+    'instance_uuid': uuids.instance,
+    'uuid': uuids.uuid,
+    'tag': 'fake-tag',
 }
 
 
@@ -70,8 +71,9 @@ class _TestVirtualInterface(object):
         vif = vif_obj.VirtualInterface(context=self.context)
         vif.address = '00:00:00:00:00:00'
         vif.network_id = 123
-        vif.instance_uuid = 'fake-uuid'
-        vif.uuid = 'fake-uuid-2'
+        vif.instance_uuid = uuids.instance
+        vif.uuid = uuids.uuid
+        vif.tag = 'fake-tag'
 
         with mock.patch.object(db, 'virtual_interface_create') as create:
             create.return_value = fake_vif
@@ -81,6 +83,40 @@ class _TestVirtualInterface(object):
         vif._context = None
         self._compare(self, fake_vif, vif)
 
+    def test_create_neutron_styyyyle(self):
+        vif = vif_obj.VirtualInterface(context=self.context)
+        vif.address = '00:00:00:00:00:00/%s' % uuids.port
+        vif.instance_uuid = uuids.instance
+        vif.uuid = uuids.uuid
+        vif.tag = 'fake-tag'
+
+        with mock.patch.object(db, 'virtual_interface_create') as create:
+            create.return_value = dict(fake_vif,
+                                       address=vif.address)
+            vif.create()
+
+        self.assertEqual(self.context, vif._context)
+        vif._context = None
+        # NOTE(danms): The actual vif should now have the namespace
+        # stripped out
+        self._compare(self, fake_vif, vif)
+
+    def test_save(self):
+        vif = vif_obj.VirtualInterface(context=self.context)
+        vif.address = '00:00:00:00:00:00'
+        vif.network_id = 123
+        vif.instance_uuid = uuids.instance_uuid
+        vif.uuid = uuids.vif_uuid
+        vif.tag = 'foo'
+        vif.create()
+
+        with mock.patch.object(db, 'virtual_interface_update') as update:
+            update.return_value = fake_vif
+            vif.tag = 'bar'
+            vif.save()
+            update.assert_called_once_with(self.context, '00:00:00:00:00:00',
+                                          {'tag': 'bar'})
+
     def test_delete_by_instance_uuid(self):
         with mock.patch.object(db,
                 'virtual_interface_delete_by_instance') as delete:
@@ -88,6 +124,31 @@ class _TestVirtualInterface(object):
                                                              'fake-uuid')
             delete.assert_called_with(self.context, 'fake-uuid')
 
+    def test_destroy(self):
+        vif = vif_obj.VirtualInterface(context=self.context)
+        vif.address = '00:00:00:00:00:00'
+        vif.network_id = 123
+        vif.instance_uuid = uuids.instance_uuid
+        vif.uuid = uuids.vif_uuid
+        vif.tag = 'foo'
+        vif.create()
+
+        vif = vif_obj.VirtualInterface.get_by_id(self.context, vif.id)
+        vif.destroy()
+        self.assertIsNone(vif_obj.VirtualInterface.get_by_id(self.context,
+                                                             vif.id))
+
+    def test_obj_make_compatible_pre_1_1(self):
+        vif = vif_obj.VirtualInterface(context=self.context)
+        vif.address = '00:00:00:00:00:00'
+        vif.network_id = 123
+        vif.instance_uuid = uuids.instance
+        vif.uuid = uuids.uuid
+        vif.tag = 'fake-tag'
+
+        primitive = vif.obj_to_primitive(target_version='1.0')
+        self.assertNotIn('tag', primitive)
+
 
 class TestVirtualInterfaceObject(test_objects._LocalTest,
                                  _TestVirtualInterface):
