@@ -47,7 +47,7 @@ class SchedulerClientTestCase(test.NoDBTestCase):
 
         self.assertIsNotNone(self.client.queryclient.instance)
         mock_select_destinations.assert_called_once_with('ctxt', fake_spec,
-                [fake_spec.instance_uuid])
+                [fake_spec.instance_uuid], False, False)
 
     @mock.patch.object(scheduler_query_client.SchedulerQueryClient,
                        'select_destinations',
@@ -56,7 +56,8 @@ class SchedulerClientTestCase(test.NoDBTestCase):
         # check if the scheduler service times out properly
         fake_spec = objects.RequestSpec()
         fake_spec.instance_uuid = uuids.instance
-        fake_args = ['ctxt', fake_spec, [fake_spec.instance_uuid]]
+        fake_args = ['ctxt', fake_spec, [fake_spec.instance_uuid], False,
+                False]
         self.assertRaises(messaging.MessagingTimeout,
                           self.client.select_destinations, *fake_args)
         mock_select_destinations.assert_has_calls([mock.call(*fake_args)] * 2)
@@ -68,7 +69,8 @@ class SchedulerClientTestCase(test.NoDBTestCase):
         # scenario: the scheduler service times out & recovers after failure
         fake_spec = objects.RequestSpec()
         fake_spec.instance_uuid = uuids.instance
-        fake_args = ['ctxt', fake_spec, [fake_spec.instance_uuid]]
+        fake_args = ['ctxt', fake_spec, [fake_spec.instance_uuid], False,
+                False]
         self.client.select_destinations(*fake_args)
         mock_select_destinations.assert_has_calls([mock.call(*fake_args)] * 2)
 
@@ -97,21 +99,41 @@ class SchedulerClientTestCase(test.NoDBTestCase):
     def test_update_compute_node(self, mock_update_compute_node):
         self.assertIsNone(self.client.reportclient.instance)
 
-        self.client.update_compute_node(mock.sentinel.cn)
+        self.client.update_compute_node(mock.sentinel.ctx, mock.sentinel.cn)
 
         self.assertIsNotNone(self.client.reportclient.instance)
-        mock_update_compute_node.assert_called_once_with(mock.sentinel.cn)
+        mock_update_compute_node.assert_called_once_with(
+            mock.sentinel.ctx, mock.sentinel.cn)
 
     @mock.patch.object(scheduler_report_client.SchedulerReportClient,
                        'set_inventory_for_provider')
     def test_set_inventory_for_provider(self, mock_set):
         self.client.set_inventory_for_provider(
+            mock.sentinel.ctx,
             mock.sentinel.rp_uuid,
             mock.sentinel.rp_name,
             mock.sentinel.inv_data,
         )
         mock_set.assert_called_once_with(
+            mock.sentinel.ctx,
             mock.sentinel.rp_uuid,
             mock.sentinel.rp_name,
             mock.sentinel.inv_data,
+            parent_provider_uuid=None,
+        )
+        # Pass the optional parent_provider_uuid
+        mock_set.reset_mock()
+        self.client.set_inventory_for_provider(
+            mock.sentinel.ctx,
+            mock.sentinel.child_uuid,
+            mock.sentinel.child_name,
+            mock.sentinel.inv_data2,
+            parent_provider_uuid=mock.sentinel.rp_uuid,
+        )
+        mock_set.assert_called_once_with(
+            mock.sentinel.ctx,
+            mock.sentinel.child_uuid,
+            mock.sentinel.child_name,
+            mock.sentinel.inv_data2,
+            parent_provider_uuid=mock.sentinel.rp_uuid,
         )
