@@ -14,8 +14,8 @@
 #    under the License.
 
 import os
-import uuid
 
+import fixtures
 import mock
 from oslo_config import cfg
 from oslo_utils import units
@@ -25,6 +25,7 @@ from nova import objects
 from nova.tests.unit import fake_instance
 from nova.tests.unit.objects import test_flavor
 from nova.tests.unit.virt.hyperv import test_base
+from nova.tests import uuidsentinel as uuids
 from nova.virt.hyperv import constants
 from nova.virt.hyperv import imagecache
 
@@ -34,7 +35,6 @@ CONF = cfg.CONF
 class ImageCacheTestCase(test_base.HyperVBaseTestCase):
     """Unit tests for the Hyper-V ImageCache class."""
 
-    FAKE_BASE_DIR = 'fake/base/dir'
     FAKE_FORMAT = 'fake_format'
     FAKE_IMAGE_REF = 'fake_image_ref'
     FAKE_VHD_SIZE_GB = 1
@@ -61,6 +61,8 @@ class ImageCacheTestCase(test_base.HyperVBaseTestCase):
         self.imagecache._pathutils = mock.MagicMock()
         self.imagecache._vhdutils = mock.MagicMock()
 
+        self.tmpdir = self.useFixture(fixtures.TempDir()).path
+
     def _test_get_root_vhd_size_gb(self, old_flavor=True):
         if old_flavor:
             mock_flavor = objects.Flavor(**test_flavor.fake_flavor)
@@ -102,7 +104,7 @@ class ImageCacheTestCase(test_base.HyperVBaseTestCase):
                                   rescue_image_id=None):
         self.instance.image_ref = self.FAKE_IMAGE_REF
         self.imagecache._pathutils.get_base_vhd_dir.return_value = (
-            self.FAKE_BASE_DIR)
+            self.tmpdir)
         self.imagecache._pathutils.exists.return_value = path_exists
         self.imagecache._vhdutils.get_vhd_format.return_value = (
             constants.DISK_FORMAT_VHD)
@@ -110,7 +112,7 @@ class ImageCacheTestCase(test_base.HyperVBaseTestCase):
         CONF.set_override('use_cow_images', use_cow)
 
         image_file_name = rescue_image_id or self.FAKE_IMAGE_REF
-        expected_path = os.path.join(self.FAKE_BASE_DIR,
+        expected_path = os.path.join(self.tmpdir,
                                      image_file_name)
         expected_vhd_path = "%s.%s" % (expected_path,
                                        constants.DISK_FORMAT_VHD.lower())
@@ -195,7 +197,7 @@ class ImageCacheTestCase(test_base.HyperVBaseTestCase):
         self.imagecache._age_and_verify_cached_images(
             mock.sentinel.FAKE_CONTEXT,
             mock.sentinel.all_instances,
-            mock.sentinel.FAKE_BASE_DIR)
+            mock.sentinel.tmpdir)
 
         self.imagecache._update_image_timestamp.assert_called_once_with(
             mock.sentinel.FAKE_IMG1)
@@ -243,7 +245,7 @@ class ImageCacheTestCase(test_base.HyperVBaseTestCase):
         mock_get_backing_files.assert_called_once_with(mock.sentinel.image)
 
     def test_remove_old_image(self):
-        fake_img_path = os.path.join(self.FAKE_BASE_DIR,
+        fake_img_path = os.path.join(self.tmpdir,
                                      self.FAKE_IMAGE_REF)
         self.imagecache._remove_old_image(fake_img_path)
         self.imagecache._pathutils.remove.assert_called_once_with(
@@ -278,7 +280,7 @@ class ImageCacheTestCase(test_base.HyperVBaseTestCase):
 
     @mock.patch.object(imagecache.os, 'listdir')
     def test_list_base_images(self, mock_listdir):
-        original_image = str(uuid.uuid4())
+        original_image = uuids.fake
         unexplained_image = 'just-an-image'
         ignored_file = 'foo.bar'
         mock_listdir.return_value = ['%s.VHD' % original_image,
