@@ -150,7 +150,8 @@ class LibvirtNetVolumeDriverTestCase(
         secret_uuid wasn't set on the cinder side for the original connection
         which is now persisted in the
         nova.block_device_mappings.connection_info column and used here. In
-        this case we fallback to use the local config for secret_uuid.
+        this case we fallback to use the local config for secret_uuid and
+        username.
         """
         libvirt_driver = net.LibvirtNetVolumeDriver(self.fake_host)
         connection_info = self.rbd_connection(self.vol)
@@ -170,7 +171,7 @@ class LibvirtNetVolumeDriverTestCase(
         conf = libvirt_driver.get_config(connection_info, self.disk_info)
         tree = conf.format_dom()
         self._assertNetworkAndProtocolEquals(tree)
-        self.assertEqual(self.user, tree.find('./auth').get('username'))
+        self.assertEqual(flags_user, tree.find('./auth').get('username'))
         self.assertEqual(secret_type, tree.find('./auth/secret').get('type'))
         # Assert that the secret_uuid comes from CONF.libvirt.rbd_secret_uuid.
         self.assertEqual(flags_uuid, tree.find('./auth/secret').get('uuid'))
