@@ -654,8 +654,6 @@ class _VirtDriverTestCase(_FakeDriverBackendTestCase):
 
     def test_live_migration(self):
         instance_ref, network_info = self._get_running_instance()
-        instance_ref.info_cache = objects.InstanceInfoCache(
-            network_info=network_info)
         fake_context = context.RequestContext('fake', 'fake')
         migration = objects.Migration(context=fake_context, id=1)
         migrate_data = objects.LibvirtLiveMigrateData(
@@ -891,6 +889,7 @@ class LibvirtConnTestCase(_VirtDriverTestCase, test.TestCase):
         # will try to execute some commands which hangs tests so let's just
         # stub out the unplug call to os-vif since we don't care about it.
         self.stub_out('os_vif.unplug', lambda a, kw: None)
+        self.stub_out('nova.compute.utils.get_machine_ips', lambda: [])
 
     def _fake_admin_context(self, *args, **kwargs):
         return self.ctxt
