@@ -239,7 +239,9 @@ class VMwareImagesTestCase(test.NoDBTestCase):
                      "hw_vif_model": constants.DEFAULT_VIF_MODEL,
                      "vmware_linked_clone": True}}
         mdata = objects.ImageMeta.from_dict(mdata)
-        img_props = images.VMwareImage.from_image(image_id, mdata)
+        with mock.patch.object(images, 'get_vsphere_location',
+                               return_value=None):
+            img_props = images.VMwareImage.from_image(None, image_id, mdata)
 
         image_size_in_kb = raw_disk_size_in_bytes / units.Ki
 
@@ -257,7 +259,8 @@ class VMwareImagesTestCase(test.NoDBTestCase):
                      os_type=constants.DEFAULT_OS_TYPE,
                      adapter_type=constants.DEFAULT_ADAPTER_TYPE,
                      disk_type=constants.DEFAULT_DISK_TYPE,
-                     vif_model=constants.DEFAULT_VIF_MODEL):
+                     vif_model=constants.DEFAULT_VIF_MODEL,
+                     vsphere_location=None):
         self.flags(use_linked_clone=global_lc_setting, group='vmware')
         raw_disk_size_in_gb = 93
         raw_disk_size_in_btyes = raw_disk_size_in_gb * units.Gi
@@ -274,8 +277,11 @@ class VMwareImagesTestCase(test.NoDBTestCase):
         if image_lc_setting is not None:
             mdata['properties']["vmware_linked_clone"] = image_lc_setting
 
+        context = mock.Mock()
         mdata = objects.ImageMeta.from_dict(mdata)
-        return images.VMwareImage.from_image(image_id, mdata)
+        with mock.patch.object(
+                images, 'get_vsphere_location', return_value=vsphere_location):
+            return images.VMwareImage.from_image(context, image_id, mdata)
 
     def test_use_linked_clone_override_nf(self):
         image_props = self._image_build(None, False)
@@ -343,3 +349,27 @@ class VMwareImagesTestCase(test.NoDBTestCase):
         self.assertEqual('lsiLogic', image.adapter_type)
         self.assertEqual('preallocated', image.disk_type)
         self.assertEqual('e1000', image.vif_model)
+
+    def test_use_vsphere_location(self):
+        image = self._image_build(None, True, vsphere_location='vsphere://ok')
+        self.assertEqual('vsphere://ok', image.vsphere_location)
+
+    def test_get_vsphere_location(self):
+        expected = 'vsphere://ok'
+        metadata = {'locations': [{}, {'url': 'http://ko'}, {'url': expected}]}
+        with mock.patch.object(images.IMAGE_API, 'get', return_value=metadata):
+            context = mock.Mock()
+            observed = images.get_vsphere_location(context, 'image_id')
+            self.assertEqual(expected, observed)
+
+    def test_get_no_vsphere_location(self):
+        metadata = {'locations': [{}, {'url': 'http://ko'}]}
+        with mock.patch.object(images.IMAGE_API, 'get', return_value=metadata):
+            context = mock.Mock()
+            observed = images.get_vsphere_location(context, 'image_id')
+            self.assertIsNone(observed)
+
+    def test_get_vsphere_location_no_image(self):
+        context = mock.Mock()
+        observed = images.get_vsphere_location(context, None)
+        self.assertIsNone(observed)
