@@ -18,12 +18,15 @@ import math
 import mock
 from oslo_utils import units
 
+from nova import exception
 from nova.objects import fields as obj_fields
 from nova.tests.unit.virt.xenapi import stubs
+from nova.tests import uuidsentinel as uuids
 from nova.virt import driver
 from nova.virt import fake
 from nova.virt import xenapi
 from nova.virt.xenapi import driver as xenapi_driver
+from nova.virt.xenapi import host
 
 
 class XenAPIDriverTestCase(stubs.XenAPITestBaseNoDB):
@@ -31,7 +34,7 @@ class XenAPIDriverTestCase(stubs.XenAPITestBaseNoDB):
 
     def _get_driver(self):
         stubs.stubout_session(self.stubs, stubs.FakeSessionForVMTests)
-        self.flags(connection_url='test_url',
+        self.flags(connection_url='http://localhost',
                    connection_password='test_pass', group='xenserver')
         return xenapi.XenAPIDriver(fake.FakeVirtAPI(), False)
 
@@ -66,7 +69,16 @@ class XenAPIDriverTestCase(stubs.XenAPITestBaseNoDB):
                 },
                 'vcpus_used': 10,
                 'pci_passthrough_devices': '',
-                'host_other-config': {'iscsi_iqn': 'someiqn'}}
+                'host_other-config': {'iscsi_iqn': 'someiqn'},
+                'vgpu_stats': {
+                    'c8328467-badf-43d8-8e28-0e096b0f88b1':
+                        {'uuid': '6444c6ee-3a49-42f5-bebb-606b52175e67',
+                         'type_name': 'Intel GVT-g',
+                         'max_heads': 1,
+                         'total': 7,
+                         'remaining': 7,
+                         },
+                     }}
 
     def test_available_resource(self):
         driver = self._get_driver()
@@ -235,3 +247,176 @@ class XenAPIDriverTestCase(stubs.XenAPITestBaseNoDB):
         mock_rollback.assert_called_once_with('fake_instance',
                                               'fake_network_info',
                                               'fake_block_device')
+
+    @mock.patch.object(host.HostState, 'get_host_stats')
+    def test_get_inventory(self, mock_get_stats):
+        expected_inv = {
+            obj_fields.ResourceClass.VCPU: {
+                'total': 50,
+                'min_unit': 1,
+                'max_unit': 50,
+                'step_size': 1,
+            },
+            obj_fields.ResourceClass.MEMORY_MB: {
+                'total': 3,
+                'min_unit': 1,
+                'max_unit': 3,
+                'step_size': 1,
+            },
+            obj_fields.ResourceClass.DISK_GB: {
+                'total': 5,
+                'min_unit': 1,
+                'max_unit': 5,
+                'step_size': 1,
+            },
+            obj_fields.ResourceClass.VGPU: {
+                'total': 7,
+                'min_unit': 1,
+                'max_unit': 1,
+                'step_size': 1,
+            },
+        }
+
+        mock_get_stats.side_effect = self.host_stats
+        drv = self._get_driver()
+        inv = drv.get_inventory(mock.sentinel.nodename)
+
+        mock_get_stats.assert_called_once_with(refresh=True)
+        self.assertEqual(expected_inv, inv)
+
+    @mock.patch.object(host.HostState, 'get_host_stats')
+    def test_get_inventory_no_vgpu(self, mock_get_stats):
+        # Test when there are no vGPU resources in the inventory.
+        host_stats = self.host_stats()
+        host_stats.update(vgpu_stats={})
+        mock_get_stats.return_value = host_stats
+
+        drv = self._get_driver()
+        inv = drv.get_inventory(mock.sentinel.nodename)
+
+        # check if the inventory data does NOT contain VGPU.
+        self.assertNotIn(obj_fields.ResourceClass.VGPU, inv)
+
+    def test_get_vgpu_total_single_grp(self):
+        # Test when only one group included in the host_stats.
+        vgpu_stats = {
+            'grp_uuid_1': {
+                'total': 7
+            }
+        }
+
+        drv = self._get_driver()
+        vgpu_total = drv._get_vgpu_total(vgpu_stats)
+
+        self.assertEqual(7, vgpu_total)
+
+    def test_get_vgpu_total_multiple_grps(self):
+        # Test when multiple groups included in the host_stats.
+        vgpu_stats = {
+            'grp_uuid_1': {
+                'total': 7
+            },
+            'grp_uuid_2': {
+                'total': 4
+            }
+        }
+
+        drv = self._get_driver()
+        vgpu_total = drv._get_vgpu_total(vgpu_stats)
+
+        self.assertEqual(11, vgpu_total)
+
+    def test_get_vgpu_info_no_vgpu_alloc(self):
+        # no vgpu in allocation.
+        alloc = {
+            'rp1': {
+                'resources': {
+                    'VCPU': 1,
+                    'MEMORY_MB': 512,
+                    'DISK_GB': 1,
+                }
+            }
+        }
+
+        drv = self._get_driver()
+        vgpu_info = drv._get_vgpu_info(alloc)
+
+        self.assertIsNone(vgpu_info)
+
+    @mock.patch.object(host.HostState, 'get_host_stats')
+    def test_get_vgpu_info_has_vgpu_alloc(self, mock_get_stats):
+        # Have vgpu in allocation.
+        alloc = {
+            'rp1': {
+                'resources': {
+                    'VCPU': 1,
+                    'MEMORY_MB': 512,
+                    'DISK_GB': 1,
+                    'VGPU': 1,
+                }
+            }
+        }
+        # The following fake data assumes there are two GPU
+        # groups both of which supply the same type of vGPUs.
+        # If the 1st GPU group has no remaining available vGPUs;
+        # the 2nd GPU group still has remaining available vGPUs.
+        # it should return the uuid from the 2nd GPU group.
+        vgpu_stats = {
+            uuids.gpu_group_1: {
+                'uuid': uuids.vgpu_type,
+                'type_name': 'GRID K180Q',
+                'max_heads': 4,
+                'total': 2,
+                'remaining': 0,
+            },
+            uuids.gpu_group_2: {
+                'uuid': uuids.vgpu_type,
+                'type_name': 'GRID K180Q',
+                'max_heads': 4,
+                'total': 2,
+                'remaining': 2,
+            },
+        }
+
+        host_stats = self.host_stats()
+        host_stats.update(vgpu_stats=vgpu_stats)
+        mock_get_stats.return_value = host_stats
+
+        drv = self._get_driver()
+        vgpu_info = drv._get_vgpu_info(alloc)
+
+        expected_info = {'gpu_grp_uuid': uuids.gpu_group_2,
+                         'vgpu_type_uuid': uuids.vgpu_type}
+        self.assertEqual(expected_info, vgpu_info)
+
+    @mock.patch.object(host.HostState, 'get_host_stats')
+    def test_get_vgpu_info_has_vgpu_alloc_except(self, mock_get_stats):
+        # Allocated vGPU but got exception due to no remaining vGPU.
+        alloc = {
+            'rp1': {
+                'resources': {
+                    'VCPU': 1,
+                    'MEMORY_MB': 512,
+                    'DISK_GB': 1,
+                    'VGPU': 1,
+                }
+            }
+        }
+        vgpu_stats = {
+            uuids.gpu_group: {
+                'uuid': uuids.vgpu_type,
+                'type_name': 'Intel GVT-g',
+                'max_heads': 1,
+                'total': 7,
+                'remaining': 0,
+            },
+        }
+
+        host_stats = self.host_stats()
+        host_stats.update(vgpu_stats=vgpu_stats)
+        mock_get_stats.return_value = host_stats
+
+        drv = self._get_driver()
+        self.assertRaises(exception.ComputeResourcesUnavailable,
+                          drv._get_vgpu_info,
+                          alloc)
