@@ -146,7 +146,7 @@ class ParseVolumeInfoTestCase(stubs.XenAPITestBaseNoDB):
             'xvdq': -1,
         }
 
-        for (input, expected) in six.iteritems(cases):
+        for (input, expected) in cases.items():
             actual = volume_utils._mountpoint_to_number(input)
             self.assertEqual(actual, expected,
                     '%s yielded %s, not %s' % (input, actual, expected))
