@@ -18,10 +18,13 @@ import random
 import re
 import time
 
+from oslo_concurrency import processutils
 from oslo_log import log as logging
+import six
 
 import nova.conf
 from nova.i18n import _
+import nova.privsep.fs
 from nova import utils
 from nova.virt.disk.mount import api
 
@@ -36,9 +39,10 @@ class NbdMount(api.Mount):
     """qemu-nbd support disk images."""
     mode = 'nbd'
 
-    def _detect_nbd_devices(self):
+    @staticmethod
+    def _detect_nbd_devices():
         """Detect nbd device files."""
-        return filter(NBD_DEVICE_RE.match, os.listdir('/sys/block/'))
+        return list(filter(NBD_DEVICE_RE.match, os.listdir('/sys/block/')))
 
     def _find_unused(self, devices):
         for device in devices:
@@ -76,9 +80,11 @@ class NbdMount(api.Mount):
         # already in use.
         LOG.debug('Get nbd device %(dev)s for %(imgfile)s',
                   {'dev': device, 'imgfile': self.image.path})
-        _out, err = utils.trycmd('qemu-nbd', '-c', device,
-                                 self.image.path,
-                                 run_as_root=True)
+        try:
+            _out, err = nova.privsep.fs.nbd_connect(device, self.image.path)
+        except processutils.ProcessExecutionError as exc:
+            err = six.text_type(exc)
+
         if err:
             self.error = _('qemu-nbd error: %s') % err
             LOG.info('NBD mount error: %s', self.error)
@@ -97,8 +103,11 @@ class NbdMount(api.Mount):
             LOG.info('NBD mount error: %s', self.error)
 
             # Cleanup
-            _out, err = utils.trycmd('qemu-nbd', '-d', device,
-                                     run_as_root=True)
+            try:
+                _out, err = nova.privsep.fs.nbd_disconnect(device)
+            except processutils.ProcessExecutionError as exc:
+                err = six.text_type(exc)
+
             if err:
                 LOG.warning('Detaching from erroneous nbd device returned '
                             'error: %s', err)
@@ -116,7 +125,7 @@ class NbdMount(api.Mount):
         if not self.linked:
             return
         LOG.debug('Release nbd device %s', self.device)
-        utils.execute('qemu-nbd', '-d', self.device, run_as_root=True)
+        nova.privsep.fs.nbd_disconnect(self.device)
         self.linked = False
         self.device = None
 
@@ -126,5 +135,4 @@ class NbdMount(api.Mount):
         # Without this flush, when a nbd device gets re-used the
         # qemu-nbd intermittently hangs.
         if self.device:
-            utils.execute('blockdev', '--flushbufs',
-                          self.device, run_as_root=True)
+            nova.privsep.fs.blockdev_flush(self.device)
