@@ -48,6 +48,11 @@ CONF = nova.conf.CONF
 MIN_LIBVIRT_VHOSTUSER_MQ = (1, 2, 17)
 #  vlan tag for macvtap passthrough mode on SRIOV VFs
 MIN_LIBVIRT_MACVTAP_PASSTHROUGH_VLAN = (1, 3, 5)
+# setting interface mtu was intoduced in libvirt 3.3, We also need to
+# check for QEMU that because libvirt is configuring in same time
+# host_mtu for virtio-net, fails if not supported.
+MIN_LIBVIRT_INTERFACE_MTU = (3, 3, 0)
+MIN_QEMU_INTERFACE_MTU = (2, 9, 0)
 
 
 def is_vif_model_valid_for_virt(virt_type, vif_model):
@@ -237,8 +242,24 @@ class LibvirtGenericVIFDriver(object):
             conf.filtername = name
         designer.set_vif_bandwidth_config(conf, inst_type)
 
+        self._set_mtu_config(vif, host, conf)
+
         return conf
 
+    def _set_mtu_config(self, vif, host, conf):
+        """:param vif: nova.network.modle.vif
+           :param host: nova.virt.libvirt.host.Host
+           :param conf: nova.virt.libvirt.config.LibvirtConfigGuestInterface
+        """
+        network = vif.get('network')
+        if (network and network.get_meta("mtu") and
+                self._has_min_version_for_mtu(host)):
+            designer.set_vif_mtu_config(conf, network.get_meta("mtu"))
+
+    def _has_min_version_for_mtu(self, host):
+        return host.has_min_version(MIN_LIBVIRT_INTERFACE_MTU,
+                                    MIN_QEMU_INTERFACE_MTU)
+
     def get_config_ivs_hybrid(self, instance, vif, image_meta,
                               inst_type, virt_type, host):
         newvif = copy.deepcopy(vif)
@@ -404,6 +425,8 @@ class LibvirtGenericVIFDriver(object):
         dev = self.get_vif_devname(vif)
         designer.set_vif_host_backend_ethernet_config(conf, dev, host)
 
+        self._set_mtu_config(vif, host, conf)
+
         return conf
 
     def _get_vhostuser_settings(self, vif):
@@ -530,6 +553,9 @@ class LibvirtGenericVIFDriver(object):
         func(instance, vif, conf, host)
 
         designer.set_vif_bandwidth_config(conf, inst_type)
+        if ('network' in vif and 'mtu' in vif.network and
+                self._has_min_version_for_mtu(host)):
+            designer.set_vif_mtu_config(conf, vif.network.mtu)
 
         return conf
 
