@@ -56,21 +56,16 @@ def _get_first_network(network, version):
         pass
 
 
-def get_injected_network_template(network_info, use_ipv6=None, template=None,
+def get_injected_network_template(network_info, template=None,
                                   libvirt_virt_type=None):
     """Returns a rendered network template for the given network_info.
 
     :param network_info:
         :py:meth:`~nova.network.manager.NetworkManager.get_instance_nw_info`
-    :param use_ipv6: If False, do not return IPv6 template information
-        even if an IPv6 subnet is present in network_info.
     :param template: Path to the interfaces template file.
     :param libvirt_virt_type: The Libvirt `virt_type`, will be `None` for
         other hypervisors..
     """
-    if use_ipv6 is None:
-        use_ipv6 = CONF.use_ipv6
-
     if not template:
         template = CONF.injected_network_template
 
@@ -128,8 +123,7 @@ def get_injected_network_template(network_info, use_ipv6=None, template=None,
         gateway_v6 = ''
         netmask_v6 = None
         dns_v6 = None
-        have_ipv6 = (use_ipv6 and subnet_v6)
-        if have_ipv6:
+        if subnet_v6:
             if subnet_v6.get_meta('dhcp_server') is not None:
                 continue
 
@@ -161,15 +155,16 @@ def get_injected_network_template(network_info, use_ipv6=None, template=None,
         return
 
     tmpl_path, tmpl_file = os.path.split(template)
-    env = jinja2.Environment(loader=jinja2.FileSystemLoader(tmpl_path),
-                             trim_blocks=True)
+    env = jinja2.Environment(  # nosec
+        loader=jinja2.FileSystemLoader(tmpl_path),  # nosec
+        trim_blocks=True)
     template = env.get_template(tmpl_file)
     return template.render({'interfaces': nets,
                             'use_ipv6': ipv6_is_available,
                             'libvirt_virt_type': libvirt_virt_type})
 
 
-def get_network_metadata(network_info, use_ipv6=None):
+def get_network_metadata(network_info):
     """Gets a more complete representation of the instance network information.
 
     This data is exposed as network_data.json in the metadata service and
@@ -177,16 +172,10 @@ def get_network_metadata(network_info, use_ipv6=None):
 
     :param network_info: `nova.network.models.NetworkInfo` object describing
         the network metadata.
-    :param use_ipv6: If False, do not return IPv6 template information
-        even if an IPv6 subnet is present in network_info. Defaults to
-        nova.netconf.use_ipv6.
     """
     if not network_info:
         return
 
-    if use_ipv6 is None:
-        use_ipv6 = CONF.use_ipv6
-
     # IPv4 or IPv6 networks
     nets = []
     # VIFs, physical NICs, or VLANs. Physical NICs will have type 'phy'.
@@ -221,7 +210,7 @@ def get_network_metadata(network_info, use_ipv6=None):
             nets.append(_get_nets(vif, subnet_v4, 4, net_num, link['id']))
             services += [dns for dns in _get_dns_services(subnet_v4)
                          if dns not in services]
-        if (use_ipv6 and subnet_v6) and subnet_v6.get('ips'):
+        if subnet_v6 and subnet_v6.get('ips'):
             net_num += 1
             nets.append(_get_nets(vif, subnet_v6, 6, net_num, link['id']))
             services += [dns for dns in _get_dns_services(subnet_v6)
@@ -273,7 +262,10 @@ def _get_nets(vif, subnet, version, net_num, link_id):
     :param link_id: Arbitrary identifier for the link the networks are
         attached to
     """
-    if subnet.get_meta('dhcp_server') is not None:
+    net_type = ''
+    if subnet.get_meta('ipv6_address_mode') is not None:
+        net_type = '_%s' % subnet.get_meta('ipv6_address_mode')
+    elif subnet.get_meta('dhcp_server') is not None:
         net_info = {
             'id': 'network%d' % net_num,
             'type': 'ipv%d_dhcp' % version,
@@ -291,7 +283,7 @@ def _get_nets(vif, subnet, version, net_num, link_id):
 
     net_info = {
         'id': 'network%d' % net_num,
-        'type': 'ipv%d' % version,
+        'type': 'ipv%d%s' % (version, net_type),
         'link': link_id,
         'ip_address': address,
         'netmask': netmask,
@@ -309,6 +301,8 @@ def _get_nets(vif, subnet, version, net_num, link_id):
         }
         net_info['routes'].append(new_route)
 
+    net_info['services'] = _get_dns_services(subnet)
+
     return net_info
 
 
