@@ -284,10 +284,9 @@ class VMwareVCDriver(driver.ComputeDriver):
             LOG.warning('The console log is missing. Check your VSPC '
                         'configuration', instance=instance)
             return b""
-        with open(path, 'rb') as fp:
-            read_log_data, remaining = nova.privsep.path.last_bytes(
-                fp, MAX_CONSOLE_BYTES)
-            return read_log_data
+        read_log_data, remaining = nova.privsep.path.last_bytes(
+            path, MAX_CONSOLE_BYTES)
+        return read_log_data
 
     def _get_vcenter_uuid(self):
         """Retrieves the vCenter UUID."""
@@ -399,6 +398,8 @@ class VMwareVCDriver(driver.ComputeDriver):
     def detach_volume(self, context, connection_info, instance, mountpoint,
                       encryption=None):
         """Detach volume storage to VM instance."""
+        # NOTE(claudiub): if context parameter is to be used in the future,
+        # the _detach_instance_volumes method will have to be updated as well.
         return self._volumeops.detach_volume(connection_info, instance)
 
     def get_volume_connector(self, instance):
@@ -430,7 +431,9 @@ class VMwareVCDriver(driver.ComputeDriver):
             for disk in block_device_mapping:
                 connection_info = disk['connection_info']
                 try:
-                    self.detach_volume(connection_info, instance,
+                    # NOTE(claudiub): Passing None as the context, as it is
+                    # not currently used.
+                    self.detach_volume(None, connection_info, instance,
                                        disk.get('device_name'))
                 except exception.DiskNotFound:
                     LOG.warning('The volume %s does not exist!',
