@@ -46,6 +46,7 @@ from nova import exception
 from nova.i18n import _
 from nova import network
 from nova import objects
+from nova.objects import fields
 from nova import utils
 from nova import version
 from nova.virt import configdrive
@@ -317,6 +318,11 @@ class VMwareVMOps(object):
         extra_specs.memory_limits.validate()
         extra_specs.disk_io_limits.validate()
         extra_specs.vif_limits.validate()
+        hw_firmware_type = image_meta.properties.get('hw_firmware_type')
+        if hw_firmware_type == fields.FirmwareType.UEFI:
+            extra_specs.firmware = 'efi'
+        elif hw_firmware_type == fields.FirmwareType.BIOS:
+            extra_specs.firmware = 'bios'
         hw_version = flavor.extra_specs.get('vmware:hw_version')
         extra_specs.hw_version = hw_version
         if CONF.vmware.pbm_enabled:
@@ -1244,13 +1250,80 @@ class VMwareVMOps(object):
         if power_on:
             vm_util.power_on_instance(self._session, instance, vm_ref=vm_ref)
 
-    def power_off(self, instance):
+    def power_off(self, instance, timeout=0, retry_interval=0):
         """Power off the specified instance.
 
         :param instance: nova.objects.instance.Instance
+        :param timeout: How long to wait in seconds for the instance to
+                        shutdown
+        :param retry_interval: Interval to check if instance is already
+                               shutdown in seconds.
         """
+        if timeout and self._clean_shutdown(instance,
+                                            timeout,
+                                            retry_interval):
+            return
+
         vm_util.power_off_instance(self._session, instance)
 
+    def _clean_shutdown(self, instance, timeout, retry_interval):
+        """Perform a soft shutdown on the VM.
+        :param instance: nova.objects.instance.Instance
+        :param timeout: How long to wait in seconds for the instance to
+                        shutdown
+        :param retry_interval: Interval to check if instance is already
+                               shutdown in seconds.
+           :return: True if the instance was shutdown within time limit,
+                    False otherwise.
+        """
+        LOG.debug("Performing Soft shutdown on instance",
+                 instance=instance)
+        vm_ref = vm_util.get_vm_ref(self._session, instance)
+
+        props = self._get_instance_props(vm_ref)
+
+        if props.get("runtime.powerState") != "poweredOn":
+            LOG.debug("Instance not in poweredOn state.",
+                      instance=instance)
+            return False
+
+        if ((props.get("summary.guest.toolsStatus") == "toolsOk") and
+            (props.get("summary.guest.toolsRunningStatus") ==
+             "guestToolsRunning")):
+
+            LOG.debug("Soft shutdown instance, timeout: %d",
+                     timeout, instance=instance)
+            self._session._call_method(self._session.vim,
+                                       "ShutdownGuest",
+                                       vm_ref)
+
+            while timeout > 0:
+                wait_time = min(retry_interval, timeout)
+                props = self._get_instance_props(vm_ref)
+
+                if props.get("runtime.powerState") == "poweredOff":
+                    LOG.info("Soft shutdown succeeded.",
+                             instance=instance)
+                    return True
+
+                time.sleep(wait_time)
+                timeout -= retry_interval
+
+            LOG.warning("Timed out while waiting for soft shutdown.",
+                        instance=instance)
+        else:
+            LOG.debug("VMware Tools not running", instance=instance)
+
+        return False
+
+    def _get_instance_props(self, vm_ref):
+        lst_properties = ["summary.guest.toolsStatus",
+                          "runtime.powerState",
+                          "summary.guest.toolsRunningStatus"]
+        return self._session._call_method(vutil,
+                                          "get_object_properties_dict",
+                                          vm_ref, lst_properties)
+
     def power_on(self, instance):
         vm_util.power_on_instance(self._session, instance)
 
@@ -1497,9 +1570,7 @@ class VMwareVMOps(object):
         """Return data about the VM instance."""
         vm_ref = vm_util.get_vm_ref(self._session, instance)
 
-        lst_properties = ["summary.config.numCpu",
-                    "summary.config.memorySizeMB",
-                    "runtime.powerState"]
+        lst_properties = ["runtime.powerState"]
         try:
             vm_props = self._session._call_method(vutil,
                                                   "get_object_properties_dict",
@@ -1507,13 +1578,8 @@ class VMwareVMOps(object):
                                                   lst_properties)
         except vexc.ManagedObjectNotFoundException:
             raise exception.InstanceNotFound(instance_id=instance.uuid)
-        max_mem = int(vm_props.get('summary.config.memorySizeMB', 0)) * 1024
-        num_cpu = int(vm_props.get('summary.config.numCpu', 0))
         return hardware.InstanceInfo(
-            state=constants.POWER_STATES[vm_props['runtime.powerState']],
-            max_mem_kb=max_mem,
-            mem_kb=max_mem,
-            num_cpu=num_cpu)
+            state=constants.POWER_STATES[vm_props['runtime.powerState']])
 
     def _get_diagnostics(self, instance):
         """Return data about VM diagnostics."""
@@ -1643,17 +1709,6 @@ class VMwareVMOps(object):
             self._datastore_browser_mapping[ds_ref.value] = ds_browser
         return ds_browser
 
-    def _get_host_ref_from_name(self, host_name):
-        """Get reference to the host with the name specified."""
-        host_objs = self._session._call_method(vim_util, "get_objects",
-                    "HostSystem", ["name"])
-        vm_util._cancel_retrieve_if_necessary(self._session, host_objs)
-        for host in host_objs:
-            if hasattr(host, 'propSet'):
-                if host.propSet[0].val == host_name:
-                    return host.obj
-        return None
-
     def _create_folder_if_missing(self, ds_name, ds_ref, folder):
         """Create a folder if it does not exist.
 
