@@ -25,7 +25,7 @@ import six.moves.urllib.parse as urlparse
 from nova.compute import rpcapi as compute_rpcapi
 import nova.conf
 from nova import exception
-from nova.i18n import _, _LE
+from nova.i18n import _
 from nova.virt.xenapi import pool_states
 from nova.virt.xenapi import vm_utils
 
@@ -54,8 +54,8 @@ class ResourcePool(object):
                 aggregate.update_metadata(metadata)
             op(host)
         except Exception:
-            LOG.exception(_LE('Aggregate %(aggregate_id)s: unrecoverable '
-                              'state during operation on %(host)s'),
+            LOG.exception(_('Aggregate %(aggregate_id)s: unrecoverable '
+                            'state during operation on %(host)s'),
                           {'aggregate_id': aggregate.id, 'host': host})
 
     def add_to_aggregate(self, context, aggregate, host, slave_info=None):
@@ -171,7 +171,7 @@ class ResourcePool(object):
                     'master_pass': CONF.xenserver.connection_password, }
             self._session.call_plugin('xenhost.py', 'host_join', args)
         except self._session.XenAPI.Failure as e:
-            LOG.error(_LE("Pool-Join failed: %s"), e)
+            LOG.error("Pool-Join failed: %s", e)
             raise exception.AggregateError(aggregate_id=aggregate_id,
                                            action='add_to_aggregate',
                                            reason=_('Unable to join %s '
@@ -190,7 +190,7 @@ class ResourcePool(object):
             host_ref = self._session.host.get_by_uuid(host_uuid)
             self._session.pool.eject(host_ref)
         except self._session.XenAPI.Failure as e:
-            LOG.error(_LE("Pool-eject failed: %s"), e)
+            LOG.error("Pool-eject failed: %s", e)
             raise exception.AggregateError(aggregate_id=aggregate_id,
                                            action='remove_from_aggregate',
                                            reason=six.text_type(e.details))
@@ -201,7 +201,7 @@ class ResourcePool(object):
             pool_ref = self._session.pool.get_all()[0]
             self._session.pool.set_name_label(pool_ref, aggregate_name)
         except self._session.XenAPI.Failure as e:
-            LOG.error(_LE("Unable to set up pool: %s."), e)
+            LOG.error("Unable to set up pool: %s.", e)
             raise exception.AggregateError(aggregate_id=aggregate_id,
                                            action='add_to_aggregate',
                                            reason=six.text_type(e.details))
@@ -212,7 +212,7 @@ class ResourcePool(object):
             pool_ref = self._session.pool.get_all()[0]
             self._session.pool.set_name_label(pool_ref, '')
         except self._session.XenAPI.Failure as e:
-            LOG.error(_LE("Pool-set_name_label failed: %s"), e)
+            LOG.error("Pool-set_name_label failed: %s", e)
             raise exception.AggregateError(aggregate_id=aggregate_id,
                                            action='remove_from_aggregate',
                                            reason=six.text_type(e.details))
