@@ -22,32 +22,20 @@ import eventlet
 import eventlet.green
 import eventlet.greenio
 import eventlet.wsgi
-from oslo_config import cfg
 from oslo_log import log as logging
 import webob
 
+import nova.conf
 from nova.consoleauth import rpcapi as consoleauth_rpcapi
 from nova import context
 from nova.i18n import _LI
+from nova import utils
 from nova import version
 from nova import wsgi
 
 
 LOG = logging.getLogger(__name__)
-
-xvp_proxy_opts = [
-    cfg.IntOpt('xvpvncproxy_port',
-               default=6081,
-               min=1,
-               max=65535,
-               help='Port that the XCP VNC proxy should bind to'),
-    cfg.StrOpt('xvpvncproxy_host',
-               default='0.0.0.0',
-               help='Address that the XCP VNC proxy should bind to'),
-    ]
-
-CONF = cfg.CONF
-CONF.register_opts(xvp_proxy_opts)
+CONF = nova.conf.CONF
 
 
 class XCPVNCProxy(object):
@@ -110,7 +98,7 @@ class XCPVNCProxy(object):
     def proxy_connection(self, req, connect_info, start_response):
         """Spawn bi-directional vnc proxy."""
         sockets = {}
-        t0 = eventlet.spawn(self.handshake, req, connect_info, sockets)
+        t0 = utils.spawn(self.handshake, req, connect_info, sockets)
         t0.wait()
 
         if not sockets.get('client') or not sockets.get('server'):
@@ -122,8 +110,8 @@ class XCPVNCProxy(object):
         client = sockets['client']
         server = sockets['server']
 
-        t1 = eventlet.spawn(self.one_way_proxy, client, server)
-        t2 = eventlet.spawn(self.one_way_proxy, server, client)
+        t1 = utils.spawn(self.one_way_proxy, client, server)
+        t2 = utils.spawn(self.one_way_proxy, server, client)
         t1.wait()
         t2.wait()
 
@@ -180,5 +168,5 @@ def get_wsgi_server():
     return wsgi.Server("XCP VNC Proxy",
                        XCPVNCProxy(),
                        protocol=SafeHttpProtocol,
-                       host=CONF.xvpvncproxy_host,
-                       port=CONF.xvpvncproxy_port)
+                       host=CONF.vnc.xvpvncproxy_host,
+                       port=CONF.vnc.xvpvncproxy_port)
